"use strict"

if (!(IwetcBuilder instanceof Object)) {
    var IwetcBuilder = {};
}

// component
IwetcBuilder.Component = {
    groups: {},
    elements: {},

    init: function () {
        let $this = this;

        if (Object.keys($this.groups).length < 1) {
            return;
        }

        jQuery(document).ready(function () {
            let wrapperElement = jQuery('#iwetc-builder-left-sidebar .iwetc-tab-content[data-content="components"] .iwetc-builder-left-sidebar-middle-content .iwetc-changeable-elements');
            wrapperElement.html('');

            let groupHtml = "";
            let bottomLayouts = "";
            let activeEmailType = jQuery('#iwetc-builder-email-type').val();

            jQuery.each($this.groups, function (key, group) {
                groupHtml += '<div class="iwetc-builder-left-sidebar-section" data-group-name="' + key + '">' +
                    '<div class="iwetc-builder-left-sidebar-section-title collapsed">' +
                    '<i class="dashicons dashicons-arrow-down"></i>' +
                    group.label +
                    '</div>';
                if (group.elements) {
                    groupHtml += "<div class='iwetc-builder-left-sidebar-section-content'>";
                    jQuery.each(group.elements, function (elementKey, element) {
                        if (jQuery.inArray(activeEmailType, element.allowedEmailTypes) !== -1) {
                            if (element.type == 'layout') {
                                bottomLayouts += '<div class="iwetc-bottom-layout-item iwetc-' + element.type + '-draggable" data-name="' + element.name + '"><i class="' + element.icon + '"></i></div>';
                            }
                            groupHtml += '<div class="iwetc-component-item iwetc-builder-col-6">';

                            if (jQuery.inArray(element.name, ['post', 'products', 'coupon', 'wc_hook']) !== -1) {
                                groupHtml += '<div class="iwetc-builder-element" style="position: relative;">';
                                groupHtml += '<i class="' + element.icon + '"></i>';
                                groupHtml += "<span>" + element.label + "</span>";
                                groupHtml += "<div class='iwetc-builder-element-pro-badge'><strong>PRO</strong></div>";
                                groupHtml += "</div>";
                            } else {
                                groupHtml += '<div class="iwetc-builder-element iwetc-' + element.type + '-draggable" data-name="' + element.name + '">';
                                groupHtml += '<i class="' + element.icon + '"></i>';
                                groupHtml += "<span>" + element.label + "</span>";
                                groupHtml += "</div>";
                            }

                            groupHtml += "</div>";
                        }
                    });
                    groupHtml += "</div>";
                }
                groupHtml += "</div>";
            });

            jQuery('.iwetc-bottom-add-layout .iwetc-bottom-layouts-wrapper').html(bottomLayouts).ready(function () {
                wrapperElement.html(groupHtml).ready(function () {
                    $this.draggableInit();
                });
            });
        });
    },

    addGroup: function (name, label) {
        if (!this.groups[name]) {
            this.groups[name] = {
                label: label,
                elements: []
            };
        }
    },

    addElement: function (data) {
        if (data.group) {
            this.groups[data.group].elements.push(data);
        }

        this.elements[data.name] = data;
    },

    getElement: function (name) {
        return this.elements[name];
    },

    getElements: function () {
        return this.elements
    },

    getGroup: function (name) {
        return this.groups[name];
    },

    getGroups: function () {
        return this.groups;
    },

    draggableInit: function () {
        let $this = this;

        // layout draggable
        jQuery('.iwetc-layout-draggable').unbind();
        jQuery('.iwetc-layout-draggable').draggable({
            cursor: 'move',
            appendTo: 'body',
            cursorAt: { left: 30, top: 11 },
            helper: function () {
                let element = IwetcBuilder.Component.getElement(jQuery(this).attr('data-name'));
                return IwetcBuilder.Generate.layout(element);
            },
            start: function (e, ui) {
                ui.helper.addClass('iwetc-is-dragging');
            },
            drag: function (e, ui) {
            },
            stop: function (e, ui) {
                ui.helper.attr('style', '');
                ui.helper.removeClass('iwetc-is-dragging');
                ui.helper.click();
                $this.contentSortableInit();
            },
            connectToSortable: '.iwetc-email-body'
        });

        // content draggable
        jQuery('.iwetc-content-draggable').unbind();
        jQuery('.iwetc-content-draggable').draggable({
            cursor: 'move',
            appendTo: 'body',
            cursorAt: { left: 30, top: 11 },
            helper: function () {
                if (jQuery('#iwetc-builder-body-elements .iwetc-layout-draggable').length < 1) {
                    let layoutElement = IwetcBuilder.Component.getElement('one_column');
                    jQuery('#iwetc-builder-body-elements .iwetc-email-body').html(IwetcBuilder.Generate.layout(layoutElement));
                    $this.contentSortableInit();
                }

                needToConfirm = true;
                let element = IwetcBuilder.Component.getElement(jQuery(this).attr('data-name'));
                return IwetcBuilder.Generate.content(element);
            },
            start: function (ev, ui) {
                ui.helper.addClass('iwetc-is-dragging');
            },
            drag: function (ev, ui) {
            },
            stop: function (ev, ui) {
                ui.helper.attr('style', '');
                ui.helper.removeClass('iwetc-is-dragging');
                $this.contentSortableInit();

                setTimeout(function () {
                    ui.helper.find('.iwetc-content-element').click();
                }, 150)
            },
            connectToSortable: '.iwetc-column-sortable',
        });

        // sortable init
        $this.layoutSortableInit();
        $this.contentSortableInit();
    },

    layoutSortableInit: function () {
        // sortable for layouts
        jQuery(".iwetc-email-body").sortable({
            cursor: 'move',
            placeholder: 'iwetc-placeholder',
            handle: '.iwetc-layout-move-handler',
            cancel: '',
            cursorAt: { left: 30, top: 11 },
            start: function (e, ui) {
                ui.helper.addClass('iwetc-is-dragging');
            },
            stop: function (ev, ui) {
                ui.item.removeClass('iwetc-is-dragging');
            }
        });
    },

    contentSortableInit: function () {
        let $this = this;
        // sortable for contents
        jQuery(".iwetc-column-sortable").sortable({
            cursor: 'move',
            placeholder: 'iwetc-placeholder',
            handle: '',
            cancel: '',
            cursorAt: { left: 30, top: 11 },
            items: '.iwetc-content-draggable',
            start: function (e, ui) {
                ui.helper.addClass('iwetc-is-dragging');
            },
            stop: function (ev, ui) {
                ui.item.removeClass('iwetc-is-dragging');
                $this.checkEmptyLayoutColumns();
            },
            connectWith: ".iwetc-column-sortable"
        });
    },

    checkEmptyLayoutColumns: function () {
        if (jQuery('.iwetc-layout-column').length > 0) {
            jQuery('.iwetc-layout-column').each(function () {
                if (jQuery(this).find('.iwetc-content-draggable').length == 0) {
                    jQuery(this).addClass('iwetc-layout-placeholder');
                } else {
                    jQuery(this).removeClass('iwetc-layout-placeholder');
                }
            })
        }
    },

    openEditor: function (elementName, elementObject) {
        if (jQuery('#iwetc-builder-body .iwetc-element-focus').length < 1) {
            return false;
        }

        let element = this.getElement(elementName);
        if (!(element instanceof Object)) {
            return false;
        }

        jQuery('#iwetc-selected-element-name').text(element.type == 'layout' ? 'Row' : element.label)

        let editorItemsHtml = '';
        let propertyObject;
        let properties;

        if (!jQuery.isArray(element.properties)) {
            let template = (elementObject.find('.iwetc-has-template').attr('data-template')) ? elementObject.find('.iwetc-has-template').attr('data-template') : 'default';
            properties = element.properties[template];
        } else {
            properties = element.properties;
        }

        if (jQuery.isArray(properties) && properties.length > 0) {
            jQuery.each(properties, function (i, property) {
                propertyObject = IwetcBuilder.Property.getProperty(property);
                editorItemsHtml += '<div class="iwetc-builder-left-sidebar-section">';
                editorItemsHtml += '<div class="iwetc-builder-left-sidebar-section-title collapsed"><i class="dashicons dashicons-arrow-down"></i>' + propertyObject.label + '</div>';
                editorItemsHtml += '<div class="iwetc-builder-left-sidebar-section-content">';
                editorItemsHtml += propertyObject.getHtml(elementObject)
                editorItemsHtml += '</div>';
                editorItemsHtml += '</div>';
                jQuery('.iwetc-builder-left-sidebar-editor-items').html(editorItemsHtml);

                if (parseInt(i + 1) === parseInt(properties.length)) {
                    iwetcBuilderReInit();
                    openEditorTab();
                }
            });
        }
    },
}

// element generator 
IwetcBuilder.Generate = {
    layout: function (element) {
        if (!element) {
            return;
        }

        let output = '';
        if (parseInt(element.columns) > 0) {
            output += "<div class='iwetc-layout-draggable iwetc-layout-editable' data-element-name='" + element.name + "' data-columns='" + element.columns + "' data-type='layout'>";
            output += '<div class="iwetc-layout-content" data-distance="0" style="width: 100%; height: auto; float: left; padding:15px; background-color: #ffffff; border-style: solid; border-width: 0; border-color: transparent; box-sizing: border-box; -moz-box-sizing: border-box; -webkit-box-sizing: border-box;">';
            output += '<div class="iwetc-layout-row" style="width: 100%; display: inline-block; box-sizing: border-box; -moz-box-sizing: border-box; -webkit-box-sizing: border-box;">';
            for (let i = 1; i <= parseInt(element.columns); i++) {
                let width = (100 / parseInt(element.columns)).toFixed(2) * 1;
                output += '<div class="iwetc-layout-column-wrap" style="width: ' + width + '%;"><div data-width="' + width + '" class="iwetc-layout-column iwetc-layout-placeholder iwetc-column-sortable iwetc-layout-col-' + element.columns + '" style="padding: 10px; border-style: solid; border-color: transparent; float: left; box-sizing: border-box; -moz-box-sizing: border-box; -webkit-box-sizing: border-box;" data-type="column">' +
                    '<button type="button" class="iwetc-column-edit-handler"><i class="dashicons dashicons-edit" title="Edit Column"></i></button>' +
                    '</div></div>';
            }
            output += '<div class="iwetc-layout-handler-left">';
            output += '<button type="button" class="iwetc-layout-move-handler"><i class="dashicons dashicons-move" title="' + IwetcBuilder.Translate.move + '"></i></button>';
            output += '<button type="button" class="iwetc-layout-edit-handler"><i class="dashicons dashicons-edit" title="' + IwetcBuilder.Translate.edit + '"></i></button>';
            output += '<button type="button" class="iwetc-layout-duplicate-handler"><i class="dashicons dashicons-admin-page" title="' + IwetcBuilder.Translate.duplicate + '"></i></button>';
            output += '</div>';
            output += '<div class="iwetc-layout-handler-right">';
            output += '<button type="button" class="iwetc-layout-copy-handler"><i class="dashicons dashicons-welcome-add-page" title="' + IwetcBuilder.Translate.copy + '"></i></button>';
            output += '<button type="button" class="iwetc-layout-paste-handler"><i class="dashicons dashicons-arrow-down-alt" title="' + IwetcBuilder.Translate.paste + '"></i></button>';
            output += '<button type="button" class="iwetc-layout-delete-handler"><i class="dashicons dashicons-trash" title="' + IwetcBuilder.Translate.delete + '"></i></button>';
            output += '</div>';
            output += '</div>';
            output += '</div>';
            output += '<button type="button" class="iwetc-add-new-row"><i class="dashicons dashicons-insert"></i></button>';
            output += '</div>';
        }

        return output;
    },

    content: function (element) {
        let output = '';
        if (element instanceof Object) {
            output += "<div class='iwetc-content-draggable'>";
            output += "<div class='iwetc-content-element iwetc-element-editable' data-element-name='" + element.name + "' data-type='content'>";
            output += '<div class="iwetc-element-content" style="background-color: transparent; border-style: solid; border-color: transparent; box-sizing: border-box; -moz-box-sizing: border-box; -webkit-box-sizing: border-box; background-position: center center; background-repeat: no-repeat; background-size: cover; line-height: 18px;">';
            output += element.defaultValue;
            output += '</div>';
            output += '<div class="iwetc-content-handler-buttons">';
            output += '<button type="button" class="iwetc-content-edit-handler"><i class="dashicons dashicons-edit" title="' + IwetcBuilder.Translate.edit + ' ' + element.name + '"></i></button>';
            output += '<button type="button" class="iwetc-content-duplicate-handler"><i class="dashicons dashicons-admin-page" title="' + IwetcBuilder.Translate.duplicate + '"></i></button>';
            output += '<button type="button" class="iwetc-content-delete-handler"><i class="dashicons dashicons-trash" title="' + IwetcBuilder.Translate.delete + '"></i></button>';
            output += '</div>';
            output += '</div>';
            output += '</div>';
        }

        return output;
    },
}

// property
IwetcBuilder.Property = {
    properties: {},

    addProperty: function (data) {
        this.properties[data.name] = data;
    },

    getProperty: function (name) {
        return this.properties[name];
    },

    render: function (propertyName) {
        let property = this.getProperty(propertyName);
        return property.html;
    },
}

IwetcBuilder.SetPostData = function () {

    if (typeof iwetcNewEmailData != 'undefined' && iwetcNewEmailData.emailType != '' && iwetcNewEmailData.emailTitle != '') {
        jQuery('#iwetc-builder-email-type').val(iwetcNewEmailData.emailType).trigger('change');
        iwetcNewEmailData.emailType;
        let categoryTemplates = IwetcBuilder.SampleTemplates[iwetcNewEmailData.emailType];

        if (categoryTemplates[Object.keys(categoryTemplates)[0]] && categoryTemplates[Object.keys(categoryTemplates)[0]].structure) {
            iwetcImportTemplate(categoryTemplates[Object.keys(categoryTemplates)[0]].structure);
        }

        jQuery('#title').val(iwetcNewEmailData.emailTitle).trigger('change');
    }

    if (IwetcBuilder.PostData.email_type) {
        jQuery('#iwetc-builder-email-type').attr('data-first-load', 'true').val(IwetcBuilder.PostData.email_type).change();
    }
    if (IwetcBuilder.PostData.direction) {
        jQuery('#iwetc-direction').val(IwetcBuilder.PostData.direction).change();
    }
    if (IwetcBuilder.PostData.custom_css) {
        jQuery('#iwetc-custom-css').val(IwetcBuilder.PostData.custom_css);
    }

    if (IwetcBuilder.PostData.email_structure) {
        jQuery('.iwetc-email-body').html(iwetcParseEmailStructure(IwetcBuilder.PostData.email_structure)).ready(function () {
            IwetcBuilder.Component.init();
        });
    }

    if (jQuery('#iwetc-builder-main-background-color').length > 0) {
        let color = (jQuery('#iwetc-builder-body').css('background-color'));
        jQuery('#iwetc-builder-main-background-color').val((color == 'rgba(0, 0, 0, 0)') ? 'transparent' : color).change();
    }

    if (jQuery('#iwetc-builder-width').length > 0) {
        jQuery('#iwetc-builder-width').val(parseInt(jQuery('.iwetc-builder-body-wrapper').css('width'))).change();
    }

    if (jQuery('#iwetc-builder-responsive-point').length > 0) {
        jQuery('#iwetc-builder-responsive-point').val(parseInt(jQuery('.iwetc-builder-body-wrapper').attr('data-responsive-point')));
    }
}