"use strict"

let basicTypes = [
    'default',
    'customer_new_account',
    'customer_reset_password'
];
let orderTypes = [
    'new_order',
    'cancelled_order',
    'failed_order',
    'customer_on_hold_order',
    'customer_processing_order',
    'customer_completed_order',
    'customer_refunded_order',
    'customer_invoice',
    'customer_note',
];
let allTypes = IwetcBuilder.EmailTypes;

// add component groups
IwetcBuilder.Component.addGroup('general', IwetcBuilder.Translate.general);
IwetcBuilder.Component.addGroup('content', IwetcBuilder.Translate.content);
IwetcBuilder.Component.addGroup('woocommerce', IwetcBuilder.Translate.woocommerce);

// add layouts
IwetcBuilder.Component.addElement({
    type: 'layout',
    group: 'general',
    name: 'one_column',
    allowedEmailTypes: allTypes,
    label: IwetcBuilder.Translate.one_column,
    icon: 'it-builder-icon-one-column',
    columns: 1,
    properties: ['column_editor', 'background', 'height', 'padding', 'border', 'custom_class']
});
IwetcBuilder.Component.addElement({
    type: 'layout',
    group: 'general',
    name: 'two_columns',
    allowedEmailTypes: allTypes,
    label: IwetcBuilder.Translate.two_columns,
    icon: 'it-builder-icon-two-columns',
    columns: 2,
    properties: ['column_editor', 'horizontal_column_distance', 'background', 'height', 'padding', 'border', 'custom_class']
});
IwetcBuilder.Component.addElement({
    type: 'layout',
    group: 'general',
    name: 'three_columns',
    allowedEmailTypes: allTypes,
    label: IwetcBuilder.Translate.three_columns,
    icon: 'it-builder-icon-three-columns',
    columns: 3,
    properties: ['column_editor', 'horizontal_column_distance', 'background', 'height', 'padding', 'border', 'custom_class']
});
IwetcBuilder.Component.addElement({
    type: 'layout',
    group: 'general',
    name: 'four_columns',
    allowedEmailTypes: allTypes,
    label: IwetcBuilder.Translate.four_columns,
    icon: 'it-builder-icon-four-columns',
    columns: 4,
    properties: ['column_editor', 'horizontal_column_distance', 'background', 'height', 'padding', 'border', 'custom_class']
});

// column
IwetcBuilder.Component.addElement({
    type: 'column',
    name: 'column',
    allowedEmailTypes: allTypes,
    label: IwetcBuilder.Translate.column,
    properties: ['column_width', 'background', 'padding', 'border', 'custom_class']
});

// add contents
IwetcBuilder.Component.addElement({
    type: 'content',
    group: 'content',
    name: 'text',
    allowedEmailTypes: allTypes,
    label: IwetcBuilder.Translate.text,
    icon: 'it-builder-icon-text',
    defaultValue: '<p>Text</p>',
    properties: ['text_editor', 'line_height', 'background', 'padding', 'margin', 'border', 'custom_class']
});
IwetcBuilder.Component.addElement({
    type: 'content',
    group: 'content',
    name: 'html',
    allowedEmailTypes: allTypes,
    label: IwetcBuilder.Translate.html,
    icon: 'it-builder-icon-html-five',
    defaultValue: '',
    properties: ['textarea']
});
IwetcBuilder.Component.addElement({
    type: 'content',
    group: 'content',
    name: 'image',
    allowedEmailTypes: allTypes,
    label: IwetcBuilder.Translate.image,
    icon: 'it-builder-icon-image',
    defaultValue: IwetcBuilder.Component.DefaultValue.image,
    properties: ['image', 'size', 'alignment', 'image_border_radius', 'background', 'padding', 'custom_class']
});
IwetcBuilder.Component.addElement({
    type: 'content',
    group: 'content',
    name: 'button',
    allowedEmailTypes: allTypes,
    label: IwetcBuilder.Translate.button,
    icon: 'it-builder-icon-button',
    defaultValue: IwetcBuilder.Component.DefaultValue.button,
    properties: ['text', 'link', 'button_text', 'border', 'background', 'size', 'alignment', 'padding', 'margin', 'custom_class']
});
IwetcBuilder.Component.addElement({
    type: 'content',
    group: 'woocommerce',
    name: 'order_details',
    allowedEmailTypes: orderTypes,
    label: IwetcBuilder.Translate.order_details,
    icon: 'it-builder-icon-order-detail',
    defaultValue: IwetcBuilder.Component.DefaultValue.order_details.default,
    childrenNames: ['order_details_product_name', 'order_details_quantity', 'order_details_price', 'order_details_product_text', 'order_details_quantity_text', 'order_details_price_text', 'items_distance_horizontal', 'items_distance_vertical', 'order_details_image'],
    properties: {
        default: ['order_details_template', 'order_details_default_translate', 'order_details_show_sku', 'font_full', 'background', 'padding', 'custom_class'],
        vertical_text: ['order_details_template', 'order_details_custom_translate', 'order_details_product_name', 'order_details_price', 'order_details_quantity', 'order_details_show_sku', 'size', 'border', 'items_distance', 'background', 'padding', 'custom_class'],
        horizontal_text: ['order_details_template', 'order_details_custom_translate', 'order_details_product_name', 'order_details_price', 'order_details_quantity', 'order_details_show_sku', 'size', 'border', 'items_distance', 'background', 'padding', 'custom_class']
    }
});
IwetcBuilder.Component.addElement({
    type: 'content',
    group: 'woocommerce',
    name: 'order_subtotal',
    allowedEmailTypes: orderTypes,
    label: IwetcBuilder.Translate.order_subtotal,
    icon: 'it-builder-icon-order-subtotal',
    defaultValue: IwetcBuilder.Component.DefaultValue.order_subtotal,
    childrenNames: ['order_subtotal_subtotal_text', 'order_subtotal_discount_text', 'order_subtotal_shipping_text', 'order_subtotal_order_fully_refunded_text', 'order_subtotal_refunded_text', 'order_subtotal_price'],
    properties: ['subtotal_translate', 'double_alignment', 'padding', 'border', 'font_full', 'background', 'custom_class'],
});
IwetcBuilder.Component.addElement({
    type: 'content',
    group: 'woocommerce',
    name: 'order_total',
    allowedEmailTypes: orderTypes,
    label: IwetcBuilder.Translate.order_total,
    icon: 'it-builder-icon-order-total',
    defaultValue: IwetcBuilder.Component.DefaultValue.order_total,
    childrenNames: ['order_total_text', 'order_total_price'],
    properties: ['order_total_translate', 'double_alignment', 'padding', 'border', 'font_full', 'background', 'custom_class'],
});
IwetcBuilder.Component.addElement({
    type: 'content',
    group: 'woocommerce',
    name: 'shipping_method',
    allowedEmailTypes: orderTypes,
    label: IwetcBuilder.Translate.shipping_method,
    icon: 'it-builder-icon-truck',
    defaultValue: IwetcBuilder.Component.DefaultValue.shipping_method,
    childrenNames: ['shipping_method_text', 'shipping_method_value'],
    properties: ['shipping_method_translate', 'double_alignment', 'padding', 'border', 'font_full', 'background', 'custom_class'],
});
IwetcBuilder.Component.addElement({
    type: 'content',
    group: 'woocommerce',
    name: 'payment_method',
    allowedEmailTypes: orderTypes,
    label: IwetcBuilder.Translate.payment_method,
    icon: 'it-builder-icon-credit-card',
    defaultValue: IwetcBuilder.Component.DefaultValue.payment_method,
    childrenNames: ['payment_method_text', 'payment_method_value'],

    properties: ['payment_method_translate', 'double_alignment', 'padding', 'border', 'font_full', 'background', 'custom_class'],
});
IwetcBuilder.Component.addElement({
    type: 'content',
    group: 'woocommerce',
    name: 'customer_note',
    allowedEmailTypes: orderTypes,
    label: IwetcBuilder.Translate.customer_note,
    icon: 'it-builder-icon-note1',
    defaultValue: IwetcBuilder.Component.DefaultValue.customer_note,
    childrenNames: ['customer_note_text', 'customer_note_value'],
    properties: ['customer_note_translate', 'double_alignment', 'padding', 'border', 'font_full', 'background', 'custom_class'],
});
IwetcBuilder.Component.addElement({
    type: 'content',
    group: 'woocommerce',
    name: 'billing_address',
    allowedEmailTypes: orderTypes,
    label: IwetcBuilder.Translate.billing_address,
    icon: 'it-builder-icon-billing-address',
    defaultValue: IwetcBuilder.Component.DefaultValue.billing_address,
    childrenNames: [],
    properties: ['alignment', 'padding', 'border', 'font_full', 'background', 'custom_class'],
});
IwetcBuilder.Component.addElement({
    type: 'content',
    group: 'woocommerce',
    name: 'shipping_address',
    allowedEmailTypes: orderTypes,
    label: IwetcBuilder.Translate.shipping_address,
    icon: 'it-builder-icon-truck',
    defaultValue: IwetcBuilder.Component.DefaultValue.shipping_address,
    childrenNames: [],
    properties: ['alignment', 'padding', 'border', 'font_full', 'background', 'custom_class'],
});
IwetcBuilder.Component.addElement({
    type: 'content',
    group: 'woocommerce',
    name: 'products',
    allowedEmailTypes: allTypes,
    label: IwetcBuilder.Translate.products,
    icon: 'it-builder-icon-product',
    defaultValue: IwetcBuilder.Component.DefaultValue.products,
    childrenNames: ['products_product_name', 'product_image', 'products_price', 'items_distance_horizontal', 'items_distance_vertical', 'add_to_cart_button'],
    properties: ['product_type', 'products_add_to_cart_in_url', 'product_image', 'products_product_name', 'products_price', 'items_distance', 'padding', 'background', 'custom_class'],
});
IwetcBuilder.Component.addElement({
    type: 'content',
    group: 'woocommerce',
    name: 'coupon',
    allowedEmailTypes: allTypes,
    label: IwetcBuilder.Translate.coupon,
    icon: 'it-builder-icon-coupon',
    defaultValue: IwetcBuilder.Component.DefaultValue.coupon,
    childrenNames: ['coupon', 'coupon_code'],
    properties: ['coupon_type', 'coupon_text_editor', 'background', 'padding', 'line_height', 'margin', 'custom_class'],
});
IwetcBuilder.Component.addElement({
    type: 'content',
    group: 'content',
    name: 'post',
    allowedEmailTypes: allTypes,
    label: IwetcBuilder.Translate.post,
    icon: 'it-builder-icon-pushpin',
    defaultValue: IwetcBuilder.Component.DefaultValue.post,
    childrenNames: ['post_image', 'post_title', 'post_content', 'items_distance_horizontal', 'items_distance_vertical'],
    properties: ['post_type', 'post_image', 'post_title', 'post_content', 'items_distance', 'border', 'alignment', 'padding', 'background', 'custom_class'],
});
IwetcBuilder.Component.addElement({
    type: 'content',
    group: 'content',
    name: 'contact',
    allowedEmailTypes: allTypes,
    label: IwetcBuilder.Translate.contact,
    icon: 'it-builder-icon-address-book',
    defaultValue: IwetcBuilder.Component.DefaultValue.contact,
    childrenNames: [],
    properties: ['contact_items', 'contact_icon_size', 'font', 'text_color', 'line_height', 'alignment', 'padding', 'background', 'custom_class'],
});
IwetcBuilder.Component.addElement({
    type: 'content',
    group: 'content',
    name: 'menu_bar',
    allowedEmailTypes: allTypes,
    label: IwetcBuilder.Translate.menu_bar,
    icon: 'it-builder-icon-menu',
    defaultValue: IwetcBuilder.Component.DefaultValue.menu_bar,
    childrenNames: [],
    properties: ['menu_bar_items', 'menu_bar_divider', 'table_direction', 'alignment', 'font_full', 'border', 'background', 'custom_class'],
});
IwetcBuilder.Component.addElement({
    type: 'content',
    group: 'content',
    name: 'socials',
    allowedEmailTypes: allTypes,
    label: IwetcBuilder.Translate.socials,
    icon: 'it-builder-icon-share2',
    defaultValue: IwetcBuilder.Component.DefaultValue.socials,
    childrenNames: [],
    properties: ['social_items', 'socials_style', 'socials_icon_size', 'direction', 'alignment', 'background', 'custom_class'],
});
IwetcBuilder.Component.addElement({
    type: 'content',
    group: 'content',
    name: 'divider',
    allowedEmailTypes: allTypes,
    label: IwetcBuilder.Translate.divider,
    icon: 'it-builder-icon-divider',
    defaultValue: IwetcBuilder.Component.DefaultValue.divider,
    childrenNames: [],
    properties: ['divider_border', 'padding', 'background', 'custom_class'],
});
IwetcBuilder.Component.addElement({
    type: 'content',
    group: 'content',
    name: 'spacer',
    allowedEmailTypes: allTypes,
    label: IwetcBuilder.Translate.spacer,
    icon: 'it-builder-icon-spacer',
    defaultValue: IwetcBuilder.Component.DefaultValue.spacer,
    childrenNames: [],
    properties: ['spacer_height', 'custom_class'],
});
IwetcBuilder.Component.addElement({
    type: 'content',
    group: 'woocommerce',
    name: 'wc_hook',
    allowedEmailTypes: orderTypes,
    label: IwetcBuilder.Translate.wc_hook,
    icon: 'it-builder-icon-hook',
    defaultValue: IwetcBuilder.Component.DefaultValue.wc_hook,
    childrenNames: ['wc_hook'],
    properties: ['select_hook', 'padding', 'background', 'font', 'text_color', 'line_height', 'custom_class'],
});

// components init
IwetcBuilder.Component.init();