jQuery(document).ready(function ($) {
    "use strict"

    // select2 init
    iwetcSelect2Init();

    $(document).on("keypress", function (e) {
        if (e.keyCode === 13) {
            if ($('#iwetc-html-editor').is(':focus') == false) {
                e.preventDefault();
            }

            if ($('#iwetc-to-email').is(':focus')) {
                $('#iwetc-modal-send-email-button').trigger('click');
            }
        }
    });

    $(window).on('scroll', function () {
        let shortcodeBox = $('.iwetc-shortcode-list:visible');
        if (shortcodeBox.length > 0 && shortcodeBox.attr('data-target') == 'email_subject') {
            let topPosition = parseInt(parseInt(shortcodeBox.attr('data-first-top')) - $(this).scrollTop());
            if (topPosition < 50) {
                shortcodeBox.hide();
            } else {
                shortcodeBox.css({
                    top: topPosition
                });
            }
        }
    })

    $('.iwetc-builder-left-sidebar-middle-content').on("scroll", function (e) {
        let shortcodeBox = $('.iwetc-shortcode-list:visible');
        if (shortcodeBox.length > 0 && shortcodeBox.attr('data-target') != 'email_subject') {
            let topPosition = parseInt(parseInt(shortcodeBox.attr('data-first-top')) - $(this).scrollTop());
            if (topPosition < 100) {
                shortcodeBox.hide();
            } else {
                shortcodeBox.css({
                    top: topPosition
                });
            }
        }
    });

    // click on document
    $(document).on('click', function (e) {
        // close shortcode list
        if (!$(e.target).hasClass('iwetc-shortcode-button') && $(e.target).closest('.iwetc-shortcode-button').length == 0) {
            $('.iwetc-shortcode-list').hide();
        }
    });

    $(document).on('change', '#iwetc-is-dark-theme', function () {
        let themeName;
        let switchElement = $(this).closest('.iwetc-switch');

        if ($(this).prop('checked') === true) {
            switchElement.find('.dark').show();
            switchElement.find('.light').hide();
            themeName = 'iwetc-dark-theme';
            $('body').removeClass('iwetc-light-theme');
            $('body').addClass('iwetc-dark-theme');
        } else {
            switchElement.find('.light').show();
            switchElement.find('.dark').hide();
            themeName = 'iwetc-light-theme';
            $('body').removeClass('iwetc-dark-theme');
            $('body').addClass('iwetc-light-theme');
        }

        iwetcUpdateTheme(themeName);
    })

    $(document).on('change', '#iwetc-template-status-button', function () {
        let switchElement = $(this).closest('.iwetc-switch');

        if ($(this).prop('checked') === true) {
            switchElement.find('.disabled').hide();
            setTimeout(function () {
                switchElement.find('.enabled').show();
            }, 200)
        } else {
            switchElement.find('.enabled').hide();
            setTimeout(function () {
                switchElement.find('.disabled').show();
            }, 200)
        }
    })

    // change tab
    $(document).on('click', '.iwetc-tabs-title li a', function () {
        let tabsElement = $(this).closest('.iwetc-tabs');
        tabsElement.find('.iwetc-tabs-title a').removeClass('active');
        $(this).addClass('active');

        tabsElement.find('.iwetc-tab-content').removeClass('active');
        tabsElement.find('.iwetc-tab-content[data-content="' + $(this).attr('data-content') + '"]').addClass('active');
        iwetcBuilderReInit();
    });

    // go to component from editor tab
    $(document).on('click', '.iwetc-editor-back-to-component', function () {
        iwetcCloseEditor();
    });

    // full screen
    $(document).on('click', '#iwetc-full-screen', function () {
        $('body').toggleClass('iwetc-show-admin-bar');

        if ($('body').hasClass('iwetc-show-admin-bar')) {
            $(this).attr('title', 'Full Screen');
        } else {
            $(this).attr('title', 'Show WordPress Menu');
        }

        $(window).trigger('resize');
    });

    // collapse sections in left sidebar
    $(document).on('click', '.iwetc-builder-left-sidebar-section-title', function () {
        $(this).toggleClass('collapsed');
        let element = $(this).closest('.iwetc-builder-left-sidebar-section');
        element.find('.iwetc-builder-left-sidebar-section-content').slideToggle();

        setTimeout(function () {
            iwetcColorPickerInit();
        }, 350)
    });

    // components search
    $(document).on("keyup", "#iwetc-builder-component-search", function () {
        let text = $(this).val().toLowerCase().trim();
        $(".iwetc-builder-element").filter(function () {
            $(this).closest('.iwetc-component-item').toggle($(this).text().toLowerCase().indexOf(text) > -1);
        });
    });

    // delete layout row
    $(document).on('click', '.iwetc-layout-delete-handler', function () {
        let $this = $(this);

        swal({
            title: "Are you sure?",
            icon: "warning",
            buttons: {
                cancel: 'Cancel',
                yes: {
                    text: "Yes",
                    value: 'yes',
                    className: 'iwetc-button-blue',
                    closeModal: true,
                },
            },
        }).then(result => {
            switch (result) {
                case 'yes':
                    needToConfirm = true;
                    $this.closest('.iwetc-layout-draggable').remove();
                    iwetcCloseEditor();
                    break;
                default:
                    return;
            }
        });
    });

    // delete content
    $(document).on('click', '.iwetc-content-delete-handler', function (e) {
        let $this = $(this);

        swal({
            title: "Are you sure?",
            icon: "warning",
            buttons: {
                cancel: 'Cancel',
                yes: {
                    text: "Yes",
                    value: 'yes',
                    className: 'iwetc-button-blue',
                    closeModal: true,
                },
            },
        }).then(result => {
            switch (result) {
                case 'yes':
                    needToConfirm = true;
                    let layoutRow = $this.closest('.iwetc-layout-column');
                    $this.closest('.iwetc-content-draggable').remove();
                    if (layoutRow.find('.iwetc-content-draggable').length == 0) {
                        layoutRow.addClass('iwetc-layout-placeholder');
                        IwetcBuilder.Component.layoutSortableInit();
                        IwetcBuilder.Component.contentSortableInit();
                    }
                    iwetcCloseEditor();

                    break;
                default:
                    return;
            }
        });
    });

    // delete email template
    $(document).on('click', '#iwetc-move-to-trash', function (e) {
        let $this = $(this);
        swal({
            title: "Are you sure?",
            icon: "warning",
            buttons: {
                cancel: 'Cancel',
                yes: {
                    text: "Yes",
                    value: 'yes',
                    className: 'iwetc-button-blue',
                    closeModal: true,
                },
            },
        }).then(result => {
            switch (result) {
                case 'yes':
                    window.location = $this.attr('data-url');
                    break;
                default:
                    return;
            }
        });
    });

    $(document).on('click', '.iwetc-layout-row', function (e) {
        if ($(e.target).hasClass('iwetc-layout-column')
            || $(e.target).hasClass('iwetc-content-edit-handler')
            || $(e.target).hasClass('iwetc-content-element')
            || $(e.target).closest('.iwetc-content-edit-handler').length > 0
            || $(e.target).closest('.iwetc-content-handler-buttons').length > 0
            || $(e.target).hasClass('.iwetc-layout-duplicate-handler') === true
            || $(e.target).closest('.iwetc-layout-duplicate-handler').length > 0
            || $(e.target).hasClass('.iwetc-layout-move-handler') === true
            || $(e.target).closest('.iwetc-layout-move-handler').length > 0
            || $(e.target).closest('.iwetc-layout-handler-right').length > 0) {
            return;
        }

        $(e.target).closest('.iwetc-layout-draggable').find('.iwetc-layout-edit-handler').trigger('click');
    });

    $(document).on('change input keyup', '#iwetc-text-editor', function () {
        needToConfirm = true;
        iwetcBuilderElementUpdate({
            type: 'html',
            property: null,
            unit: null,
            value: $.iwetcNl2br($(this).val())
        });
    });

    $(document).on('change input keyup', '#iwetc-html-editor', function () {
        needToConfirm = true;
        iwetcBuilderElementUpdate({
            type: 'html',
            property: null,
            unit: null,
            value: $.iwetcNl2br($(this).val())
        });
    });

    $(document).on('click', '.iwetc-layout-draggable', function (e) {
        if ($(e.target).hasClass('iwetc-layout-column')
            || $(e.target).hasClass('iwetc-add-new-row')
            || $(e.target).hasClass('iwetc-content-edit-handler')
            || $(e.target).hasClass('iwetc-content-element')
            || $(e.target).closest('.iwetc-content-edit-handler').length > 0
            || $(e.target).closest('.iwetc-content-handler-buttons').length > 0
            || $(e.target).hasClass('.iwetc-layout-duplicate-handler') === true
            || $(e.target).closest('.iwetc-layout-duplicate-handler').length > 0
            || $(e.target).hasClass('.iwetc-layout-move-handler') === true
            || $(e.target).closest('.iwetc-layout-move-handler').length > 0
            || $(e.target).closest('.iwetc-layout-handler-right').length > 0) {
            return;
        }

        $(e.target).closest('.iwetc-layout-draggable').find('.iwetc-layout-edit-handler').trigger('click');
    });

    $(document).on('click', '.iwetc-layout-column', function (e) {
        if ($(e.target).find('.iwetc-content-draggable').length > 0
            || $(e.target).hasClass('iwetc-content-edit-handler')
            || $(e.target).hasClass('iwetc-content-element')
            || $(e.target).closest('.iwetc-content-edit-handler').length > 0
            || $(e.target).closest('.iwetc-content-handler-buttons').length > 0
            || $(e.target).hasClass('.iwetc-layout-duplicate-handler') === true
            || $(e.target).closest('.iwetc-layout-duplicate-handler').length > 0
            || $(e.target).hasClass('.iwetc-layout-move-handler') === true
            || $(e.target).closest('.iwetc-layout-move-handler').length > 0
            || $(e.target).closest('.iwetc-layout-handler-right').length > 0) {
            return;
        }

        $(e.target).closest('.iwetc-layout-draggable').find('.iwetc-layout-edit-handler').trigger('click');
    });

    $(document).on('click', '.iwetc-add-new-row', function (e) {
        let oneColumnElement = IwetcBuilder.Component.getElement('one_column');
        $(this).closest('.iwetc-layout-editable').before(IwetcBuilder.Generate.layout(oneColumnElement)).ready(function () {
            IwetcBuilder.Component.layoutSortableInit();
            IwetcBuilder.Component.contentSortableInit();
        });
        iwetcCloseEditor();
    });

    // duplicate content
    $(document).on('click', '.iwetc-content-duplicate-handler', function () {
        needToConfirm = true;
        let clone = $(this).closest('.iwetc-content-draggable').clone();
        $(this).closest('.iwetc-content-draggable').after(clone).ready(function () {
            $('.iwetc-element-editable').removeClass('iwetc-element-focus');
            clone.find('.iwetc-element-editable').trigger('click');
            IwetcBuilder.Component.layoutSortableInit();
            IwetcBuilder.Component.contentSortableInit();
        });

        iwetcCloseEditor();
    });

    // open bottom layouts wrappers
    $(document).on('click', '.iwetc-bottom-add-layout-button', function () {
        $('.iwetc-bottom-layouts-wrapper').toggle();
    });

    // close bottom layouts wrapper by click
    $(document).on('click', 'body', function (e) {
        if ($(e.target).closest('.iwetc-bottom-add-layout').length == 0) {
            $('.iwetc-bottom-layouts-wrapper').toggle(false);
        }
    });

    // add bottom layout item by click
    $(document).on('click', '.iwetc-bottom-layout-item', function () {
        needToConfirm = true;
        let layoutElement = IwetcBuilder.Component.getElement($(this).attr('data-name'));
        jQuery('#iwetc-builder-body-elements .iwetc-email-body').append(IwetcBuilder.Generate.layout(layoutElement));
        IwetcBuilder.Component.contentSortableInit();
        $('.iwetc-bottom-layouts-wrapper').toggle(false);
        iwetcCloseEditor();
    });

    // copy layout
    $(document).on('click', '.iwetc-layout-copy-handler', function () {
        needToConfirm = true;
        let layout = $(this).closest('.iwetc-layout-draggable');
        localStorage.setItem('iwetcLayoutRow', layout.prop('outerHTML'));
    });

    // paste layout
    $(document).on('click', '.iwetc-layout-paste-handler', function () {
        needToConfirm = true;
        let layoutRow = localStorage.getItem('iwetcLayoutRow');
        if (layoutRow) {
            $(this).closest('.iwetc-layout-draggable').after($(layoutRow)).ready(function () {
                IwetcBuilder.Component.layoutSortableInit();
                IwetcBuilder.Component.contentSortableInit();
            });
        }
        iwetcCloseEditor();
    });

    // edit layout
    $(document).on('click', '.iwetc-layout-edit-handler', function (e) {
        if ($(e.target).hasClass('iwetc-layout-column') === true
            || $(e.target).closest('.iwetc-content-handler-buttons').length > 0
            || $(e.target).hasClass('iwetc-element-focus')) {
            return;
        }

        iwetcCloseEditor();

        let layout = $(this).closest('.iwetc-layout-editable');
        layout.addClass('iwetc-element-focus');
        IwetcBuilder.Component.openEditor(layout.attr('data-element-name'), layout.find('.iwetc-layout-content'));

        e.stopPropagation();
    });

    // edit column
    $(document).on('click', '.iwetc-column-edit-handler', function (e) {
        iwetcCloseEditor();

        let column = $(this).closest('.iwetc-layout-column');
        column.addClass('iwetc-element-focus');
        IwetcBuilder.Component.openEditor('column', column);

        e.stopPropagation();
    });

    // duplicate layout
    $(document).on('click', '.iwetc-layout-duplicate-handler', function () {
        needToConfirm = true;
        let clone = $(this).closest('.iwetc-layout-draggable').clone();
        $(this).closest('.iwetc-layout-draggable').after(clone).ready(function () {
            IwetcBuilder.Component.layoutSortableInit();
            IwetcBuilder.Component.contentSortableInit();
        });

        iwetcCloseEditor();
    });

    // change email type
    $(document).on('change', '#iwetc-builder-email-type', function () {
        let emailType = $(this).val();
        let emailTypeLabel = $('#iwetc-builder-email-type option:selected').text();

        if ($(this).attr('data-first-load') == 'false') {
            swal({
                title: 'Insert default template for ' + emailTypeLabel + '?',
                icon: 'warning',
                buttons: {
                    cancel: 'Cancel (No Change)',
                    yes: {
                        text: "Yes",
                        value: 'yes',
                        className: 'iwetc-button-blue',
                        closeModal: true,
                    },
                    no: {
                        text: "No (Blank Page)",
                        value: 'no',
                        className: 'iwetc-button-red',
                        closeModal: true,
                    },
                },
            }).then(function (value) {
                switch (value) {
                    case 'yes':
                        let templateName = $('#iwetc-saved-templates-list').find('.iwetc-saved-template-item[data-category="' + emailType + '"]').first().find('.iwetc-template-import').val();
                        if (IwetcBuilder.SampleTemplates[emailType][templateName] && IwetcBuilder.SampleTemplates[emailType][templateName].structure) {
                            iwetcImportTemplate(IwetcBuilder.SampleTemplates[emailType][templateName].structure);
                        }
                        break;
                    case 'no':
                        iwetcImportTemplate('{}');
                        break;
                    default:
                        IwetcBuilder.Component.init();
                        return;
                }
            });
        }

        $('#iwetc-builder-email-type').attr('data-first-load', 'false');
    });

    // email subject shortcode
    $(document).on('click', '.iwetc-email-subject-shortcode', function () {
        $('.iwetc-email-subject-shortcode .iwetc-email-subject-shortcode-list').toggle();
    });
    $(document).on('click', '.iwetc-email-subject-shortcode-list li', function () {
        needToConfirm = true;
        $('label#title-prompt-text').addClass('screen-reader-text');
        $('input#title').val($('input#title').val() + $(this).text());
    });

    // editable contents
    $(document).on('click', '.iwetc-element-editable', function (e) {
        if ($(e.target).hasClass('iwetc-layout-column') === true
            || $(e.target).closest('.iwetc-content-handler-buttons').length > 0
            || $(e.target).hasClass('iwetc-element-focus')) {
            return;
        }

        iwetcCloseEditor();
        if ($(e.target).hasClass('iwetc-element-editable')) {
            $(e.target).addClass('iwetc-element-focus');
        } else {
            $(e.target).closest('.iwetc-element-editable').addClass('iwetc-element-focus');
        }

        let target = ($(this).find('.iwetc-element-content').find('.iwetc-builder-content-target').length > 0) ? $(this).find('.iwetc-element-content').find('.iwetc-builder-content-target') : $(this).find('.iwetc-element-content');
        IwetcBuilder.Component.openEditor($(this).attr('data-element-name'), target);
        e.stopPropagation();
    });

    let inputs = document.querySelectorAll('.iwetc-custom-input-file');
    Array.prototype.forEach.call(inputs, function (input) {
        let label = input.nextElementSibling,
            labelVal = label.innerHTML;

        input.addEventListener('change', function (e) {
            let fileName = (this.files && this.files.length > 1) ? (this.getAttribute('data-multiple-caption') || '').replace('{count}', this.files.length) : e.target.value.split('\\').pop();
            if (fileName) {
                jQuery(this.getAttribute('data-label-id')).text(fileName);
            } else {
                label.innerHTML = labelVal;
            }
        });
    });

    $(document).on('input', 'input.iwetc-builder-editor-input', function () {
        needToConfirm = true;

        if ($(this).attr('type') == 'number') {
            if ($(this).attr('max') && parseInt($(this).val()) > parseInt($(this).attr('max'))) {
                $(this).val(parseInt($(this).attr('max')));
            }

            if ($(this).attr('min') && parseInt($(this).val()) < parseInt($(this).attr('min'))) {
                $(this).val(parseInt($(this).attr('min')));
            }

            if ($('.iwetc-properties-auto-height-row').prop('checked') == false) {
                $('.iwetc-builder-editor-input').change();
            }
        }

        iwetcBuilderElementUpdate({
            type: $(this).attr('data-type'),
            property: $(this).attr('data-property'),
            unit: ($(this).attr('data-unit')) ? $(this).attr('data-unit') : null,
            target: ($(this).attr('data-target')) ? $(this).attr('data-target') : null,
            value: ($(this).attr('type') == 'checkbox') ? $(this).prop('checked') : $(this).val()
        });
    });

    $(document).on('change', 'input.iwetc-builder-editor-input', function () {
        needToConfirm = true;

        if ($(this).attr('type') == 'number') {
            if ($(this).val() == '') {
                $(this).val(0).trigger('input');
            }
        }

        iwetcBuilderElementUpdate({
            type: $(this).attr('data-type'),
            property: $(this).attr('data-property'),
            unit: ($(this).attr('data-unit')) ? $(this).attr('data-unit') : null,
            target: ($(this).attr('data-target')) ? $(this).attr('data-target') : null,
            value: ($(this).attr('type') == 'checkbox') ? $(this).prop('checked') : $(this).val()
        });
    });

    // update element
    $(document).on('click', 'button.iwetc-builder-editor-input', function () {
        needToConfirm = true;
        iwetcBuilderElementUpdate({
            type: $(this).attr('data-type'),
            property: $(this).attr('data-property'),
            unit: ($(this).attr('data-unit')) ? $(this).attr('data-unit') : null,
            target: ($(this).attr('data-target')) ? $(this).attr('data-target') : null,
            value: $(this).val()
        });
    });

    $(document).on('change', 'select.iwetc-builder-editor-input', function () {
        needToConfirm = true;
        iwetcBuilderElementUpdate({
            type: $(this).attr('data-type'),
            property: $(this).attr('data-property'),
            unit: ($(this).attr('data-unit')) ? $(this).attr('data-unit') : null,
            target: ($(this).attr('data-target')) ? $(this).attr('data-target') : null,
            value: ($(this).attr('type') == 'checkbox') ? $(this).prop('checked') : $(this).val()
        });
    });

    $(document).on('change', 'select.iwetc-builder-post-content-type', function () {
        needToConfirm = true;

        if ($(this).val() == 'none') {
            $('.iwetc-element-focus').find('p[data-name="post_content"]').hide();
        } else {
            $('.iwetc-element-focus').find('p[data-name="post_content"]').show();
        }
    });

    // change product component
    $(document).on('change', '.iwetc-builder-change-product-component', function () {
        needToConfirm = true;
        let element = $(this).closest('.iwetc-builder-left-sidebar-section-content');
        let productItem = $('.iwetc-element-focus').find('table td').first();

        iwetcBuilderElementUpdate({
            type: 'html',
            property: null,
            unit: null,
            target: null,
            value: iwetcGetProductComponentHtml({
                row: element.find('select[data-name="row"]').val(),
                column: element.find('select[data-name="column"]').val(),
                type: element.find('.iwetc-properties-product-type').val(),
                products: element.find('.iwetc-select2-products[data-property="data-products"]').val(),
                exclude_products: element.find('.iwetc-select2-products[data-property="data-exclude-products"]').val(),
                categories: element.find('.iwetc-select2-product-categories[data-property="data-categories"]').val(),
                exclude_categories: element.find('.iwetc-select2-product-categories[data-property="data-exclude-categories"]').val(),
                add_to_cart: $('.iwetc-builder-products-add-to-cart-in-url-input').prop('checked') == true ? 'true' : 'false',
            }, productItem)
        });
    });

    // change post component
    $(document).on('change', '.iwetc-builder-change-post-component', function () {
        needToConfirm = true;
        let element = $(this).closest('.iwetc-builder-left-sidebar-subsection');
        let postItem = $('.iwetc-element-focus').find('table td').first();
        iwetcBuilderElementUpdate({
            type: 'html',
            property: null,
            unit: null,
            target: null,
            value: iwetcGetPostComponentHtml(element.find('select[data-name="row"]').val(), element.find('select[data-name="column"]').val(), postItem)
        });
    });

    // change direction
    $(document).on('change', '.iwetc-change-direction', function () {
        needToConfirm = true;
        $('.iwetc-element-focus .iwetc-directional').attr('data-direction', $(this).find('option:selected').attr('data-direction')).change();
    });

    // change table direction
    $(document).on('change', '.iwetc-change-table-direction', function () {
        needToConfirm = true;
        let direction = $(this).find('option:selected').attr('value');
        let element = $('.iwetc-element-focus .iwetc-table-directional');
        let divider = element.find('tbody td[data-name="menu_bar_divider"]').last();
        let html = '';
        element.attr('data-direction', direction).change();

        if (direction == 'vertical') {
            element.find('td').each(function () {
                let dataId = ($(this).attr('data-id')) ? 'data-id="' + $(this).attr('data-id') + '"' : '';
                let dataName = ($(this).attr('data-name')) ? 'data-name="' + $(this).attr('data-name') + '"' : '';
                let style = ($(this).attr('style')) ? 'style="' + $(this).attr('style') + '"' : '';

                html += '<tr><td ' + dataId + ' ' + dataName + ' ' + style + '>' + $(this).html() + '</td></tr>'
            });
        } else {
            html = '<tr>';
            element.find('td').each(function () {
                let dataId = ($(this).attr('data-id')) ? 'data-id="' + $(this).attr('data-id') + '"' : '';
                let dataName = ($(this).attr('data-name')) ? 'data-name="' + $(this).attr('data-name') + '"' : '';
                let style = ($(this).attr('style')) ? 'style="' + $(this).attr('style') + '"' : '';

                html += '<td ' + dataId + ' ' + dataName + ' ' + style + '>' + $(this).html() + '</td>'
            });
            html += '</tr>';
        }

        element.find('tbody').html(html).ready(function () {
            if (direction == 'vertical') {
                element.find('tbody td[data-name="menu_bar_divider"]').css({
                    "border-left": "none",
                    "border-bottom": divider.css('border-left-width') + ' ' + divider.css('border-left-color') + ' ' + divider.css('border-left-style')
                })
            } else {
                element.find('tbody td[data-name="menu_bar_divider"]').css({
                    "border-bottom": "none",
                    "border-left": divider.css('border-bottom-width') + ' ' + divider.css('border-bottom-color') + ' ' + divider.css('border-bottom-style')
                })
            }
        });
    });

    // set active class for alignment buttons
    $(document).on('click', 'button[data-property="text-align"]', function () {
        needToConfirm = true;
        let section = $(this).closest('.iwetc-builder-left-sidebar-subsection');
        section.find('button[data-property="text-align"]').removeClass('active');
        $(this).addClass('active');
    })

    // wp media init
    $(document).on('click', '.iwetc-media-uploader button.iwetc-open-media', function (event) {
        let mediaUploader;
        let uploaderButton = $(this);
        event.preventDefault();

        if (mediaUploader) {
            mediaUploader.open();
            return;
        }

        mediaUploader = wp.media.frames.downloadable_file = wp.media({
            title: 'Choose an image',
            button: {
                text: 'Use image',
            },
            multiple: false
        });

        mediaUploader.on('select', function () {
            let attachment = mediaUploader.state().get("selection").toJSON();
            let value = (uploaderButton.attr('data-type') == 'style') ? 'url(' + attachment[0].url + ')' : attachment[0].url;

            if (uploaderButton.attr('data-target') && jQuery('.iwetc-element-focus').find(uploaderButton.attr('data-target')).length < 1) {
                if (uploaderButton.closest('.iwetc-contact-item-container').length > 0) {
                    let widthField = uploaderButton.closest('.iwetc-builder-left-sidebar-middle-content').find('input.iwetc-slider-number-input[data-property="width"][data-target="img"]');
                    let width = (widthField.length > 0) ? widthField.val() : 20;
                    jQuery('.iwetc-element-focus').find('span[data-name="contact_item_image_' + uploaderButton.attr('data-id') + '"]').html('<img style="width: ' + width + 'px; height: auto; float: left; margin-top: 5px;" src="">');
                }
            }

            iwetcBuilderElementUpdate({
                type: uploaderButton.attr('data-type'),
                property: (uploaderButton.attr('data-property')) ? uploaderButton.attr('data-property') : '',
                target: (uploaderButton.attr('data-target')) ? uploaderButton.attr('data-target') : '',
                unit: null,
                value: value
            });
        });

        mediaUploader.open();
    });

    // wp media init
    $(document).on('click', '.iwetc-media-button', function (event) {
        let mediaUploader;
        let uploaderButton = $(this);
        event.preventDefault();

        if (mediaUploader) {
            mediaUploader.open();
            return;
        }

        mediaUploader = wp.media.frames.downloadable_file = wp.media({
            title: 'Choose an image',
            button: {
                text: 'Use image',
            },
            multiple: false
        });

        mediaUploader.on('select', function () {
            let attachment = mediaUploader.state().get("selection").toJSON();
            if (uploaderButton.attr('data-url-target')) {
                $(uploaderButton.attr('data-url-target')).val(attachment[0].url);
            }
        });

        mediaUploader.open();
    });

    $(document).on('click', '.iwetc-media-clear', function (event) {
        needToConfirm = true;
        let uploaderElement = $(event.target).closest('.iwetc-media-uploader').find('.iwetc-open-media');
        iwetcBuilderElementUpdate({
            type: uploaderElement.attr('data-type'),
            property: uploaderElement.attr('data-property'),
            target: (uploaderElement.attr('data-target')) ? uploaderElement.attr('data-target') : '',
            unit: null,
            value: ''
        });
    });

    $(document).on('click', '#iwetc-builder-preview-desktop', function () {
        $('#iwetc-modal-email-preview .iwetc-email-wrapper').removeClass('iwetc-mobile');
        $('#iwetc-modal-email-preview .iwetc-email-wrapper').addClass('iwetc-desktop');
        let width = (jQuery('#iwetc-builder-width')) ? parseInt(jQuery('#iwetc-builder-width').val()) : '700';
        $('#iwetc-modal-email-preview .iwetc-email-wrapper').css({ width: width + 'px' });
    })

    $(document).on('click', '#iwetc-builder-preview-mobile', function () {
        $('#iwetc-modal-email-preview .iwetc-email-wrapper').addClass('iwetc-mobile');
        $('#iwetc-modal-email-preview .iwetc-email-wrapper').removeClass('iwetc-desktop');
        let width = (jQuery('#iwetc-builder-responsive-point')) ? parseInt(jQuery('#iwetc-builder-responsive-point').val()) : '360';
        $('#iwetc-modal-email-preview .iwetc-email-wrapper').css({ width: width + 'px' });
    });

    $(document).on('click', '#iwetc-builder-preview', function () {
        iwetcGetEmailPreview();
    });

    // change coupon type
    $(document).on('change', '.iwetc-builder-change-coupon-type', function () {
        needToConfirm = true;
        $('.iwetc-existing-coupon select').html('');
        if ($(this).val() == 'existing_coupon') {
            $('.iwetc-generate-coupon').hide();
            $('.iwetc-existing-coupon').show();
        } else {
            $('.iwetc-generate-coupon').show();
            $('.iwetc-existing-coupon').hide();
        }
    });

    $(document).on('change', '.iwetc-existing-coupon select', function () {
        needToConfirm = true;
        $('.iwetc-element-focus .iwetc-builder-content-target').attr('data-coupon-code', ($(this).val()));
    });

    $(document).on('click', '#publish', function (e) {
        needToConfirm = false;
        e.preventDefault();
        $('#iwetc-email-structure').val(JSON.stringify(iwetcGetEmailStructure())).ready(function () {
            $('#post').submit();
        });
    });

    $(document).on('click', '#iwetc-modal-send-email-button', function (e) {
        iwetcSendTestEmail();
    });

    $(document).on('change', '.iwetc-select2-products', function (e) {
        needToConfirm = true;
        let data = [];
        $.each($('.iwetc-select2-products option:selected'), function () {
            if (typeof IwetcBuilder.Products !== 'object' || Object.keys(IwetcBuilder.Products).length < 1) {
                IwetcBuilder.Products = {};
            }

            if ($(this).val()) {
                if (IwetcBuilder.Products[$(this).val()] == undefined) {
                    IwetcBuilder.Products[$(this).val()] = $(this).text();
                }

                data.push($(this).val());
            }
        });

        let productIds = data.filter(function (v, i, self) {
            return i == self.indexOf(v);
        });

        $('#iwetc-preload-products').val(productIds);
    });

    $(document).on('change', '.iwetc-select2-product-categories', function (e) {
        needToConfirm = true;
        let data = [];
        $.each($('.iwetc-select2-product-categories option:selected'), function () {
            if (typeof IwetcBuilder.ProductCategories !== 'object' || Object.keys(IwetcBuilder.ProductCategories).length < 1) {
                IwetcBuilder.ProductCategories = {};
            }

            if ($(this).val()) {
                if (IwetcBuilder.ProductCategories[$(this).val()] == undefined) {
                    IwetcBuilder.ProductCategories[$(this).val()] = $(this).text();
                }

                data.push($(this).val());
            }
        });

        let productCategoryIds = data.filter(function (v, i, self) {
            return i == self.indexOf(v);
        });

        $('#iwetc-preload-product-categories').val(productCategoryIds);
    });

    $(document).on('change', '.iwetc-select2-post-categories', function (e) {
        needToConfirm = true;
        let data = [];
        $.each($('.iwetc-select2-post-categories option:selected'), function () {
            if (typeof IwetcBuilder.PostCategories !== 'object' || Object.keys(IwetcBuilder.PostCategories).length < 1) {
                IwetcBuilder.PostCategories = {};
            }

            if ($(this).val()) {
                if (IwetcBuilder.PostCategories[$(this).val()] == undefined) {
                    IwetcBuilder.PostCategories[$(this).val()] = $(this).text();
                }

                data.push($(this).val());
            }
        });

        let postCategoryIds = data.filter(function (v, i, self) {
            return i == self.indexOf(v);
        });

        $('#iwetc-preload-post-categories').val(postCategoryIds);
    });

    $(document).on('change', '.iwetc-post-included', function (e) {
        needToConfirm = true;
        let data = [];
        $.each($('.iwetc-post-included option:selected'), function () {
            if (typeof IwetcBuilder.PostIncluded !== 'object' || Object.keys(IwetcBuilder.PostIncluded).length < 1) {
                IwetcBuilder.PostIncluded = {};
            }

            if ($(this).val()) {
                if (IwetcBuilder.PostIncluded[$(this).val()] == undefined) {
                    IwetcBuilder.PostIncluded[$(this).val()] = $(this).text();
                }

                data.push($(this).val());
            }
        });

        let postIds = data.filter(function (v, i, self) {
            return i == self.indexOf(v);
        });

        $('#iwetc-preload-post-included').val(postIds);
    });

    $(document).on('change', '.iwetc-post-excluded', function (e) {
        needToConfirm = true;
        let data = [];
        $.each($('.iwetc-post-excluded option:selected'), function () {
            if (typeof IwetcBuilder.PostExcluded !== 'object' || Object.keys(IwetcBuilder.PostExcluded).length < 1) {
                IwetcBuilder.PostExcluded = {};
            }

            if ($(this).val()) {
                if (IwetcBuilder.PostExcluded[$(this).val()] == undefined) {
                    IwetcBuilder.PostExcluded[$(this).val()] = $(this).text();
                }

                data.push($(this).val());
            }
        });

        let postIds = data.filter(function (v, i, self) {
            return i == self.indexOf(v);
        });

        $('#iwetc-preload-post-excluded').val(postIds);
    });

    $(document).on('click', '.iwetc-shortcode-button', function (e) {
        let position = $(this).offset();
        let shortcodeList = $('.iwetc-shortcode-list');

        let topPosition = parseInt(position.top) - parseInt($(window).scrollTop()) + 34;
        shortcodeList.attr('data-first-top', topPosition);
        shortcodeList.attr('data-target', $(this).attr('data-shortcode-id'));

        let submenuPosition = ($(this).attr('data-shortcode-position')) ? $(this).attr('data-shortcode-position') : 'left';
        if (submenuPosition == 'right') {
            $('.iwetc-shortcode-submenu').css({
                right: 'auto',
                left: '146px'
            })
        } else {
            $('.iwetc-shortcode-submenu').css({
                left: 'auto',
                right: '146px'
            })
        }

        shortcodeList.css({
            top: topPosition,
            left: parseInt(position.left) - 126
        });

        if (shortcodeList.css('display') == 'none') {
            shortcodeList.show();
        }
    });

    $(document).on('click', '.iwetc-shortcode-list .iwetc-shortcode-submenu li', function (e) {
        needToConfirm = true;
        let shortcodeId = $(this).closest('.iwetc-shortcode-list').attr('data-target');
        let targetElement = $('.iwetc-has-shortcode[data-shortcode-id="' + shortcodeId + '"]');
        if (targetElement.find('input').length > 0) {
            let oldValue = targetElement.find('input').val();
            targetElement.find('input').val(oldValue + $(this).attr('data-value')).trigger('input');
        }
    });

    $(document).on('click', '#iwetc-builder-body a', function (e) {
        e.preventDefault();
    })

    $(document).on('click', '#iwetc-left-sidebar-toggle', function (e) {
        if ($('body').hasClass('iwetc-builder-left-sidebar-hide')) {
            $('body').removeClass('iwetc-builder-left-sidebar-hide');
            $(this).removeClass('iwetc-left-sidebar-toggle-closed');
        } else {
            $('body').addClass('iwetc-builder-left-sidebar-hide');
            $(this).addClass('iwetc-left-sidebar-toggle-closed');
        }
    });

    $(document).on('change', '.iwetc-builder-change-wc-hook', function () {
        needToConfirm = true;
        $('.iwetc-element-focus').find('span[data-name="wc_hook"]').text($(this).val());
    });

    $(document).on('click', '#iwetc-menu-bar-add-item', function () {
        needToConfirm = true;
        iwetcMenuBarAddItem();
    });

    $(document).on('input', '.iwetc-menu-bar-item input.iwetc-builder-editor-input[data-type="text"]', function () {
        needToConfirm = true;
        let label = ($(this).val() != '') ? $(this).val() : 'Menu item';
        $(this).closest('.iwetc-menu-bar-item').find('strong[data-name="menu-bar-item-label"]').text(label);
    });

    $(document).on('click', '.iwetc-menu-bar-item .iwetc-menu-bar-item-title', function (e) {
        if ($(e.target).hasClass('dashicons-trash') == false && $(e.target).hasClass('iwetc-menu-bar-item-delete-button') == false) {
            $(this).toggleClass('collapsed');
            $(this).closest('.iwetc-menu-bar-item').find('.iwetc-menu-bar-item-fields').slideToggle();
        } else {
            let menuItem = $(this).closest('.iwetc-menu-bar-item');
            $('.iwetc-element-focus').find('td[data-name="menu_bar_item"][data-id="' + menuItem.attr('data-id') + '"]').remove();
            $('.iwetc-element-focus').find('td[data-name="menu_bar_divider"][data-id="' + menuItem.attr('data-id') + '"]').remove();
            menuItem.remove();

            if ($('.iwetc-element-focus').find('.iwetc-menu-bar-table td').length > 0) {
                let firstItem = $('.iwetc-element-focus').find('.iwetc-menu-bar-table td').first();
                if (firstItem.attr('data-name') == 'menu_bar_divider') {
                    firstItem.remove();
                }
            }
        }
    });

    $(document).on('click', '.iwetc-contact-item-container .iwetc-contact-item-title', function (e) {
        if ($(e.target).hasClass('dashicons-trash') == false && $(e.target).hasClass('iwetc-contact-item-delete-button') == false) {
            $(this).toggleClass('collapsed');
            $(this).closest('.iwetc-contact-item-container').find('.iwetc-contact-item-fields').slideToggle();
        } else {
            let contactItem = $(this).closest('.iwetc-contact-item-container');
            $('.iwetc-element-focus').find('.iwetc-contact-item[data-id="' + contactItem.attr('data-id') + '"]').remove();
            contactItem.remove();
        }
    });

    $(document).on('change', '.iwetc-menu-bar-divider-enable', function () {
        let divider = $('.iwetc-element-focus').find('td[data-name="menu_bar_divider"]');
        let dividerColor = $('div[data-name="menu_bar_divider_color"]');
        if ($(this).prop('checked') === true) {
            dividerColor.show();
            divider.show();
        } else {
            dividerColor.hide();
            divider.hide();
        }
    });

    $(document).on('click', '.iwetc-builder-change-size-unit', function () {
        $(this).closest('div').find('.iwetc-builder-change-size-unit').removeClass('active');
        $(this).addClass('active');

        let unit = $(this).val();
        let input = $(this).closest('div').find('input.iwetc-builder-editor-input[data-property="width"]');

        $('.iwetc-element-focus').find('.iwetc-resizable').attr('data-unit', unit)
        input.attr('data-unit', unit);

        if (unit == '%' && input.val() > 100) {
            input.val(100);
        }

        input.trigger('input');
    });

    $(document).on('click', '.iwetc-builder-change-post-image-size-unit', function () {
        $(this).closest('div').find('.iwetc-builder-change-post-image-size-unit').removeClass('active');
        $(this).addClass('active');

        let unit = $(this).val();
        let input = $(this).closest('div').find('input.iwetc-builder-editor-input[data-property="width"]');

        $('.iwetc-element-focus').find('img[data-name="post_image"]').attr('data-unit', unit)
        input.attr('data-unit', unit);

        if (unit == '%' && input.val() > 100) {
            input.val(100);
        }

        input.trigger('input');
    });

    $(document).on('change', '.iwetc-builder-products-add-to-cart-in-url-input', function () {
        needToConfirm = true;
        let addToCartButton = $('.iwetc-element-focus').find('.iwetc-add-to-cart-button');
        let AddToCartProperties = $('div[data-name="products_add_to_cart_properties"]');

        if ($(this).prop('checked') === true) {
            addToCartButton.css({ display: 'inline-block' });
            AddToCartProperties.show();
        } else {
            addToCartButton.hide();
            AddToCartProperties.hide();
        }

        iwetcColorPickerInit();
    });

    $(document).on('click', '#iwetc-contact-add-item', function () {
        needToConfirm = true;
        iwetcContactAddItem();
    });

    $(document).on('change', '.iwetc-builder-socials-style', function () {
        needToConfirm = true;
        $('.iwetc-element-focus').find('ul').toggleClass('iwetc-socials-style2');
    });

    $(document).on('change', '.iwetc-properties-auto-height-row', function () {
        needToConfirm = true;
        let heightInputElement = $(this).closest('.iwetc-builder-left-sidebar-section-content').find('.iwetc-properties-height');
        let heightInput = $(this).closest('.iwetc-builder-left-sidebar-section-content').find('.iwetc-properties-height-input');
        let activeRow = $('.iwetc-element-focus .iwetc-layout-content');
        if ($(this).prop('checked') === true) {
            activeRow.css({ height: 'auto' });
            activeRow.find('.iwetc-layout-column').css({ height: 'auto' });
            heightInputElement.hide();
        } else {
            activeRow.css({ height: heightInput.val() });
            heightInput.change();
            heightInputElement.show();
        }
    });

    $(document).on('change', '.iwetc-properties-auto-height-product-image', function () {
        needToConfirm = true;
        let heightInputElement = $(this).closest('.iwetc-builder-left-sidebar-section-content').find('.iwetc-properties-height');
        let heightInput = $(this).closest('.iwetc-builder-left-sidebar-section-content').find('.iwetc-properties-height input[data-property="height"]');
        let imageElement = $('.iwetc-element-focus img[data-name="product_image"]');

        if ($(this).prop('checked') === true) {
            imageElement.css({ height: 'auto' });
            heightInputElement.hide();
        } else {
            imageElement.css({ height: heightInput.val() });
            heightInputElement.show();
        }
    });

    $(document).on('input change', '.iwetc-properties-height-input', function () {
        needToConfirm = true;
        let rowElement = $('.iwetc-element-focus .iwetc-layout-content');
        let paddingSize = parseInt(rowElement.css('padding-top')) + parseInt(rowElement.css('padding-bottom'));
        let borderSize = parseInt(rowElement.css('border-top-width')) + parseInt(rowElement.css('border-bottom-width'));
        let columnNewHeight = parseInt($(this).val()) - (paddingSize + borderSize);

        rowElement.find('.iwetc-layout-column').css({ height: columnNewHeight });
    });

    $(document).on('click', '.iwetc-template-import', function () {
        let templateName = $(this).val();
        let templateCategory = $(this).closest('.iwetc-saved-template-item').attr('data-category');
        if (IwetcBuilder.SampleTemplates[templateCategory][templateName] && IwetcBuilder.SampleTemplates[templateCategory][templateName].structure) {
            iwetcImportTemplate(IwetcBuilder.SampleTemplates[templateCategory][templateName].structure);
            if (templateCategory != 'custom_templates') {
                $('#iwetc-builder-email-type').attr('data-first-load', 'true');
                $('#iwetc-builder-email-type').val(templateCategory).change();
            }
            swal('Imported', "", "success");
        } else {
            swal('Error', "", "warning");
        }

        $('#iwetc-builder-email-type').attr('data-first-load', 'false');
    });

    $(document).on('keypress', 'input[type="number"]', function (e) {
        needToConfirm = true;
        if (e.which != 8 && isNaN(String.fromCharCode(e.which)) && e.keyCode != 45) {
            e.preventDefault();
        }
    });

    $(document).on('change', '.iwetc-constrain-proportion', function (e) {
        if ($(this).prop('checked') == true) {
            $(this).closest('label').addClass('iwetc-proportion-enable').find('i').replaceWith(IwetcBuilder.linkIcon);
        } else {
            $(this).closest('label').removeClass('iwetc-proportion-enable').find('i').replaceWith(IwetcBuilder.unlinkIcon);
        }
    });

    $(document).on('input', '.iwetc-has-proportion', function (e) {
        if ($(this).closest('.iwetc-constrain-proportion-container').find('.iwetc-constrain-proportion').prop('checked') == true) {
            let inputs = $(this).closest('.iwetc-constrain-proportion-container').find('.iwetc-builder-editor-input');
            let value = $(this).val();
            if (inputs.length > 0) {
                $.each(inputs, function () {
                    if ($(this).val() != value) {
                        $(this).val(value).trigger('input');
                    }
                });
            }
        }
    });

    $(document).on('change', '.iwetc-properties-product-type', function (e) {
        needToConfirm = true;
        let customQueryFields = $('.iwetc-properties-product-type-custom-query-fields');
        if ($(this).val() == 'custom_query') {
            customQueryFields.show();
        } else {
            customQueryFields.find('select').val('').change();
            customQueryFields.hide();
        }
    });

    $(document).on('input change', '.iwetc-properties-column-width-input', function () {
        $('.iwetc-element-focus').closest('.iwetc-layout-column-wrap').css({ width: $(this).val() + '%' });

        let activeRow = $('.iwetc-element-focus').closest('.iwetc-layout-draggable');
        iwetcUpdateColumnsDistance(activeRow.find('.iwetc-layout-content').attr('data-distance'), activeRow.attr('data-columns'), activeRow.find('.iwetc-layout-column-wrap'));
    });

    $(document).on('click', '.iwetc-content-edit-handler', function (e) {
        $(this).closest('.iwetc-content-element').trigger('click');
    });

    $(document).on('input change', '.iwetc-properties-horizontal-column-distance-input', function () {
        $(this).closest('div').find('.iwetc-slider-number-preview').text($(this).val());
        iwetcUpdateColumnsDistance($(this).val(), $('.iwetc-element-focus').attr('data-columns'), $('.iwetc-element-focus').find('.iwetc-layout-column-wrap'));
    });

    $(document).on('input change', '.iwetc-slider-number-input', function () {
        $(this).closest('div').find('.iwetc-slider-number-preview').text($(this).val());
    });

    $(document).on('click', '#iwetc-saved-templates-button', function () {
        $('#iwetc-saved-template').val('all').change();
    });

    $(document).on('change', '#iwetc-saved-template', function () {
        if ($(this).val() == 'all') {
            $('#iwetc-saved-templates-list .iwetc-saved-template-item').show();
        } else {
            $('#iwetc-saved-templates-list .iwetc-saved-template-item').hide();
            $('#iwetc-saved-templates-list .iwetc-saved-template-item[data-category="' + $(this).val() + '"]').show();
        }
    });

    $(document).on('change', '#iwetc-direction', function () {
        $('.iwetc-email-body').css({
            direction: $(this).val()
        });
    });

    $(document).on('click', '.iwetc-insert-template-toggle-button', function () {
        $('.iwetc-insert-template-container').slideToggle(250);
    });

    $('#titlewrap').addClass('iwetc-has-shortcode').attr('data-shortcode-id', 'email_subject').attr('data-shortcode-position', 'left');
    iwetcBuilderReInit();
    IwetcBuilder.SetPostData();

    // unbind beforeunload
    $('form#post').on('submit', function () {
        needToConfirm = false;
        $(window).unbind('beforeunload');
    });

    window.onbeforeunload = function (event) {
        if (needToConfirm) {
            return 'Leaving so soon? Your data will be lost if you continue.';
        }
    };
})