"use strict"

function getFontWeightOptions(selected = '400') {
    let output = '<option value="400" ';
    output += (selected == '400') ? 'selected' : '';
    output += '>400</option><option value="500" ';
    output += (selected == '500') ? 'selected' : '';
    output += '>500</option><option value="600" ';
    output += (selected == '600') ? 'selected' : '';
    output += '>600</option><option value="700" ';
    output += (selected == '700') ? 'selected' : '';
    output += '>700</option><option value="800" ';
    output += (selected == '800') ? 'selected' : '';
    output += '>800</option><option value="900" ';
    output += (selected == '900') ? 'selected' : '';
    output += '>900</option>';
    return output;
}

// add properties
IwetcBuilder.Property.addProperty({
    name: 'column_editor',
    label: IwetcBuilder.Translate.columns,
    getHtml: function (element) {
        let columns;
        if (element.hasClass('iwetc-layout-draggable')) {
            columns = (element.attr('data-element-name')) ? element.attr('data-element-name') : '';
        } else {
            columns = (element.closest('.iwetc-layout-draggable').attr('data-element-name')) ? element.closest('.iwetc-layout-draggable').attr('data-element-name') : '';
        }

        let output = '<select class="iwetc-builder-col-12 iwetc-builder-editor-input" data-type="change_columns"><option value="one_column" ';
        output += (columns == 'one_column') ? 'selected' : '';
        output += '>1 Column</option>';
        output += '<option value="two_columns" ';
        output += (columns == 'two_columns') ? 'selected' : '';
        output += '>2 Columns</option>';
        output += '<option value="three_columns" ';
        output += (columns == 'three_columns') ? 'selected' : '';
        output += '>3 Columns</option>';
        output += '<option value="four_columns" ';
        output += (columns == 'four_columns') ? 'selected' : '';
        output += '>4 Columns</option>';
        output += '</select>';
        return output;
    }
});
IwetcBuilder.Property.addProperty({
    name: 'column_width',
    label: IwetcBuilder.Translate.width + ' (%)',
    getHtml: function (element) {
        let width = element.attr('data-width');
        return '<div class="iwetc-builder-col-12">' +
            '<input type="range" min="0" max="100" class="iwetc-builder-editor-input iwetc-properties-column-width-input iwetc-slider-number-input" value="' + width + '" data-type="attribute" data-property="data-width">' +
            '<span class="iwetc-slider-number-preview">' + width + '</span>' +
            '</div>';
    }
});
IwetcBuilder.Property.addProperty({
    name: 'horizontal_column_distance',
    label: IwetcBuilder.Translate.distance + ' (px)',
    getHtml: function (element) {
        let distance = element.attr('data-distance');
        return '<div class="iwetc-builder-col-12">' +
            '<input type="range" min="0" max="100" class="iwetc-builder-editor-input iwetc-properties-horizontal-column-distance-input iwetc-slider-number-input" value="' + distance + '" data-type="attribute" data-property="data-distance">' +
            '<span class="iwetc-slider-number-preview">' + distance + '</span>' +
            '</div>';
    }
});
IwetcBuilder.Property.addProperty({
    name: 'text_editor',
    label: IwetcBuilder.Translate.text_editor,
    getHtml: function (element) {
        setTimeout(function () {
            iwetcTinyMceSetContent('iwetc-text-editor', element.html());
        }, 350);
        return '<textarea id="iwetc-text-editor" class="iwetc-builder-editor-input"></textarea>';
    }
});
IwetcBuilder.Property.addProperty({
    name: 'textarea',
    label: IwetcBuilder.Translate.html_editor,
    getHtml: function (element) {
        return '<textarea id="iwetc-html-editor" rows="10" class="iwetc-builder-editor-input">' + jQuery.iwetcNl2br(element.html()) + '</textarea>';
    }
});
IwetcBuilder.Property.addProperty({
    name: 'custom_class',
    label: IwetcBuilder.Translate.custom_class,
    getHtml: function (element) {
        let customClass = (element.attr('data-custom-class')) ? element.attr('data-custom-class') : '';
        return '<input type="text" class="iwetc-builder-editor-input" value="' + customClass + '" placeholder="Class name ..." data-type="attribute" data-property="data-custom-class">';
    }
});
IwetcBuilder.Property.addProperty({
    name: 'image',
    label: IwetcBuilder.Translate.image,
    getHtml: function (element) {
        let url = (element.find('a').attr('href')) ? element.find('a').attr('href') : '';
        let alt = element.find('img').attr('alt');
        let target = element.find('a').attr('target');
        let output = '<div class="iwetc-media-uploader"><button type="button" class="iwetc-open-media" data-type="attribute" data-property="src" data-target="[data-name=\'image\']">Select</button></div>' +
            '<div class="iwetc-builder-left-sidebar-subsection">' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Url</label>' +
            '<input type="text" class="iwetc-builder-editor-input" placeholder="Url ..." value="' + url + '" data-type="attribute" data-property="href" data-target="[data-name=\'url\']">' +
            '</div>' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Target</label>' +
            '<select class="iwetc-builder-editor-input" data-type="attribute" data-property="target" data-target="[data-name=\'url\']">' +
            '<option value="_blank" ';
        output += (target == '_blank') ? 'selected' : '';
        output += '>_blank</option><option value="_self" ';
        output += (target == '_self') ? 'selected' : '';
        output += '>_self</option><option value="_parent" ';
        output += (target == '_parent') ? 'selected' : '';
        output += '>_parent</option><option value="_top" ';
        output += (target == '_top') ? 'selected' : '';
        output += '>_top</option>' +
            '</select>' +
            '</div>' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Alt</label>' +
            '<input type="text" class="iwetc-builder-editor-input" placeholder="Alt ..." value="' + alt + '" data-type="attribute" data-property="alt" data-target="[data-name=\'image\']">' +
            '</div>' +
            '</div>';

        return output;
    }
});
IwetcBuilder.Property.addProperty({
    name: 'background',
    label: IwetcBuilder.Translate.background,
    getHtml: function (element) {
        let output = '<div class="iwetc-builder-left-sidebar-subsection">' +
            '<div class="iwetc-builder-col-6">' +
            '<label>Image</label>' +
            '<div class="iwetc-media-uploader with-clear-button">' +
            '<button type="button" class="iwetc-open-media" data-type="style" data-property="background-image">Select</button>' +
            '</div>' +
            '</div>' +
            '<div class="iwetc-builder-col-6">' +
            '<label>Color</label>' +
            '<input type="text" class="iwetc-color-picker" value="' + element.css('background-color') + '" data-type="style" data-property="background-color">' +
            '</div>' +
            '</div>';

        return output;
    }
});
IwetcBuilder.Property.addProperty({
    name: 'text_color',
    label: IwetcBuilder.Translate.text_color,
    getHtml: function (element) {
        return '<div class="iwetc-builder-col-6"><input type="text" class="iwetc-color-picker" data-type="style" data-property="color" value="' + element.css('color') + '"></div>';
    }
});
IwetcBuilder.Property.addProperty({
    name: 'height',
    label: IwetcBuilder.Translate.height,
    getHtml: function (element) {
        let height = (element.attr('style').indexOf('height: auto;') == -1) ? parseInt(element.css('height')) : 'auto';
        let output = '<div class="iwetc-builder-col-12">' +
            '<label>Enable auto height</label><input type="checkbox" class="iwetc-properties-auto-height-row iwetc-builder-properties-right-checkbox" ';
        output += (height == 'auto') ? 'checked="checked"' : '';
        output += '></div><div class="iwetc-builder-col-12 iwetc-properties-height" ';
        output += (height == 'auto') ? 'style="display: none;"' : 'style="display: block;"';
        output += '><label>Height</label><input type="number" min="1" class="iwetc-builder-editor-input iwetc-properties-height-input" data-type="style" data-property="height" value="' + parseInt(element.css('height')) + '" ';
        output += ' data-unit="px"></div>';
        return output;
    }
});
IwetcBuilder.Property.addProperty({
    name: 'line_height',
    label: IwetcBuilder.Translate.line_height,
    getHtml: function (element) {
        let lineHeight = (element.css('line-height')) ? parseInt(element.css('line-height')) : 26;
        let output = '<input type="number" min="0" value="' + lineHeight + '" class="iwetc-builder-col-12 iwetc-builder-editor-input" placeholder="28" data-type="style" data-property="line-height" data-unit="px">';
        return output;
    }
});
IwetcBuilder.Property.addProperty({
    name: 'alignment',
    label: IwetcBuilder.Translate.alignment,
    getHtml: function (element) {
        if (!element.hasClass('iwetc-element-content')) {
            element = element.closest('.iwetc-element-content');
        }
        let alignment = (jQuery.inArray(element.css('text-align'), ['left', 'right', 'center']) !== -1) ? element.css('text-align') : 'left';
        let output = '<div class="iwetc-builder-left-sidebar-subsection"><button type="button" class="iwetc-builder-editor-input ';
        output += (alignment == 'left') ? 'active' : '';
        output += '" value="left" data-type="style" data-property="text-align"><i class="dashicons dashicons-editor-alignleft"></i></button>';
        output += '<button type="button" class="iwetc-builder-editor-input ';
        output += (alignment == 'center') ? 'active' : '';
        output += '" value="center" data-type="style" data-property="text-align"><i class="dashicons dashicons-editor-aligncenter"></i></button>';
        output += '<button type="button" class="iwetc-builder-editor-input ';
        output += (alignment == 'right') ? 'active' : '';
        output += '" value="right" data-type="style" data-property="text-align"><i class="dashicons dashicons-editor-alignright"></i></button></div>';
        return output;
    }
});
IwetcBuilder.Property.addProperty({
    name: 'direction',
    label: IwetcBuilder.Translate.direction,
    getHtml: function (element) {
        let horizontalType = (element.find('.iwetc-directional').attr('data-horizontal-type')) ? element.find('.iwetc-directional').attr('data-horizontal-type') : 'flex';
        let direction = element.find('.iwetc-directional').attr('data-direction');
        let target = (horizontalType == 'flex') ? '.iwetc-directional' : '.iwetc-directional li';
        let output = '<div class="iwetc-builder-left-sidebar-subsection"><select class="iwetc-builder-editor-input iwetc-change-direction" data-type="style" data-property="display" data-target="' + target + '"><option value="' + horizontalType + '" ';
        output += (direction == 'horizontal') ? 'selected' : '';
        output += ' data-direction="horizontal">Horizontal</option><option value="block" ';
        output += (direction == 'vertical') ? 'selected' : '';
        output += ' data-direction="vertical">Vertical</option></select></div>';
        return output;
    }
});
IwetcBuilder.Property.addProperty({
    name: 'table_direction',
    label: IwetcBuilder.Translate.direction,
    getHtml: function (element) {
        let direction = element.find('.iwetc-table-directional').attr('data-direction');
        let output = '<div class="iwetc-builder-left-sidebar-subsection"><select class="iwetc-change-table-direction"><option value="horizontal" ';
        output += (direction == 'horizontal') ? 'selected' : '';
        output += '>Horizontal</option><option value="vertical" ';
        output += (direction == 'vertical') ? 'selected' : '';
        output += '>Vertical</option></select></div>';
        return output;
    }
});
IwetcBuilder.Property.addProperty({
    name: 'double_alignment',
    label: IwetcBuilder.Translate.alignment,
    getHtml: function (element) {
        let leftElement = element.find('.iwetc-left-alignmentable');
        let rightElement = element.find('.iwetc-right-alignmentable');

        let leftAlignment = (jQuery.inArray(leftElement.css('text-align'), ['left', 'right', 'center']) !== -1) ? leftElement.css('text-align') : 'left';
        let rightAlignment = (jQuery.inArray(rightElement.css('text-align'), ['left', 'right', 'center']) !== -1) ? rightElement.css('text-align') : 'right';

        let output = '<div class="iwetc-builder-left-sidebar-subsection"><div class="iwetc-builder-col-12"><div><label>Left</label></div>';
        output += '<button type="button" class="iwetc-builder-editor-input ';
        output += (leftAlignment == 'left') ? 'active' : '';
        output += '" value="left" data-type="style" data-property="text-align" data-target=".iwetc-left-alignmentable"><i class="dashicons dashicons-editor-alignleft"></i></button>';
        output += '<button type="button" class="iwetc-builder-editor-input ';
        output += (leftAlignment == 'center') ? 'active' : '';
        output += '" value="center" data-type="style" data-property="text-align" data-target=".iwetc-left-alignmentable"><i class="dashicons dashicons-editor-aligncenter"></i></button>';
        output += '<button type="button" class="iwetc-builder-editor-input ';
        output += (leftAlignment == 'right') ? 'active' : '';
        output += '" value="right" data-type="style" data-property="text-align" data-target=".iwetc-left-alignmentable"><i class="dashicons dashicons-editor-alignright"></i></button>';
        output += '</div></div>';
        output += '<div class="iwetc-builder-left-sidebar-subsection"><div class="iwetc-builder-col-12"><div><label>Right</label></div>';
        output += '<button type="button" class="iwetc-builder-editor-input ';
        output += (rightAlignment == 'left') ? 'active' : '';
        output += '" value="left" data-type="style" data-property="text-align" data-target=".iwetc-right-alignmentable"><i class="dashicons dashicons-editor-alignleft"></i></button>';
        output += '<button type="button" class="iwetc-builder-editor-input ';
        output += (rightAlignment == 'center') ? 'active' : '';
        output += '" value="center" data-type="style" data-property="text-align" data-target=".iwetc-right-alignmentable"><i class="dashicons dashicons-editor-aligncenter"></i></button>';
        output += '<button type="button" class="iwetc-builder-editor-input ';
        output += (rightAlignment == 'right') ? 'active' : '';
        output += '" value="right" data-type="style" data-property="text-align" data-target=".iwetc-right-alignmentable"><i class="dashicons dashicons-editor-alignright"></i></button>';
        output += '</div></div>';
        return output;
    }
});
IwetcBuilder.Property.addProperty({
    name: 'size',
    label: IwetcBuilder.Translate.size,
    getHtml: function (element) {
        let width, unit;

        if (element.hasClass('iwetc-resizable')) {
            unit = (element.attr('data-unit')) ? element.attr('data-unit') : 'px';
            width = (unit == '%') ? Math.round((parseInt(element.css('width')) / parseInt(element.closest('div').css('width'))) * 100).toFixed(0) : parseInt(element.css('width'));
            element.css({ width: element.css('width') });
        } else {
            let target = element.find('.iwetc-resizable');
            unit = (target.first().attr('data-unit')) ? target.first().attr('data-unit') : 'px';
            width = (unit == '%') ? Math.round((parseInt(target.first().css('width')) / parseInt(element.closest('div').css('width'))) * 100).toFixed(0) : parseInt(target.first().css('width'));
            target.css({ width: target.first().css('width') });
        }

        let output = '<div class="iwetc-builder-col-12"><label for="">Width' +
            '<button type="button" class="iwetc-builder-change-size-unit ';
        output += (unit == 'px') ? 'active' : '';
        output += '" value="px">px</button>' +
            '<button type="button" class="iwetc-builder-change-size-unit ';
        output += (unit == '%') ? 'active' : '';
        output += '" value="%">%</button>' +
            '</label>' +
            '<input type="number" min="0" value="' + width + '" placeholder="150" class="iwetc-builder-editor-input" data-type="style" data-target=".iwetc-resizable" data-property="width" data-unit="' + unit + '">' +
            '</div>';

        return output;
    }
});
IwetcBuilder.Property.addProperty({
    name: 'font',
    label: IwetcBuilder.Translate.font,
    getHtml: function (element) {
        let fontSize = (element.css('font-size')) ? parseInt(element.css('font-size')) : 14;
        let fontWeight = (element.css('font-weight')) ? parseInt(element.css('font-weight')) : 400;
        return '<div class="iwetc-builder-left-sidebar-subsection">' +
            '<div class="iwetc-builder-col-6">' +
            '<label for="">Font size (px)</label>' +
            '<input type="number" min="0" value="' + fontSize + '" placeholder="100" class="iwetc-builder-editor-input" data-type="style" data-property="font-size" data-unit="px">' +
            '</div>' +
            '<div class="iwetc-builder-col-6">' +
            '<label for="">Font weight</label>' +
            '<select class="iwetc-builder-editor-input" data-type="style" data-property="font-weight">' +
            getFontWeightOptions(fontWeight) +
            '</select>' +
            '</div>' +
            '</div>';
    }
});
IwetcBuilder.Property.addProperty({
    name: 'text',
    label: IwetcBuilder.Translate.text,
    getHtml: function (element) {
        return '<div class="iwetc-builder-col-12">' +
            '<div class="iwetc-has-shortcode" data-shortcode-id="text" data-shortcode-position="right">' +
            '<input type="text" value="' + element.text() + '" placeholder="Text ..." class="iwetc-builder-editor-input" data-type="text">' +
            '</div>' +
            '</div>';
    }
});
IwetcBuilder.Property.addProperty({
    name: 'link',
    label: IwetcBuilder.Translate.link,
    getHtml: function (element) {
        let target = element.attr('target');
        let output = '<div class="iwetc-builder-col-12">' +
            '<div class="iwetc-has-shortcode" data-shortcode-id="link" data-shortcode-position="right">' +
            '<input type="text" value="' + element.attr('href') + '" placeholder="Link ..." class="iwetc-builder-editor-input" data-type="attribute" data-property="href">' +
            '</div>' +
            '</div>' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Target</label>' +
            '<select class="iwetc-builder-editor-input" data-type="attribute" data-property="target">' +
            '<option value="_blank" ';
        output += (target == '_blank') ? 'selected' : '';
        output += '>_blank</option><option value="_self" ';
        output += (target == '_self') ? 'selected' : '';
        output += '>_self</option><option value="_parent" ';
        output += (target == '_parent') ? 'selected' : '';
        output += '>_parent</option><option value="_top" ';
        output += (target == '_top') ? 'selected' : '';
        output += '>_top</option>' +
            '</select>' +
            '</div>';

        return output;
    }
});
IwetcBuilder.Property.addProperty({
    name: 'padding',
    label: IwetcBuilder.Translate.padding,
    getHtml: function (element) {
        let proportion = element.attr('data-padding-proportion');
        let proportionChecked = '',
            proportionClassName = '',
            proportionIcon = IwetcBuilder.unlinkIcon;

        if (typeof proportion === 'undefined' || proportion == 'true') {
            proportionChecked = 'checked="checked"';
            proportionClassName = 'iwetc-proportion-enable';
            proportionIcon = IwetcBuilder.linkIcon;
        }

        let paddingTop = (element.css('padding-top')) ? parseInt(element.css('padding-top')) : 0;
        let paddingRight = (element.css('padding-right')) ? parseInt(element.css('padding-right')) : 0;
        let paddingBottom = (element.css('padding-bottom')) ? parseInt(element.css('padding-bottom')) : 0;
        let paddingLeft = (element.css('padding-left')) ? parseInt(element.css('padding-left')) : 0;

        let output = '<div class="iwetc-constrain-proportion-container">' +
            '<div class="iwetc-builder-col-2-5">' +
            '<label>Top</label>' +
            '<input type="number" min="0" value="' + paddingTop + '" placeholder="10" class="iwetc-builder-editor-input iwetc-has-proportion" data-type="style" data-property="padding-top" data-unit="px">' +
            '</div>' +
            '<div class="iwetc-builder-col-2-5">' +
            '<label>Right</label>' +
            '<input type="number" min="0" value="' + paddingRight + '" placeholder="10" class="iwetc-builder-editor-input iwetc-has-proportion" data-type="style" data-property="padding-right" data-unit="px">' +
            '</div>' +
            '<div class="iwetc-builder-col-2-5">' +
            '<label>Bottom</label>' +
            '<input type="number" min="0" value="' + paddingBottom + '" placeholder="10" class="iwetc-builder-editor-input iwetc-has-proportion" data-type="style" data-property="padding-bottom" data-unit="px">' +
            '</div>' +
            '<div class="iwetc-builder-col-2-5">' +
            '<label>Left</label>' +
            '<input type="number" min="0" value="' + paddingLeft + '" placeholder="10" class="iwetc-builder-editor-input iwetc-has-proportion" data-type="style" data-property="padding-left" data-unit="px">' +
            '</div>' +
            '<div class="iwetc-constrain-proportion-field">' +
            '<label class="';
        output += proportionClassName;
        output += '"><strong></strong><span>' + proportionIcon +
            '<input type="checkbox" class="iwetc-constrain-proportion iwetc-builder-editor-input" data-type="attribute" data-property="data-padding-proportion" ';
        output += proportionChecked;
        output += '></span></label>' +
            '</div>' +
            '</div>';

        return output;
    }
});
IwetcBuilder.Property.addProperty({
    name: 'margin',
    label: IwetcBuilder.Translate.margin,
    getHtml: function (element) {
        let proportion = element.attr('data-margin-proportion');
        let proportionChecked = '',
            proportionClassName = '',
            proportionIcon = IwetcBuilder.unlinkIcon;

        if (typeof proportion === 'undefined' || proportion == 'true') {
            proportionChecked = 'checked="checked"';
            proportionClassName = 'iwetc-proportion-enable';
            proportionIcon = IwetcBuilder.linkIcon;
        }

        let marginTop = (element.css('margin-top')) ? parseInt(element.css('margin-top')) : 0;
        let marginRight = (element.css('margin-right')) ? parseInt(element.css('margin-right')) : 0;
        let marginBottom = (element.css('margin-bottom')) ? parseInt(element.css('margin-bottom')) : 0;
        let marginLeft = (element.css('margin-left')) ? parseInt(element.css('margin-left')) : 0;

        let output = '<div class="iwetc-constrain-proportion-container">' +
            '<div class="iwetc-builder-col-2-5">' +
            '<label>Top</label>' +
            '<input type="number" min="-1000" value="' + marginTop + '" placeholder="10" class="iwetc-builder-editor-input iwetc-has-proportion" data-type="style" data-property="margin-top" data-unit="px">' +
            '</div>' +
            '<div class="iwetc-builder-col-2-5">' +
            '<label>Right</label>' +
            '<input type="number" min="-1000" value="' + marginRight + '" placeholder="10" class="iwetc-builder-editor-input iwetc-has-proportion" data-type="style" data-property="margin-right" data-unit="px">' +
            '</div>' +
            '<div class="iwetc-builder-col-2-5">' +
            '<label>Bottom</label>' +
            '<input type="number" min="-1000" value="' + marginBottom + '" placeholder="10" class="iwetc-builder-editor-input iwetc-has-proportion" data-type="style" data-property="margin-bottom" data-unit="px">' +
            '</div>' +
            '<div class="iwetc-builder-col-2-5">' +
            '<label>Left</label>' +
            '<input type="number" min="-1000" value="' + marginLeft + '" placeholder="10" class="iwetc-builder-editor-input iwetc-has-proportion" data-type="style" data-property="margin-left" data-unit="px">' +
            '</div>' +
            '<div class="iwetc-constrain-proportion-field">' +
            '<label class="';
        output += proportionClassName;
        output += '"><strong></strong><span>' + proportionIcon +
            '<input type="checkbox" class="iwetc-constrain-proportion iwetc-builder-editor-input" data-type="attribute" data-property="data-margin-proportion" ';
        output += proportionChecked;
        output += '></span></label>' +
            '</div>' +
            '</div>';

        return output;
    }
});
IwetcBuilder.Property.addProperty({
    name: 'border',
    label: IwetcBuilder.Translate.border,
    getHtml: function (element) {
        let borderColor = (element.css('border-top-color')) ? element.css('border-top-color') : '';
        let borderStyle = (element.css('border-top-style')) ? element.css('border-top-style') : '';

        let borderWidthProportion = element.attr('data-border-width-proportion');
        let borderWidthProportionChecked = '',
            borderWidthProportionClassName = '',
            borderWidthProportionIcon = IwetcBuilder.unlinkIcon;

        if (typeof borderWidthProportion === 'undefined' || borderWidthProportion == 'true') {
            borderWidthProportionChecked = 'checked="checked"';
            borderWidthProportionClassName = 'iwetc-proportion-enable';
            borderWidthProportionIcon = IwetcBuilder.linkIcon;
        }

        let borderRadiusProportion = element.attr('data-border-radius-proportion');
        let borderRadiusProportionChecked = '',
            borderRadiusProportionClassName = '',
            borderRadiusProportionIcon = IwetcBuilder.unlinkIcon;

        if (typeof borderRadiusProportion === 'undefined' || borderRadiusProportion == 'true') {
            borderRadiusProportionChecked = 'checked="checked"';
            borderRadiusProportionClassName = 'iwetc-proportion-enable';
            borderRadiusProportionIcon = IwetcBuilder.linkIcon;
        }

        let borderTopWidth = (element.css('border-top-width')) ? parseInt(element.css('border-top-width')) : 0;
        let borderRightWidth = (element.css('border-right-width')) ? parseInt(element.css('border-right-width')) : 0;
        let borderBottomWidth = (element.css('border-bottom-width')) ? parseInt(element.css('border-bottom-width')) : 0;
        let borderLeftWidth = (element.css('border-left-width')) ? parseInt(element.css('border-left-width')) : 0;

        let borderTopLeftRadius = (element.css('border-top-left-radius')) ? parseInt(element.css('border-top-left-radius')) : 0;
        let borderTopRightRadius = (element.css('border-top-right-radius')) ? parseInt(element.css('border-top-right-radius')) : 0;
        let borderBottomLeftRadius = (element.css('border-bottom-left-radius')) ? parseInt(element.css('border-bottom-left-radius')) : 0;
        let borderBottomRightRadius = (element.css('border-bottom-right-radius')) ? parseInt(element.css('border-bottom-right-radius')) : 0;

        let output = '<div class="iwetc-builder-left-sidebar-subsection">' +
            '<div class="iwetc-builder-col-6">' +
            '<label>Color</label>' +
            '<input type="text" class="iwetc-color-picker" data-type="style" data-property="border-color" value="' + borderColor + '">' +
            '</div>' +
            '<div class="iwetc-builder-col-6">' +
            '<label>Style</label>' +
            '<select name="" id="" class="iwetc-builder-editor-input" data-type="style" data-property="border-style">';
        output += '<option value="solid" ';
        output += (borderStyle && borderStyle == 'solid') ? 'selected' : '';
        output += '>Solid</option>';
        output += '<option value="dotted" ';
        output += (borderStyle && borderStyle == 'dotted') ? 'selected' : '';
        output += '>Dotted</option>';
        output += '<option value="dashed" ';
        output += (borderStyle && borderStyle == 'dashed') ? 'selected' : '';
        output += '>Dashed</option>';
        output += '</select>' +
            '</div>' +
            '</div>' +
            '<div class="iwetc-builder-left-sidebar-subsection iwetc-constrain-proportion-container">' +
            '<div class="iwetc-builder-left-sidebar-subsection-title">' +
            '<span>Width</span>' +
            '</div>' +
            '<div class="iwetc-builder-col-2-5">' +
            '<label>Top</label>' +
            '<input type="number" min="0" value="' + borderTopWidth + '" placeholder="0" class="iwetc-builder-editor-input iwetc-has-proportion" data-type="style" data-property="border-top-width" data-unit="px">' +
            '</div>' +
            '<div class="iwetc-builder-col-2-5">' +
            '<label>Right</label>' +
            '<input type="number" min="0" value="' + borderRightWidth + '" placeholder="0" class="iwetc-builder-editor-input iwetc-has-proportion" data-type="style" data-property="border-right-width" data-unit="px">' +
            '</div>' +
            '<div class="iwetc-builder-col-2-5">' +
            '<label>Bottom</label>' +
            '<input type="number" min="0" value="' + borderBottomWidth + '" placeholder="0" class="iwetc-builder-editor-input iwetc-has-proportion" data-type="style" data-property="border-bottom-width" data-unit="px">' +
            '</div>' +
            '<div class="iwetc-builder-col-2-5">' +
            '<label>Left</label>' +
            '<input type="number" min="0" value="' + borderLeftWidth + '" placeholder="0" class="iwetc-builder-editor-input iwetc-has-proportion" data-type="style" data-property="border-left-width" data-unit="px">' +
            '</div>' +
            '<div class="iwetc-constrain-proportion-field">' +
            '<label class="';
        output += borderWidthProportionClassName;
        output += '"><strong></strong><span>' + borderWidthProportionIcon +
            '<input type="checkbox" class="iwetc-constrain-proportion iwetc-builder-editor-input" data-type="attribute" data-property="data-border-width-proportion" ';
        output += borderWidthProportionChecked;
        output += '></span></label>' +
            '</div>' +

            '</div>' +
            '<div class="iwetc-builder-left-sidebar-subsection iwetc-constrain-proportion-container">' +
            '<div class="iwetc-builder-left-sidebar-subsection-title">' +
            '<span>Radius</span>' +
            '</div>' +
            '<div class="iwetc-builder-col-2-5">' +
            '<label>T-L</label>' +
            '<input type="number" min="0" value="' + borderTopLeftRadius + '" placeholder="0" class="iwetc-builder-editor-input iwetc-has-proportion" data-type="style" data-property="border-top-left-radius" data-unit="px">' +
            '</div>' +
            '<div class="iwetc-builder-col-2-5">' +
            '<label>T-R</label>' +
            '<input type="number" min="0" value="' + borderTopRightRadius + '" placeholder="0" class="iwetc-builder-editor-input iwetc-has-proportion" data-type="style" data-property="border-top-right-radius" data-unit="px">' +
            '</div>' +
            '<div class="iwetc-builder-col-2-5">' +
            '<label>B-R</label>' +
            '<input type="number" min="0" value="' + borderBottomRightRadius + '" placeholder="0" class="iwetc-builder-editor-input iwetc-has-proportion" data-type="style" data-property="border-bottom-right-radius" data-unit="px">' +
            '</div>' +
            '<div class="iwetc-builder-col-2-5">' +
            '<label>B-L</label>' +
            '<input type="number" min="0" value="' + borderBottomLeftRadius + '" placeholder="0" class="iwetc-builder-editor-input iwetc-has-proportion" data-type="style" data-property="border-bottom-left-radius" data-unit="px">' +
            '</div>' +
            '<div class="iwetc-constrain-proportion-field">' +
            '<label class="';
        output += borderRadiusProportionClassName;
        output += '"><strong></strong><span>' + borderRadiusProportionIcon +
            '<input type="checkbox" class="iwetc-constrain-proportion iwetc-builder-editor-input" data-type="attribute" data-property="data-border-radius-proportion" ';
        output += borderRadiusProportionChecked;
        output += '></span></label>' +
            '</div>' +
            '</div>';

        return output;
    }
});
IwetcBuilder.Property.addProperty({
    name: 'divider_border',
    label: IwetcBuilder.Translate.border,
    getHtml: function (element) {
        let borderColor = (element.find('hr').css('border-top-color')) ? element.find('hr').css('border-top-color') : 'transparent';
        let borderWidth = (element.find('hr').css('border-top-width')) ? parseInt(element.find('hr').css('border-top-width')) : '';
        let borderStyle = (element.find('hr').css('border-top-style')) ? element.find('hr').css('border-top-style') : '';

        let output = '<div class="iwetc-builder-left-sidebar-subsection">' +
            '<div class="iwetc-builder-col-6">' +
            '<label>Color</label>' +
            '<input type="text" class="iwetc-color-picker" data-type="style" data-property="border-top-color" value="' + borderColor + '" data-target="hr">' +
            '</div>' +
            '<div class="iwetc-builder-col-6">' +
            '<label>Height</label>' +
            '<input type="number" min="0" value="' + borderWidth + '" placeholder="0" class="iwetc-builder-editor-input" data-type="style" data-property="border-top-width" data-unit="px" data-target="hr">' +
            '</div>' +
            '<div class="iwetc-builder-col-6">' +
            '<label>Style</label>' +
            '<select class="iwetc-builder-editor-input" data-type="style" data-property="border-style" data-target="hr">';
        output += '<option value="solid" ';
        output += (borderStyle && borderStyle == 'solid') ? 'selected' : '';
        output += '>Solid</option>';
        output += '<option value="dotted" ';
        output += (borderStyle && borderStyle == 'dotted') ? 'selected' : '';
        output += '>Dotted</option>';
        output += '<option value="dashed" ';
        output += (borderStyle && borderStyle == 'dashed') ? 'selected' : '';
        output += '>Dashed</option>';
        output += '</select>' +
            '</div>' +
            '</div>';

        return output;
    }
});
IwetcBuilder.Property.addProperty({
    name: 'spacer_height',
    label: IwetcBuilder.Translate.height,
    getHtml: function (element) {
        let height = (element.find('.iwetc-spacer')) ? parseInt(element.find('.iwetc-spacer').css('height')) : 25;
        let output = '<div class="iwetc-builder-col-12">' +
            '<label>Height</label>' +
            '<input type="number" min="0" class="iwetc-builder-editor-input" data-type="style" data-property="height" value="' + height + '" data-target=".iwetc-spacer">' +
            '</div>';
        return output;
    }
});
IwetcBuilder.Property.addProperty({
    name: 'button_text',
    label: IwetcBuilder.Translate.text,
    getHtml: function (element) {
        let fontSize = (element.css('font-size')) ? parseInt(element.css('font-size')) : 14;
        let fontWeight = (element.css('font-weight')) ? parseInt(element.css('font-weight')) : 400;
        let lineHeight = (element.css('line-height')) ? parseInt(element.css('line-height')) : 26;

        return '<div class="iwetc-builder-left-sidebar-subsection">' +
            '<div class="iwetc-builder-col-6">' +
            '<label for="">Font size (px)</label>' +
            '<input type="number" min="0" value="' + fontSize + '" placeholder="100" class="iwetc-builder-editor-input" data-type="style" data-property="font-size" data-unit="px">' +
            '</div>' +
            '<div class="iwetc-builder-col-6">' +
            '<label for="">Font weight</label>' +
            '<select class="iwetc-builder-editor-input" data-type="style" data-property="font-weight">' +
            getFontWeightOptions(fontWeight) +
            '</select>' +
            '</div>' +
            '<div class="iwetc-builder-col-6">' +
            '<label for="">Line height (px)</label>' +
            '<input type="number" min="0" value="' + lineHeight + '" class="iwetc-builder-editor-input" placeholder="28" data-type="style" data-property="line-height" data-unit="px">' +
            '</div>' +
            '<div class="iwetc-builder-col-6">' +
            '<label for="">Color</label>' +
            '<input type="text" class="iwetc-color-picker" data-type="style" data-property="color" value="' + element.css('color') + '">' +
            '</div>' +
            '</div>';
    }
});
IwetcBuilder.Property.addProperty({
    name: 'order_details_template',
    label: IwetcBuilder.Translate.template,
    getHtml: function (element) {
        let template = element.find('.iwetc-has-template').attr('data-template');
        let output = '<select class="iwetc-builder-col-12 iwetc-builder-editor-input" data-type="order_details_template"><option value="default" ';
        output += (template == 'default') ? 'selected' : '';
        output += '>Default</option>';
        output += '<option value="vertical_text" ';
        output += (template == 'vertical_text') ? 'selected' : '';
        output += '>Vertical text</option>';
        output += '<option value="horizontal_text" ';
        output += (template == 'horizontal_text') ? 'selected' : '';
        output += '>Horizontal text</option>';
        output += '</select>';
        return output;
    }
});
IwetcBuilder.Property.addProperty({
    name: 'order_details_default_translate',
    label: IwetcBuilder.Translate.translate,
    getHtml: function (element) {
        return '<div class="iwetc-builder-left-sidebar-subsection">' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Product</label>' +
            '<input type="text" value="' + element.find('.iwetc-text-translatable[data-name="order_details_product_text"]').text() + '" placeholder="Product ..." class="iwetc-builder-editor-input" data-type="translate" data-property="order_details_product_text">' +
            '</div>' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Quantity</label>' +
            '<input type="text" value="' + element.find('.iwetc-text-translatable[data-name="order_details_quantity_text"]').text() + '" placeholder="Quantity ..." class="iwetc-builder-editor-input" data-type="translate" data-property="order_details_quantity_text">' +
            '</div>' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Price</label>' +
            '<input type="text" value="' + element.find('.iwetc-text-translatable[data-name="order_details_price_text"]').text() + '" placeholder="Price ..." class="iwetc-builder-editor-input" data-type="translate" data-property="order_details_price_text">' +
            '</div>' +
            '</div>';
    }
});
IwetcBuilder.Property.addProperty({
    name: 'order_details_custom_translate',
    label: IwetcBuilder.Translate.translate,
    getHtml: function (element) {
        return '<div class="iwetc-builder-left-sidebar-subsection">' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Quantity</label>' +
            '<input type="text" value="' + element.find('.iwetc-text-translatable[data-name="order_details_quantity_text"]').first().text() + '" placeholder="Quantity ..." class="iwetc-builder-editor-input" data-type="translate" data-property="order_details_quantity_text">' +
            '</div>' +
            '</div>';
    }
});
IwetcBuilder.Property.addProperty({
    name: 'order_details_show_sku',
    label: IwetcBuilder.Translate.show_sku,
    getHtml: function (element) {
        let checked = (element.find('[data-name="order_details_product_name"]').hasClass('iwetc-has-sku') === true) ? 'checked="checked"' : '';
        return '<label for="iwetc-builder-show-sku">Enable</label>' +
            '<input type="checkbox" value="yes" class="iwetc-builder-properties-right-checkbox iwetc-builder-editor-input" data-type="order_details_show_sku" data-property="order_details_product" id="iwetc-builder-show-sku" ' + checked + '>';
    }
});
IwetcBuilder.Property.addProperty({
    name: 'order_details_product_name',
    label: IwetcBuilder.Translate.product_name,
    getHtml: function (element) {
        let fontSize = 13,
            fontWeight = 400,
            textColor = '#3e3e3e',
            lineHeight = 25;

        if (element.find('[data-name="order_details_product_name"]').length > 0) {
            fontSize = parseInt(element.find('[data-name="order_details_product_name"]').first().css('font-size'));
            fontWeight = parseInt(element.find('[data-name="order_details_product_name"]').first().css('font-weight'));
            textColor = element.find('[data-name="order_details_product_name"]').first().css('color');
            lineHeight = parseInt(element.find('[data-name="order_details_product_name"]').first().css('line-height'));
        }

        return '<div class="iwetc-builder-left-sidebar-subsection">' +
            '<div class="iwetc-builder-col-6">' +
            '<label>Font size</label>' +
            '<input type="number" min="1" value="' + fontSize + '" placeholder="12 ..." class="iwetc-builder-editor-input" data-type="style" data-property="font-size" data-target="[data-name=\'order_details_product_name\']" data-unit="px">' +
            '</div>' +
            '<div class="iwetc-builder-col-6">' +
            '<label>Font weight</label>' +
            '<select class="iwetc-builder-editor-input" data-type="style" data-property="font-weight" data-target="[data-name=\'order_details_product_name\']">' +
            getFontWeightOptions(fontWeight) +
            '</select>' +
            '</div>' +
            '<div class="iwetc-builder-col-6">' +
            '<label>Text color</label>' +
            '<input type="text" value="' + textColor + '" class="iwetc-color-picker" data-type="style" data-property="color" data-target="[data-name=\'order_details_product_name\']">' +
            '</div>' +
            '<div class="iwetc-builder-col-6">' +
            '<label>Line height</label>' +
            '<input type="number" min="0" value="' + lineHeight + '" placeholder="25 ..." class="iwetc-builder-editor-input" data-type="style" data-property="line-height" data-target="[data-name=\'order_details_product_name\']" data-unit="px">' +
            '</div>' +
            '</div>';
    }
});
IwetcBuilder.Property.addProperty({
    name: 'font_full',
    label: IwetcBuilder.Translate.font,
    getHtml: function (element) {
        let fontSize = (element.css('font-size')) ? parseInt(element.css('font-size')) : 13,
            fontWeight = (element.css('font-weight')) ? parseInt(element.css('font-weight')) : 400,
            textColor = (element.css('color')) ? element.css('color') : '#3e3e3e',
            lineHeight = (element.css('line-height')) ? parseInt(element.css('line-height')) : 18;

        return '<div class="iwetc-builder-left-sidebar-subsection">' +
            '<div class="iwetc-builder-col-6">' +
            '<label>Font size</label>' +
            '<input type="number" min="1" value="' + fontSize + '" placeholder="12 ..." class="iwetc-builder-editor-input" data-type="style" data-property="font-size" data-unit="px">' +
            '</div>' +
            '<div class="iwetc-builder-col-6">' +
            '<label>Font weight</label>' +
            '<select class="iwetc-builder-editor-input" data-type="style" data-property="font-weight">' +
            getFontWeightOptions(fontWeight) +
            '</select>' +
            '</div>' +
            '<div class="iwetc-builder-col-6">' +
            '<label>Text color</label>' +
            '<input type="text" value="' + textColor + '" class="iwetc-color-picker" data-type="style" data-property="color">' +
            '</div>' +
            '<div class="iwetc-builder-col-6">' +
            '<label>Line height</label>' +
            '<input type="number" min="0" value="' + lineHeight + '" placeholder="25 ..." class="iwetc-builder-editor-input" data-type="style" data-property="line-height" data-unit="px">' +
            '</div>' +
            '</div>';
    }
});
IwetcBuilder.Property.addProperty({
    name: 'order_details_price',
    label: IwetcBuilder.Translate.price,
    getHtml: function (element) {
        let fontSize = 13,
            fontWeight = 400,
            textColor = '#3e3e3e',
            lineHeight = 25;

        if (element.find('[data-name="order_details_price"]').length > 0) {
            fontSize = parseInt(element.find('[data-name="order_details_price"]').first().css('font-size'));
            fontWeight = parseInt(element.find('[data-name="order_details_price"]').first().css('font-weight'));
            textColor = element.find('[data-name="order_details_price"]').first().css('color');
            lineHeight = parseInt(element.find('[data-name="order_details_price"]').first().css('line-height'));
        }

        return '<div class="iwetc-builder-left-sidebar-subsection">' +
            '<div class="iwetc-builder-col-6">' +
            '<label>Font size</label>' +
            '<input type="number" min="0" value="' + fontSize + '" placeholder="12 ..." class="iwetc-builder-editor-input" data-type="style" data-property="font-size" data-target="[data-name=\'order_details_price\']" data-unit="px">' +
            '</div>' +
            '<div class="iwetc-builder-col-6">' +
            '<label>Font weight</label>' +
            '<select class="iwetc-builder-editor-input" data-type="style" data-property="font-weight" data-target="[data-name=\'order_details_price\']">' +
            getFontWeightOptions(fontWeight) +
            '</select>' +
            '</div>' +
            '<div class="iwetc-builder-col-6">' +
            '<label>Text color</label>' +
            '<input type="text" value="' + textColor + '" class="iwetc-color-picker" data-type="style" data-property="color" data-target="[data-name=\'order_details_price\']">' +
            '</div>' +
            '<div class="iwetc-builder-col-6">' +
            '<label>Line height</label>' +
            '<input type="number" min="0" value="' + lineHeight + '" placeholder="25 ..." class="iwetc-builder-editor-input" data-type="style" data-property="line-height" data-target="[data-name=\'order_details_price\']" data-unit="px">' +
            '</div>' +
            '</div>';
    }
});
IwetcBuilder.Property.addProperty({
    name: 'order_details_quantity',
    label: IwetcBuilder.Translate.quantity,
    getHtml: function (element) {
        let fontSize = 13,
            fontWeight = 400,
            textColor = '#3e3e3e',
            lineHeight = 25;

        if (element.find('[data-name="order_details_quantity"]').length > 0) {
            fontSize = parseInt(element.find('[data-name="order_details_quantity"]').first().css('font-size'));
            fontWeight = parseInt(element.find('[data-name="order_details_quantity"]').first().css('font-weight'));
            textColor = element.find('[data-name="order_details_quantity"]').first().css('color');
            lineHeight = parseInt(element.find('[data-name="order_details_quantity"]').first().css('line-height'));
        }

        return '<div class="iwetc-builder-left-sidebar-subsection">' +
            '<div class="iwetc-builder-col-6">' +
            '<label>Font size</label>' +
            '<input type="number" min="0" value="' + fontSize + '" placeholder="12 ..." class="iwetc-builder-editor-input" data-type="style" data-property="font-size" data-target="[data-name=\'order_details_quantity\']" data-unit="px">' +
            '</div>' +
            '<div class="iwetc-builder-col-6">' +
            '<label>Font weight</label>' +
            '<select class="iwetc-builder-editor-input" data-type="style" data-property="font-weight" data-target="[data-name=\'order_details_quantity\']">' +
            getFontWeightOptions(fontWeight) +
            '</select>' +
            '</div>' +
            '<div class="iwetc-builder-col-6">' +
            '<label>Text color</label>' +
            '<input type="text" value="' + textColor + '" class="iwetc-color-picker" data-type="style" data-property="color" data-target="[data-name=\'order_details_quantity\']">' +
            '</div>' +
            '<div class="iwetc-builder-col-6">' +
            '<label>Line height</label>' +
            '<input type="number" min="0" value="' + lineHeight + '" placeholder="25 ..." class="iwetc-builder-editor-input" data-type="style" data-property="line-height" data-target="[data-name=\'order_details_quantity\']" data-unit="px">' +
            '</div>' +
            '</div>';
    }
});
IwetcBuilder.Property.addProperty({
    name: 'items_distance',
    label: IwetcBuilder.Translate.items_distance,
    getHtml: function (element) {
        let vertical = (element.find('[data-name="items_distance_vertical"]').length > 0) ? parseInt(element.find('[data-name="items_distance_vertical"]').css('padding-bottom')) : 10;
        let horizontal = (element.find('[data-name="items_distance_horizontal"]').length > 0) ? parseInt(element.find('[data-name="items_distance_horizontal"]').css('padding-left')) : 10;

        return '<div class="iwetc-builder-left-sidebar-subsection">' +
            '<div class="iwetc-builder-col-6">' +
            '<label>Horizontal</label>' +
            '<input type="number" min="0" value="' + horizontal + '" class="iwetc-builder-editor-input" data-type="items_distance_horizontal">' +
            '</div>' +
            '<div class="iwetc-builder-col-6">' +
            '<label>Vertical</label>' +
            '<input type="number" min="0" value="' + vertical + '" class="iwetc-builder-editor-input" data-type="items_distance_vertical">' +
            '</div>' +
            '</div>';
    }
});
IwetcBuilder.Property.addProperty({
    name: 'subtotal_translate',
    label: IwetcBuilder.Translate.translate,
    getHtml: function (element) {
        return '<div class="iwetc-builder-left-sidebar-subsection">' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Subtotal</label>' +
            '<input type="text" value="' + element.find('.iwetc-text-translatable[data-name="order_subtotal_subtotal_text"]').text() + '" placeholder="Subtotal ..." class="iwetc-builder-editor-input" data-type="translate" data-property="order_subtotal_subtotal_text">' +
            '</div>' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Discount</label>' +
            '<input type="text" value="' + element.find('.iwetc-text-translatable[data-name="order_subtotal_discount_text"]').text() + '" placeholder="Discount ..." class="iwetc-builder-editor-input" data-type="translate" data-property="order_subtotal_discount_text">' +
            '</div>' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Shipping</label>' +
            '<input type="text" value="' + element.find('.iwetc-text-translatable[data-name="order_subtotal_shipping_text"]').text() + '" placeholder="Shipping ..." class="iwetc-builder-editor-input" data-type="translate" data-property="order_subtotal_shipping_text">' +
            '</div>' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Order fully refunded</label>' +
            '<input type="text" value="' + element.find('.iwetc-text-translatable[data-name="order_subtotal_order_fully_refunded_text"]').text() + '" placeholder="Order fully refunded ..." class="iwetc-builder-editor-input" data-type="translate" data-property="order_subtotal_order_fully_refunded_text">' +
            '</div>' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Refunded</label>' +
            '<input type="text" value="' + element.find('.iwetc-text-translatable[data-name="order_subtotal_refunded_text"]').text() + '" placeholder="Refunded ..." class="iwetc-builder-editor-input" data-type="translate" data-property="order_subtotal_refunded_text">' +
            '</div>' +
            '</div>';
    }
});
IwetcBuilder.Property.addProperty({
    name: 'order_total_translate',
    label: IwetcBuilder.Translate.translate,
    getHtml: function (element) {
        return '<div class="iwetc-builder-left-sidebar-subsection">' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Order total</label>' +
            '<input type="text" value="' + element.find('.iwetc-text-translatable[data-name="order_total_text"]').text() + '" placeholder="Order total ..." class="iwetc-builder-editor-input" data-type="translate" data-property="order_total_text">' +
            '</div>' +
            '</div>';
    }
});
IwetcBuilder.Property.addProperty({
    name: 'shipping_method_translate',
    label: IwetcBuilder.Translate.translate,
    getHtml: function (element) {
        return '<div class="iwetc-builder-left-sidebar-subsection">' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Shipping method</label>' +
            '<input type="text" value="' + element.find('.iwetc-text-translatable[data-name="shipping_method_text"]').text() + '" placeholder="Shipping method ..." class="iwetc-builder-editor-input" data-type="translate" data-property="shipping_method_text">' +
            '</div>' +
            '</div>';
    }
});
IwetcBuilder.Property.addProperty({
    name: 'payment_method_translate',
    label: IwetcBuilder.Translate.translate,
    getHtml: function (element) {
        return '<div class="iwetc-builder-left-sidebar-subsection">' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Payment method</label>' +
            '<input type="text" value="' + element.find('.iwetc-text-translatable[data-name="payment_method_text"]').text() + '" placeholder="Payment method ..." class="iwetc-builder-editor-input" data-type="translate" data-property="payment_method_text">' +
            '</div>' +
            '</div>';
    }
});
IwetcBuilder.Property.addProperty({
    name: 'customer_note_translate',
    label: IwetcBuilder.Translate.translate,
    getHtml: function (element) {
        return '<div class="iwetc-builder-left-sidebar-subsection">' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Customer note</label>' +
            '<input type="text" value="' + element.find('.iwetc-text-translatable[data-name="customer_note_text"]').text() + '" placeholder="Customer note ..." class="iwetc-builder-editor-input" data-type="translate" data-property="customer_note_text">' +
            '</div>' +
            '</div>';
    }
});
IwetcBuilder.Property.addProperty({
    name: 'product_type',
    label: IwetcBuilder.Translate.product_type,
    getHtml: function (element) {
        let row = element.find('table').attr('data-row');
        let column = element.find('table').attr('data-column');
        let productType = element.find('.iwetc-has-type').attr('data-type');
        let productIds = element.find('.iwetc-has-type').attr('data-products').split(',');
        let excludeProductIds = element.find('.iwetc-has-type').attr('data-exclude-products').split(',');
        let categoryIds = element.find('.iwetc-has-type').attr('data-categories').split(',');
        let excludeCategoryIds = element.find('.iwetc-has-type').attr('data-exclude-categories').split(',');

        let output = '<div class="iwetc-builder-left-sidebar-subsection">' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Type</label>' +
            '<select class="iwetc-builder-editor-input iwetc-properties-product-type" data-type="attribute" data-property="data-type" data-target=".iwetc-has-type">' +
            '<optgroup label="Based order">' +
            '<option value="related" ';
        output += (productType == 'related') ? 'selected' : '';
        output += '>Related</option><option value="category" ';
        output += (productType == 'category') ? 'selected' : '';
        output += '>Category</option><option value="up_sell" ';
        output += (productType == 'up_sell') ? 'selected' : '';
        output += '>Up sell</option><option value="cross_sell" ';
        output += (productType == 'cross_sell') ? 'selected' : '';
        output += '>Cross sell</option></optgroup>' +
            '<optgroup label="Custom"><option value="newest" ';
        output += (productType == 'newest') ? 'selected' : '';
        output += '>Newest</option><option value="on_sale" ';
        output += (productType == 'on_sale') ? 'selected' : '';
        output += '>On sale</option><option value="featured" ';
        output += (productType == 'featured') ? 'selected' : '';
        output += '>Featured</option><option value="best_seller" ';
        output += (productType == 'best_seller') ? 'selected' : '';
        output += '>Best seller</option><option value="best_rated" ';
        output += (productType == 'best_rated') ? 'selected' : '';
        output += '>Best rated</option><option value="custom_query" ';
        output += (productType == 'custom_query') ? 'selected' : '';
        output += '>Custom query</option></optgroup>' +
            '</select></div></div>' +
            '<div class="iwetc-builder-left-sidebar-subsection iwetc-properties-product-type-custom-query-fields" style="display: ';
        output += (productType == 'custom_query') ? 'block' : 'none';
        output += '">' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Products</label>' +
            '<select class="iwetc-select2-products iwetc-builder-editor-input" style="width: 100%;" data-type="attribute" data-property="data-products" data-target=".iwetc-has-type" multiple>';
        if (jQuery.isArray(productIds) && productIds.length > 0) {
            jQuery.each(productIds, function (i, productId) {
                if (productId) {
                    output += '<option value="' + parseInt(productId) + '" selected>' + IwetcBuilder.Products[productId] + '</option>';
                }
            });
        }
        output += '</select>' +
            '</div>' +

            '<div class="iwetc-builder-col-12">' +
            '<label>Exclude products</label>' +
            '<select class="iwetc-select2-products iwetc-builder-editor-input" style="width: 100%;" data-type="attribute" data-property="data-exclude-products" data-target=".iwetc-has-type" multiple>';
        if (jQuery.isArray(excludeProductIds) && excludeProductIds.length > 0) {
            jQuery.each(excludeProductIds, function (i, productId) {
                if (productId) {
                    output += '<option value="' + parseInt(productId) + '" selected>' + IwetcBuilder.Products[productId] + '</option>';
                }
            });
        }
        output += '</select>' +
            '</div>' +

            '<div class="iwetc-builder-col-12">' +
            '<label>Categories</label>' +
            '<select class="iwetc-select2-product-categories iwetc-builder-editor-input" style="width: 100%;" data-type="attribute" data-property="data-categories" data-target=".iwetc-has-type" multiple>';
        if (jQuery.isArray(categoryIds) && categoryIds.length > 0) {
            jQuery.each(categoryIds, function (i, categoryId) {
                if (categoryId) {
                    output += '<option value="' + parseInt(categoryId) + '" selected>' + IwetcBuilder.ProductCategories[categoryId] + '</option>';
                }
            });
        }
        output += '</select>' +
            '</div>' +

            '<div class="iwetc-builder-col-12">' +
            '<label>Exclude categories</label>' +
            '<select class="iwetc-select2-product-categories iwetc-builder-editor-input" style="width: 100%;" data-type="attribute" data-property="data-exclude-categories" data-target=".iwetc-has-type" multiple>';
        if (jQuery.isArray(excludeCategoryIds) && excludeCategoryIds.length > 0) {
            jQuery.each(excludeCategoryIds, function (i, categoryId) {
                if (categoryId) {
                    output += '<option value="' + parseInt(categoryId) + '" selected>' + IwetcBuilder.ProductCategories[categoryId] + '</option>';
                }
            });
        }

        output += '</select>' +
            '</div>' +
            '</div>' +
            '<div class="iwetc-builder-left-sidebar-subsection"><div class="iwetc-builder-col-6"><label>Max row</label>' +
            '<select class="iwetc-builder-change-product-component" data-name="row"><option value="1" ';
        output += (row == 1) ? 'selected' : '';
        output += '>1</option><option value="2" ';
        output += (row == 2) ? 'selected' : '';
        output += '>2</option><option value="3" ';
        output += (row == 3) ? 'selected' : '';
        output += '>3</option><option value="4" ';
        output += (row == 4) ? 'selected' : '';
        output += '>4</option></select>';
        output += '</div>' +
            '<div class="iwetc-builder-col-6">' +
            '<label>Column</label>' +
            '<select class="iwetc-builder-change-product-component" data-name="column"><option value="1" ';
        output += (column == 1) ? 'selected' : '';
        output += '>1</option><option value="2" ';
        output += (column == 2) ? 'selected' : '';
        output += '>2</option><option value="3" ';
        output += (column == 3) ? 'selected' : '';
        output += '>3</option><option value="4" ';
        output += (column == 4) ? 'selected' : '';
        output += '>4</option></select></div></div>';

        return output;
    }
});
IwetcBuilder.Property.addProperty({
    name: 'products_add_to_cart_in_url',
    label: IwetcBuilder.Translate.product_add_to_cart_in_url,
    getHtml: function (element) {
        let addToCart = element.find('.iwetc-has-add-to-cart').attr('data-add-to-cart');
        let addToCartButton = element.find('.iwetc-add-to-cart-button');
        let buttonText = (addToCartButton.first().text()) ? addToCartButton.first().text() : 'Add to cart';
        let buttonTextColor = (addToCartButton.first().css('color')) ? addToCartButton.first().css('color') : '#fff';
        let buttonBackgroundColor = (addToCartButton.first().text()) ? addToCartButton.first().text() : '#3e3e3e';
        let paddingTop = (addToCartButton.first().css('padding-top')) ? parseInt(addToCartButton.first().css('padding-top')) : 0;
        let paddingRight = (addToCartButton.first().css('padding-right')) ? parseInt(addToCartButton.first().css('padding-right')) : 0;
        let paddingBottom = (addToCartButton.first().css('padding-bottom')) ? parseInt(addToCartButton.first().css('padding-bottom')) : 0;
        let paddingLeft = (addToCartButton.first().css('padding-left')) ? parseInt(addToCartButton.first().css('padding-left')) : 0;
        let marginTop = (addToCartButton.first().css('margin-top')) ? parseInt(addToCartButton.first().css('margin-top')) : 0;
        let marginRight = (addToCartButton.first().css('margin-right')) ? parseInt(addToCartButton.first().css('margin-right')) : 0;
        let marginBottom = (addToCartButton.first().css('margin-bottom')) ? parseInt(addToCartButton.first().css('margin-bottom')) : 0;
        let marginLeft = (addToCartButton.first().css('margin-left')) ? parseInt(addToCartButton.first().css('margin-left')) : 0;
        let borderTopLeftRadius = (addToCartButton.first().css('border-top-left-radius')) ? parseInt(addToCartButton.first().css('border-top-left-radius')) : 0;
        let borderTopRightRadius = (addToCartButton.first().css('border-top-right-radius')) ? parseInt(addToCartButton.first().css('border-top-right-radius')) : 0;
        let borderBottomLeftRadius = (addToCartButton.first().css('border-bottom-left-radius')) ? parseInt(addToCartButton.first().css('border-bottom-left-radius')) : 0;
        let borderBottomRightRadius = (addToCartButton.first().css('border-bottom-right-radius')) ? parseInt(addToCartButton.first().css('border-bottom-right-radius')) : 0;
        let productAddToCartPropertiesDisplay = (addToCart == 'true') ? 'block' : 'none';

        let paddingProportion = element.attr('data-padding-button-proportion');
        let paddingProportionChecked = '',
            paddingProportionClassName = '',
            paddingProportionIcon = IwetcBuilder.unlinkIcon;

        if (typeof paddingProportion === 'undefined' || paddingProportion == 'true') {
            paddingProportionChecked = 'checked="checked"';
            paddingProportionClassName = 'iwetc-proportion-enable';
            paddingProportionIcon = IwetcBuilder.linkIcon;
        }

        let marginProportion = element.attr('data-margin-proportion');
        let marginProportionChecked = '',
            marginProportionClassName = '',
            marginProportionIcon = IwetcBuilder.unlinkIcon;

        if (typeof marginProportion === 'undefined' || marginProportion == 'true') {
            marginProportionChecked = 'checked="checked"';
            marginProportionClassName = 'iwetc-proportion-enable';
            marginProportionIcon = IwetcBuilder.linkIcon;
        }

        let borderRadiusProportion = element.attr('data-border-radius-proportion');
        let borderRadiusProportionChecked = '',
            borderRadiusProportionClassName = '',
            borderRadiusProportionIcon = IwetcBuilder.unlinkIcon;

        if (typeof borderRadiusProportion === 'undefined' || borderRadiusProportion == 'true') {
            borderRadiusProportionChecked = 'checked="checked"';
            borderRadiusProportionClassName = 'iwetc-proportion-enable';
            borderRadiusProportionIcon = IwetcBuilder.linkIcon;
        }

        let output = '<div class="iwetc-builder-left-sidebar-subsection">' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Enable</label>' +
            '<input type="checkbox" class="iwetc-builder-properties-right-checkbox iwetc-builder-editor-input iwetc-builder-products-add-to-cart-in-url-input" data-type="attribute" data-property="data-add-to-cart" data-target=".iwetc-has-add-to-cart" ';
        output += (addToCart == 'true') ? 'checked="checked"' : '';
        output += '>' +
            '</div>' +
            '<div data-name="products_add_to_cart_properties" style="display: ' + productAddToCartPropertiesDisplay + '">' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Text</label>' +
            '<input type="text" value="' + buttonText + '" placeholder="Text ..." class="iwetc-builder-editor-input" data-type="text" data-target=".iwetc-add-to-cart-button">' +
            '</div>' +
            '<div class="iwetc-builder-col-6">' +
            '<label>Text Color</label>' +
            '<input type="text" class="iwetc-color-picker" value="' + buttonTextColor + '" data-type="style" data-property="color" data-target=".iwetc-add-to-cart-button">' +
            '</div>' +
            '<div class="iwetc-builder-col-6">' +
            '<label>Background Color</label>' +
            '<input type="text" class="iwetc-color-picker" value="' + buttonBackgroundColor + '" data-type="style" data-property="background-color" data-target=".iwetc-add-to-cart-button">' +
            '</div>' +

            '<div class="iwetc-constrain-proportion-container">' +
            '<div class="iwetc-builder-col-12" style="margin-bottom: 0;">' +
            '<label><strong>Padding</strong></label>' +
            '</div>' +
            '<div class="iwetc-builder-col-2-5" style="margin-top: 0;">' +
            '<label>Top</label>' +
            '<input type="number" min="0" value="' + paddingTop + '" placeholder="10" class="iwetc-builder-editor-input iwetc-has-proportion" data-type="style" data-property="padding-top" data-target=".iwetc-add-to-cart-button" data-unit="px">' +
            '</div>' +
            '<div class="iwetc-builder-col-2-5" style="margin-top: 0;">' +
            '<label>Right</label>' +
            '<input type="number" min="0" value="' + paddingRight + '" placeholder="10" class="iwetc-builder-editor-input iwetc-has-proportion" data-type="style" data-property="padding-right" data-target=".iwetc-add-to-cart-button" data-unit="px">' +
            '</div>' +
            '<div class="iwetc-builder-col-2-5" style="margin-top: 0;">' +
            '<label>Bottom</label>' +
            '<input type="number" min="0" value="' + paddingBottom + '" placeholder="10" class="iwetc-builder-editor-input iwetc-has-proportion" data-type="style" data-property="padding-bottom" data-target=".iwetc-add-to-cart-button" data-unit="px">' +
            '</div>' +
            '<div class="iwetc-builder-col-2-5" style="margin-top: 0;">' +
            '<label>Left</label>' +
            '<input type="number" min="0" value="' + paddingLeft + '" placeholder="10" class="iwetc-builder-editor-input iwetc-has-proportion" data-type="style" data-property="padding-left" data-target=".iwetc-add-to-cart-button" data-unit="px">' +
            '</div>' +
            '<div class="iwetc-constrain-proportion-field">' +
            '<label class="';
        output += paddingProportionClassName;
        output += '"><strong></strong><span>' + paddingProportionIcon +
            '<input type="checkbox" class="iwetc-constrain-proportion iwetc-builder-editor-input" data-type="attribute" data-property="data-padding-button-proportion" ';
        output += paddingProportionChecked;
        output += '></span></label>' +
            '</div>' +
            '</div>' +

            '<div class="iwetc-constrain-proportion-container">' +
            '<div class="iwetc-builder-col-12" style="margin-bottom: 0;">' +
            '<label><strong>Margin</strong></label>' +
            '</div>' +
            '<div class="iwetc-builder-col-2-5" style="margin-top: 0;">' +
            '<label>Top</label>' +
            '<input type="number" min="0" value="' + marginTop + '" placeholder="10" class="iwetc-builder-editor-input iwetc-has-proportion" data-type="style" data-property="margin-top" data-target=".iwetc-add-to-cart-button" data-unit="px">' +
            '</div>' +
            '<div class="iwetc-builder-col-2-5" style="margin-top: 0;">' +
            '<label>Right</label>' +
            '<input type="number" min="0" value="' + marginRight + '" placeholder="10" class="iwetc-builder-editor-input iwetc-has-proportion" data-type="style" data-property="margin-right" data-target=".iwetc-add-to-cart-button" data-unit="px">' +
            '</div>' +
            '<div class="iwetc-builder-col-2-5" style="margin-top: 0;">' +
            '<label>Bottom</label>' +
            '<input type="number" min="0" value="' + marginBottom + '" placeholder="10" class="iwetc-builder-editor-input iwetc-has-proportion" data-type="style" data-property="margin-bottom" data-target=".iwetc-add-to-cart-button" data-unit="px">' +
            '</div>' +
            '<div class="iwetc-builder-col-2-5" style="margin-top: 0;">' +
            '<label>Left</label>' +
            '<input type="number" min="0" value="' + marginLeft + '" placeholder="10" class="iwetc-builder-editor-input iwetc-has-proportion" data-type="style" data-property="margin-left" data-target=".iwetc-add-to-cart-button" data-unit="px">' +
            '</div>' +
            '<div class="iwetc-constrain-proportion-field">' +
            '<label class="';
        output += marginProportionClassName;
        output += '"><strong></strong><span>' + marginProportionIcon +
            '<input type="checkbox" class="iwetc-constrain-proportion iwetc-builder-editor-input" data-type="attribute" data-property="data-margin-proportion" ';
        output += marginProportionChecked;
        output += '></span></label>' +
            '</div>' +
            '</div>' +
            '</div>' +

            '<div class="iwetc-constrain-proportion-container">' +
            '<div class="iwetc-builder-col-12" style="margin-top: 15px; margin-bottom: 0;">' +
            '<label><strong>Border radius</strong></label>' +
            '</div>' +
            '<div class="iwetc-builder-col-2-5" style="margin-top: 0;">' +
            '<label>T-L</label>' +
            '<input type="number" min="0" value="' + borderTopLeftRadius + '" placeholder="10" class="iwetc-builder-editor-input iwetc-has-proportion" data-type="style" data-property="border-top-left-radius" data-target=".iwetc-add-to-cart-button" data-unit="px">' +
            '</div>' +
            '<div class="iwetc-builder-col-2-5" style="margin-top: 0;">' +
            '<label>T-R</label>' +
            '<input type="number" min="0" value="' + borderTopRightRadius + '" placeholder="10" class="iwetc-builder-editor-input iwetc-has-proportion" data-type="style" data-property="border-top-right-radius" data-target=".iwetc-add-to-cart-button" data-unit="px">' +
            '</div>' +
            '<div class="iwetc-builder-col-2-5" style="margin-top: 0;">' +
            '<label>B-R</label>' +
            '<input type="number" min="0" value="' + borderBottomRightRadius + '" placeholder="10" class="iwetc-builder-editor-input iwetc-has-proportion" data-type="style" data-property="border-bottom-right-radius" data-target=".iwetc-add-to-cart-button" data-unit="px">' +
            '</div>' +
            '<div class="iwetc-builder-col-2-5" style="margin-top: 0;">' +
            '<label>B-L</label>' +
            '<input type="number" min="0" value="' + borderBottomLeftRadius + '" placeholder="10" class="iwetc-builder-editor-input iwetc-has-proportion" data-type="style" data-property="border-bottom-left-radius" data-target=".iwetc-add-to-cart-button" data-unit="px">' +
            '</div>' +
            '<div class="iwetc-constrain-proportion-field">' +
            '<label class="';
        output += borderRadiusProportionClassName;
        output += '"><strong></strong><span>' + borderRadiusProportionIcon +
            '<input type="checkbox" class="iwetc-constrain-proportion iwetc-builder-editor-input" data-type="attribute" data-property="data-border-radius-proportion" ';
        output += borderRadiusProportionChecked;
        output += '></span></label>' +
            '</div>' +
            '</div>' +
            '</div>' +

            '</div>' +
            '</div>';
        return output;
    }
});
IwetcBuilder.Property.addProperty({
    name: 'product_image',
    label: IwetcBuilder.Translate.product_image,
    getHtml: function (element) {
        let width = 150;

        if (element.find('[data-name="product_image"]').length > 0) {
            width = parseInt(element.find('[data-name="product_image"]').first().css('width'));
        }

        let output = '<div class="iwetc-builder-col-12">' +
            '<label>Width (px)</label>' +
            '<input type="range" min="0" max="300" value="' + width + '" placeholder="150" class="iwetc-builder-editor-input iwetc-slider-number-input" data-type="style" data-target="img" data-property="width" data-unit="px">' +
            '<span class="iwetc-slider-number-preview">' + width + '</span>' +
            '</div>';
        return output;
    }
});
IwetcBuilder.Property.addProperty({
    name: 'products_product_name',
    label: IwetcBuilder.Translate.product_name,
    getHtml: function (element) {
        let fontSize = 13,
            characterLimit = 30,
            fontWeight = 400,
            textColor = '#3e3e3e',
            lineHeight = 25,
            topDistance = 0,
            bottomDistance = 0;

        if (element.find('[data-name="products_product_name"]').length > 0) {
            characterLimit = parseInt(element.find('[data-name="products_product_name"]').first().attr('data-character-limit'));
            fontSize = parseInt(element.find('[data-name="products_product_name"]').first().css('font-size'));
            fontWeight = parseInt(element.find('[data-name="products_product_name"]').first().css('font-weight'));
            textColor = element.find('[data-name="products_product_name"]').first().css('color');
            lineHeight = parseInt(element.find('[data-name="products_product_name"]').first().css('line-height'));
            topDistance = parseInt(element.find('[data-name="products_product_name"]').first().css('padding-top'));
            bottomDistance = parseInt(element.find('[data-name="products_product_name"]').first().css('padding-bottom'));
        }

        return '<div class="iwetc-builder-left-sidebar-subsection">' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Character limit</label>' +
            '<input type="number" min="0" value="' + characterLimit + '" placeholder="30 ..." class="iwetc-builder-editor-input" data-type="character_limit" data-target="[data-name=\'products_product_name\']">' +
            '</div>' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Top distance</label>' +
            '<input type="range" min="0" max="20" value="' + topDistance + '" class="iwetc-builder-editor-input iwetc-slider-number-input" data-type="style" data-property="padding-top" data-target="[data-name=\'products_product_name\']" data-unit="px">' +
            '<span class="iwetc-slider-number-preview">' + topDistance + '</span>' +
            '</div>' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Bottom distance</label>' +
            '<input type="range" min="0" max="20" value="' + bottomDistance + '" class="iwetc-builder-editor-input iwetc-slider-number-input" data-type="style" data-property="padding-bottom" data-target="[data-name=\'products_product_name\']" data-unit="px">' +
            '<span class="iwetc-slider-number-preview">' + bottomDistance + '</span>' +
            '</div>' +
            '<div class="iwetc-builder-col-6">' +
            '<label>Font size</label>' +
            '<input type="number" min="0" value="' + fontSize + '" placeholder="12 ..." class="iwetc-builder-editor-input" data-type="style" data-property="font-size" data-target="[data-name=\'products_product_name\']" data-unit="px">' +
            '</div>' +
            '<div class="iwetc-builder-col-6">' +
            '<label>Font weight</label>' +
            '<select class="iwetc-builder-editor-input" data-type="style" data-property="font-weight" data-target="[data-name=\'products_product_name\']">' +
            getFontWeightOptions(fontWeight) +
            '</select>' +
            '</div>' +
            '<div class="iwetc-builder-col-6">' +
            '<label>Text color</label>' +
            '<input type="text" value="' + textColor + '" class="iwetc-color-picker" data-type="style" data-property="color" data-target="[data-name=\'products_product_name\']">' +
            '</div>' +
            '<div class="iwetc-builder-col-6">' +
            '<label>Line height</label>' +
            '<input type="number" min="0" value="' + lineHeight + '" placeholder="25 ..." class="iwetc-builder-editor-input" data-type="style" data-property="line-height" data-target="[data-name=\'products_product_name\']" data-unit="px">' +
            '</div>' +
            '</div>';
    }
});
IwetcBuilder.Property.addProperty({
    name: 'products_price',
    label: IwetcBuilder.Translate.price,
    getHtml: function (element) {
        let fontSize = 13,
            fontWeight = 400,
            textColor = '#3e3e3e',
            lineHeight = 25;

        if (element.find('[data-name="products_price"]').length > 0) {
            fontSize = parseInt(element.find('[data-name="products_price"]').first().css('font-size'));
            fontWeight = parseInt(element.find('[data-name="products_price"]').first().css('font-weight'));
            textColor = element.find('[data-name="products_price"]').first().css('color');
            lineHeight = parseInt(element.find('[data-name="products_price"]').first().css('line-height'));
        }

        return '<div class="iwetc-builder-left-sidebar-subsection">' +
            '<div class="iwetc-builder-col-6">' +
            '<label>Font size</label>' +
            '<input type="number" min="0" value="' + fontSize + '" placeholder="12 ..." class="iwetc-builder-editor-input" data-type="style" data-property="font-size" data-target="[data-name=\'products_price\']" data-unit="px">' +
            '</div>' +
            '<div class="iwetc-builder-col-6">' +
            '<label>Font weight</label>' +
            '<select class="iwetc-builder-editor-input" data-type="style" data-property="font-weight" data-target="[data-name=\'products_price\']">' +
            getFontWeightOptions(fontWeight) +
            '</select>' +
            '</div>' +
            '<div class="iwetc-builder-col-6">' +
            '<label>Text color</label>' +
            '<input type="text" value="' + textColor + '" class="iwetc-color-picker" data-type="style" data-property="color" data-target="[data-name=\'products_price\']">' +
            '</div>' +
            '<div class="iwetc-builder-col-6">' +
            '<label>Line height</label>' +
            '<input type="number" min="0" value="' + lineHeight + '" placeholder="25 ..." class="iwetc-builder-editor-input" data-type="style" data-property="line-height" data-target="[data-name=\'products_price\']" data-unit="px">' +
            '</div>' +
            '</div>';
    }
});
IwetcBuilder.Property.addProperty({
    name: 'post_image',
    label: IwetcBuilder.Translate.post_image,
    getHtml: function (element) {
        let image = element.find('[data-name="post_image"]').first();
        let widthUnit = (image.attr('data-unit')) ? image.attr('data-unit') : 'px';
        let width = (widthUnit == '%') ? Math.round((parseInt(image.css('width')) / parseInt(image.parent().css('width'))) * 100).toFixed(0) : parseInt(image.css('width'));
        let borderRadiusProportion = element.attr('data-image-border-radius-proportion');
        let borderRadiusProportionChecked = '',
            borderRadiusProportionClassName = '',
            borderRadiusProportionIcon = IwetcBuilder.unlinkIcon;

        if (typeof borderRadiusProportion === 'undefined' || borderRadiusProportion == 'true') {
            borderRadiusProportionChecked = 'checked="checked"';
            borderRadiusProportionClassName = 'iwetc-proportion-enable';
            borderRadiusProportionIcon = IwetcBuilder.linkIcon;
        }

        let borderTopLeftRadius = (image.css('border-top-left-radius')) ? parseInt(image.css('border-top-left-radius')) : 0;
        let borderTopRightRadius = (image.css('border-top-right-radius')) ? parseInt(image.css('border-top-right-radius')) : 0;
        let borderBottomLeftRadius = (image.css('border-bottom-left-radius')) ? parseInt(image.css('border-bottom-left-radius')) : 0;
        let borderBottomRightRadius = (image.css('border-bottom-right-radius')) ? parseInt(image.css('border-bottom-right-radius')) : 0;

        let output = '<div class="iwetc-builder-left-sidebar-subsection">' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Width' +
            '<button type="button" class="iwetc-builder-change-post-image-size-unit ';
        output += (widthUnit == 'px') ? 'active' : '';
        output += '" value="px">px</button>' +
            '<button type="button" class="iwetc-builder-change-post-image-size-unit ';
        output += (widthUnit == '%') ? 'active' : '';
        output += '" value="%">%</button>' +
            '</label > ' +
            '<input type="number" min="0" value="' + width + '" placeholder="150" class="iwetc-builder-editor-input" data-type="style" data-target="img" data-property="width" data-unit="' + widthUnit + '">' +
            '</div>' +
            '</div>' +
            '<div class="iwetc-builder-left-sidebar-subsection iwetc-constrain-proportion-container">' +
            '<div class="iwetc-builder-left-sidebar-subsection-title">' +
            '<label>Border radius</label>' +
            '</div>' +
            '<div class="iwetc-builder-col-2-5">' +
            '<label>T-L</label>' +
            '<input type="number" min="0" value="' + borderTopLeftRadius + '" placeholder="0" class="iwetc-builder-editor-input iwetc-has-proportion" data-type="style" data-property="border-top-left-radius" data-target="img" data-unit="px">' +
            '</div>' +
            '<div class="iwetc-builder-col-2-5">' +
            '<label>T-R</label>' +
            '<input type="number" min="0" value="' + borderTopRightRadius + '" placeholder="0" class="iwetc-builder-editor-input iwetc-has-proportion" data-type="style" data-property="border-top-right-radius" data-target="img" data-unit="px">' +
            '</div>' +
            '<div class="iwetc-builder-col-2-5">' +
            '<label>B-R</label>' +
            '<input type="number" min="0" value="' + borderBottomRightRadius + '" placeholder="0" class="iwetc-builder-editor-input iwetc-has-proportion" data-type="style" data-property="border-bottom-right-radius" data-target="img" data-unit="px">' +
            '</div>' +
            '<div class="iwetc-builder-col-2-5">' +
            '<label>B-L</label>' +
            '<input type="number" min="0" value="' + borderBottomLeftRadius + '" placeholder="0" class="iwetc-builder-editor-input iwetc-has-proportion" data-type="style" data-property="border-bottom-left-radius" data-target="img" data-unit="px">' +
            '</div>' +
            '<div class="iwetc-constrain-proportion-field">' +
            '<label class="';
        output += borderRadiusProportionClassName;
        output += '"><strong></strong><span>' + borderRadiusProportionIcon +
            '<input type="checkbox" class="iwetc-constrain-proportion iwetc-builder-editor-input" data-type="attribute" data-property="data-image-border-radius-proportion" ';
        output += borderRadiusProportionChecked;
        output += '></span></label>' +
            '</div>' +
            '</div>';

        return output;
    }
});
IwetcBuilder.Property.addProperty({
    name: 'post_title',
    label: IwetcBuilder.Translate.post_title,
    getHtml: function (element) {
        let fontSize = 13,
            characterLimit = 30,
            fontWeight = 400,
            textColor = '#3e3e3e',
            lineHeight = 25;

        if (element.find('[data-name="post_title"]').length > 0) {
            characterLimit = parseInt(element.find('[data-name="post_title"]').first().attr('data-character-limit'));
            fontSize = parseInt(element.find('[data-name="post_title"]').first().css('font-size'));
            fontWeight = parseInt(element.find('[data-name="post_title"]').first().css('font-weight'));
            textColor = element.find('[data-name="post_title"]').first().css('color');
            lineHeight = parseInt(element.find('[data-name="post_title"]').first().css('line-height'));
        }

        return '<div class="iwetc-builder-left-sidebar-subsection">' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Character limit</label>' +
            '<input type="number" min="0" value="' + characterLimit + '" placeholder="30 ..." class="iwetc-builder-editor-input" data-type="character_limit" data-target="[data-name=\'post_title\']">' +
            '</div>' +
            '<div class="iwetc-builder-col-6">' +
            '<label>Font size</label>' +
            '<input type="number" min="0" value="' + fontSize + '" placeholder="12 ..." class="iwetc-builder-editor-input" data-type="style" data-property="font-size" data-target="[data-name=\'post_title\']" data-unit="px">' +
            '</div>' +
            '<div class="iwetc-builder-col-6">' +
            '<label>Font weight</label>' +
            '<select class="iwetc-builder-editor-input" data-type="style" data-property="font-weight" data-target="[data-name=\'post_title\']">' +
            getFontWeightOptions(fontWeight) +
            '</select>' +
            '</div>' +
            '<div class="iwetc-builder-col-6">' +
            '<label>Text color</label>' +
            '<input type="text" value="' + textColor + '" class="iwetc-color-picker" data-type="style" data-property="color" data-target="[data-name=\'post_title\']">' +
            '</div>' +
            '<div class="iwetc-builder-col-6">' +
            '<label>Line height</label>' +
            '<input type="number" min="0" value="' + lineHeight + '" placeholder="25 ..." class="iwetc-builder-editor-input" data-type="style" data-property="line-height" data-target="[data-name=\'post_title\']" data-unit="px">' +
            '</div>' +
            '</div>';
    }
});
IwetcBuilder.Property.addProperty({
    name: 'post_content',
    label: IwetcBuilder.Translate.post_content,
    getHtml: function (element) {
        let fontSize = 13,
            characterLimit = 80,
            fontWeight = 400,
            textColor = '#3e3e3e',
            lineHeight = 25,
            contentType = 'excerpt';

        if (element.find('[data-name="post_content"]').length > 0) {
            characterLimit = parseInt(element.find('[data-name="post_content"]').first().attr('data-character-limit'));
            fontSize = parseInt(element.find('[data-name="post_content"]').first().css('font-size'));
            fontWeight = parseInt(element.find('[data-name="post_content"]').first().css('font-weight'));
            textColor = element.find('[data-name="post_content"]').first().css('color');
            lineHeight = parseInt(element.find('[data-name="post_content"]').first().css('line-height'));
            contentType = element.find('[data-name="post_content"]').first().attr('data-content-type');
        }

        let output = '<div class="iwetc-builder-left-sidebar-subsection">' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Content type</label>' +
            '<select class="iwetc-builder-editor-input iwetc-builder-post-content-type" data-type="attribute" data-property="data-content-type" data-target="[data-name=\'post_content\']"><option value="none" ';
        output += (contentType == 'none') ? 'selected' : '';
        output += '>None</option><option value="excerpt" ';
        output += (contentType == 'excerpt') ? 'selected' : '';
        output += '>Excerpt</option><option value="content" ';
        output += (contentType == 'content') ? 'selected' : '';
        output += '>Content</option></select>' +
            '</div>' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Character limit</label>' +
            '<input type="number" min="0" value="' + characterLimit + '" placeholder="30 ..." class="iwetc-builder-editor-input" data-type="character_limit" data-target="[data-name=\'post_content\']">' +
            '</div>' +
            '<div class="iwetc-builder-col-6">' +
            '<label>Font size</label>' +
            '<input type="number" min="0" value="' + fontSize + '" placeholder="12 ..." class="iwetc-builder-editor-input" data-type="style" data-property="font-size" data-target="[data-name=\'post_content\']" data-unit="px">' +
            '</div>' +
            '<div class="iwetc-builder-col-6">' +
            '<label>Font weight</label>' +
            '<select class="iwetc-builder-editor-input" data-type="style" data-property="font-weight" data-target="[data-name=\'post_content\']">' +
            getFontWeightOptions(fontWeight) +
            '</select>' +
            '</div>' +
            '<div class="iwetc-builder-col-6">' +
            '<label>Text color</label>' +
            '<input type="text" value="' + textColor + '" class="iwetc-color-picker" data-type="style" data-property="color" data-target="[data-name=\'post_content\']">' +
            '</div>' +
            '<div class="iwetc-builder-col-6">' +
            '<label>Line height</label>' +
            '<input type="number" min="0" value="' + lineHeight + '" placeholder="25 ..." class="iwetc-builder-editor-input" data-type="style" data-property="line-height" data-target="[data-name=\'post_content\']" data-unit="px">' +
            '</div>' +
            '</div>';

        return output;
    }
});
IwetcBuilder.Property.addProperty({
    name: 'post_type',
    label: IwetcBuilder.Translate.post_type,
    getHtml: function (element) {
        let table = element.find('table');
        let row = table.attr('data-row');
        let column = table.attr('data-column');

        let category = table.attr('data-category');
        let included = table.attr('data-included');
        let excluded = table.attr('data-excluded');

        let output = '<div class="iwetc-builder-left-sidebar-subsection">' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Category</label>' +
            '<select class="iwetc-select2-post-categories iwetc-builder-editor-input" style="width: 100%;" data-type="attribute" data-property="data-category" data-target=".iwetc-has-category" multiple>';
        if (category && IwetcBuilder.PostCategories instanceof Object && Object.keys(IwetcBuilder.PostCategories).length > 0) {
            jQuery.each(IwetcBuilder.PostCategories, function (key, value) {
                output += '<option value="' + key + '" selected>' + value + '</option>'
            });
        }
        output += '</select>' +
            '</div>' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Included posts</label>' +
            '<select class="iwetc-select2-posts iwetc-post-included iwetc-builder-editor-input" data-type="attribute" data-property="data-included" style="width: 100%;" multiple data-target=".iwetc-has-included">';
        if (included && IwetcBuilder.PostIncluded instanceof Object && Object.keys(IwetcBuilder.PostIncluded).length > 0) {
            jQuery.each(IwetcBuilder.PostIncluded, function (key, value) {
                output += '<option value="' + key + '" selected>' + value + '</option>'
            });
        }
        output += '</select>' +
            '</div>' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Excluded posts</label>' +
            '<select class="iwetc-select2-posts iwetc-post-excluded iwetc-builder-editor-input" data-type="attribute" data-property="data-excluded" style="width: 100%;" multiple data-target=".iwetc-has-excluded">';
        if (excluded && IwetcBuilder.PostExcluded instanceof Object && Object.keys(IwetcBuilder.PostExcluded).length > 0) {
            jQuery.each(IwetcBuilder.PostExcluded, function (key, value) {
                output += '<option value="' + key + '" selected>' + value + '</option>'
            });
        }
        output += '</select>' +
            '</div>' +
            '</div><div class="iwetc-builder-left-sidebar-subsection"><div class="iwetc-builder-col-6"><label>Max row</label>' +
            '<select class="iwetc-builder-change-post-component" data-name="row"><option value="1" ';
        output += (row == 1) ? 'selected' : '';
        output += '>1</option><option value="2" ';
        output += (row == 2) ? 'selected' : '';
        output += '>2</option><option value="3" ';
        output += (row == 3) ? 'selected' : '';
        output += '>3</option><option value="4" ';
        output += (row == 4) ? 'selected' : '';
        output += '>4</option></select>';
        output += '</div>' +
            '<div class="iwetc-builder-col-6">' +
            '<label>Column</label>' +
            '<select class="iwetc-builder-change-post-component" data-name="column"><option value="1" ';
        output += (column == 1) ? 'selected' : '';
        output += '>1</option><option value="2" ';
        output += (column == 2) ? 'selected' : '';
        output += '>2</option><option value="3" ';
        output += (column == 3) ? 'selected' : '';
        output += '>3</option><option value="4" ';
        output += (column == 4) ? 'selected' : '';
        output += '>4</option></select></div></div>';

        return output;
    }
});
IwetcBuilder.Property.addProperty({
    name: 'contact_home',
    label: IwetcBuilder.Translate.contact_home,
    getHtml: function (element) {
        let postType = '';
        let output = '<div class="iwetc-builder-left-sidebar-subsection">' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Icon</label>' +
            '<select class="iwetc-builder-editor-input" data-type="attribute" data-property="src" data-target="[data-name=\'contact_home_image\']"><option value="' + IwetcBuilder.SiteIconSrc.black + '" ';
        output += (postType == 'black') ? 'selected' : '';
        output += '>Black</option><option value="' + IwetcBuilder.SiteIconSrc.white + '" ';
        output += (postType == 'white') ? 'selected' : '';
        output += '>White</option>';
        output += '</select></div>' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Text</label>' +
            '<input type="text" value="' + element.find('[data-name="contact_home_text"]').text() + '" class="iwetc-builder-editor-input" data-type="text" data-target="[data-name=\'contact_home_text\']">' +
            '</div>' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Url</label>' +
            '<input type="text" value="' + element.find('[data-name="contact_home_url"]').attr('href') + '" class="iwetc-builder-editor-input" data-type="attribute" data-property="href" data-target="[data-name=\'contact_home_url\']">' +
            '</div></div>';

        return output;
    }
});
IwetcBuilder.Property.addProperty({
    name: 'contact_email',
    label: IwetcBuilder.Translate.contact_email,
    getHtml: function (element) {
        let postType = '';
        let output = '<div class="iwetc-builder-left-sidebar-subsection">' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Icon</label>' +
            '<select class="iwetc-builder-editor-input" data-type="attribute" data-property="src" data-target="[data-name=\'contact_email_image\']"><option value="' + IwetcBuilder.EmailIconSrc.black + '" ';
        output += (postType == 'black') ? 'selected' : '';
        output += '>Black</option><option value="' + IwetcBuilder.EmailIconSrc.white + '" ';
        output += (postType == 'white') ? 'selected' : '';
        output += '>White</option>';
        output += '</select></div>' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Text</label>' +
            '<input type="text" value="' + element.find('[data-name="contact_email_text"]').text() + '" class="iwetc-builder-editor-input" data-type="text" data-target="[data-name=\'contact_email_text\']">' +
            '</div>' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Email address</label>' +
            '<input type="text" value="' + element.find('[data-name="contact_email_url"]').attr('href') + '" data-type="attribute" class="iwetc-builder-editor-input" data-property="href" data-target="[data-name=\'contact_email_url\']">' +
            '</div></div>';

        return output;
    }
});
IwetcBuilder.Property.addProperty({
    name: 'contact_phone',
    label: IwetcBuilder.Translate.contact_phone,
    getHtml: function (element) {
        let output = '<div class="iwetc-builder-left-sidebar-subsection">' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Choose icon</label>' +
            '<input type="text" class="">' +
            '</div>' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Text</label>' +
            '<input type="text" value="' + element.find('[data-name="contact_phone_text"]').text() + '" class="iwetc-builder-editor-input" data-type="text" data-target="[data-name=\'contact_phone_text\']">' +
            '</div>' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Phone number</label>' +
            '<input type="text" value="' + element.find('[data-name="contact_phone_url"]').attr('href') + '" class="iwetc-builder-editor-input" data-type="attribute" data-property="href" data-target="[data-name=\'contact_phone_url\']">' +
            '</div>' +
            '</div>';

        return output;
    }
});
IwetcBuilder.Property.addProperty({
    name: 'contact_items',
    label: IwetcBuilder.Translate.contact_items,
    getHtml: function (element) {
        let output = '<div class="iwetc-builder-left-sidebar-subsection" id="iwetc-sidebar-contact-items">';

        if (element.find('.iwetc-contact-item').length > 0) {
            jQuery.each(element.find('.iwetc-contact-item'), function () {
                output += iwetcContactGetItem(jQuery(this).attr('data-id'));
            });
        }

        output += '</div>' +
            '<button type="button" id="iwetc-contact-add-item" class="iwetc-button iwetc-button-blue">Add item</button>';

        return output;
    }
});
IwetcBuilder.Property.addProperty({
    name: 'select_hook',
    label: IwetcBuilder.Translate.select_hook,
    getHtml: function (element) {
        let hook = (element.find('[data-name="wc_hook"]').attr('data-wc-hook')) ? element.find('[data-name="wc_hook"]').attr('data-wc-hook') : '';
        let output = '' +
            '<div class="iwetc-builder-col-12">' +
            '<select class="iwetc-builder-editor-input iwetc-builder-change-wc-hook" data-type="attribute" data-property="data-wc-hook" data-target="[data-name=\'wc_hook\']"><option value="woocommerce_email_before_order_table" ';
        output += (hook == 'woocommerce_email_before_order_table') ? 'selected' : '';
        output += '>woocommerce_email_before_order_table</option><option value="woocommerce_email_after_order_table" ';
        output += (hook == 'woocommerce_email_after_order_table') ? 'selected' : '';
        output += '>woocommerce_email_after_order_table</option><option value="woocommerce_email_order_meta" ';
        output += (hook == 'woocommerce_email_order_meta') ? 'selected' : '';
        output += '>woocommerce_email_order_meta</option>';
        output += '</select></div>';

        return output;
    }
});
IwetcBuilder.Property.addProperty({
    name: 'menu_bar_items',
    label: IwetcBuilder.Translate.menu_bar_items,
    getHtml: function (element) {
        let output = '<div class="iwetc-builder-left-sidebar-subsection" id="iwetc-menu-bar-items">';

        if (element.find('td').length > 0) {
            jQuery.each(element.find('td[data-name="menu_bar_item"]'), function () {
                output += iwetcMenuBarGetItem(jQuery(this).attr('data-id'));
            });
        }

        output += '</div>' +
            '<button type="button" id="iwetc-menu-bar-add-item" class="iwetc-button iwetc-button-blue">Add item</button>';

        return output;
    }
});
IwetcBuilder.Property.addProperty({
    name: 'menu_bar_divider',
    label: IwetcBuilder.Translate.menu_bar_divider,
    getHtml: function (element) {
        let divider = element.find('[data-name="menu_bar_divider"]').first();
        let checked = '';
        let colorDisplay = 'none';
        if (divider.is(':visible')) {
            checked = 'checked="checked"';
            colorDisplay = 'block';
        }

        let borderColor = '#3e3e3e';
        if (divider.length > 0) {
            borderColor = (divider.css('border-color') == 'rgba(0, 0, 0, 0)') ? 'transparent' : divider.css('border-color');
        }

        let output = '';
        output += '<div class="iwetc-builder-left-sidebar-subsection">' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Enable</label>' +
            '<input type="checkbox" class="iwetc-builder-properties-right-checkbox iwetc-menu-bar-divider-enable" ' + checked + '>' +
            '</div>' +
            '<div class="iwetc-builder-col-12" data-name="menu_bar_divider_color" style="display: ' + colorDisplay + ';">' +
            '<label>Color</label>' +
            '<input type="text" class="iwetc-color-picker iwetc-menu-bar-divider-color" value="' + borderColor + '" data-type="style" data-property="border-color" data-target="[data-name=\'menu_bar_divider\']">' +
            '</div>' +
            '</div>';
        return output;
    }
});
IwetcBuilder.Property.addProperty({
    name: 'social_items',
    label: IwetcBuilder.Translate.social_items,
    getHtml: function (element) {
        let facebook = {
            checked: (element.find('[data-name="socials_facebook"]').length > 0 && element.find('[data-name="socials_facebook"]').css('display') == 'none') ? '' : 'checked="checked"',
            icon: (element.find('[data-name="socials_facebook_image"]').length > 0) ? element.find('[data-name="socials_facebook_image"]').attr('src') : '',
            link: (element.find('[data-name="socials_facebook_link"]').length > 0) ? element.find('[data-name="socials_facebook_link"]').attr('href') : '',
            target: (element.find('[data-name="socials_facebook_link"]').length > 0) ? element.find('[data-name="socials_facebook_link"]').attr('target') : '',
        }
        let twitter = {
            checked: (element.find('[data-name="socials_twitter"]').length > 0 && element.find('[data-name="socials_twitter"]').css('display') == 'none') ? '' : 'checked="checked"',
            icon: (element.find('[data-name="socials_twitter_image"]').length > 0) ? element.find('[data-name="socials_twitter_image"]').attr('src') : '',
            link: (element.find('[data-name="socials_twitter_link"]').length > 0) ? element.find('[data-name="socials_twitter_link"]').attr('href') : '',
            target: (element.find('[data-name="socials_twitter_link"]').length > 0) ? element.find('[data-name="socials_twitter_link"]').attr('target') : '',
        }
        let youtube = {
            checked: (element.find('[data-name="socials_youtube"]').length > 0 && element.find('[data-name="socials_youtube"]').css('display') == 'none') ? '' : 'checked="checked"',
            icon: (element.find('[data-name="socials_youtube_image"]').length > 0) ? element.find('[data-name="socials_youtube_image"]').attr('src') : '',
            link: (element.find('[data-name="socials_youtube_link"]').length > 0) ? element.find('[data-name="socials_youtube_link"]').attr('href') : '',
            target: (element.find('[data-name="socials_youtube_link"]').length > 0) ? element.find('[data-name="socials_youtube_link"]').attr('target') : '',
        }
        let instagram = {
            checked: (element.find('[data-name="socials_instagram"]').length > 0 && element.find('[data-name="socials_instagram"]').css('display') == 'none') ? '' : 'checked="checked"',
            icon: (element.find('[data-name="socials_instagram_image"]').length > 0) ? element.find('[data-name="socials_instagram_image"]').attr('src') : '',
            link: (element.find('[data-name="socials_instagram_link"]').length > 0) ? element.find('[data-name="socials_instagram_link"]').attr('href') : '',
            target: (element.find('[data-name="socials_instagram_link"]').length > 0) ? element.find('[data-name="socials_instagram_link"]').attr('target') : '',
        }
        let linkedin = {
            checked: (element.find('[data-name="socials_linkedin"]').length > 0 && element.find('[data-name="socials_linkedin"]').css('display') == 'none') ? '' : 'checked="checked"',
            icon: (element.find('[data-name="socials_linkedin_image"]').length > 0) ? element.find('[data-name="socials_linkedin_image"]').attr('src') : '',
            link: (element.find('[data-name="socials_linkedin_link"]').length > 0) ? element.find('[data-name="socials_linkedin_link"]').attr('href') : '',
            target: (element.find('[data-name="socials_linkedin_link"]').length > 0) ? element.find('[data-name="socials_linkedin_link"]').attr('target') : '',
        }
        let whatsapp = {
            checked: (element.find('[data-name="socials_whatsapp"]').length > 0 && element.find('[data-name="socials_whatsapp"]').css('display') == 'none') ? '' : 'checked="checked"',
            icon: (element.find('[data-name="socials_whatsapp_image"]').length > 0) ? element.find('[data-name="socials_whatsapp_image"]').attr('src') : '',
            link: (element.find('[data-name="socials_whatsapp_link"]').length > 0) ? element.find('[data-name="socials_whatsapp_link"]').attr('href') : '',
            target: (element.find('[data-name="socials_whatsapp_link"]').length > 0) ? element.find('[data-name="socials_whatsapp_link"]').attr('target') : '',
        }

        let output = '<div class="iwetc-builder-left-sidebar-subsection">' +
            '<div class="iwetc-builder-left-sidebar-subsection-title"><input type="checkbox" class="iwetc-builder-editor-input" data-type="add_remove_social_item" data-property="socials_facebook" ' + facebook.checked + '><span>Facebook</span></div>' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Icon</label>' +
            '<select class="iwetc-builder-editor-input" data-type="attribute" data-property="src" data-target="[data-name=\'socials_facebook_image\']"><option value="' + IwetcBuilder.FacebookIconSrc.black + '" ';
        output += (IwetcBuilder.FacebookIconSrc.black == facebook.icon) ? 'selected' : '';
        output += ' >Black</option><option value="' + IwetcBuilder.FacebookIconSrc.white + '" ';
        output += (IwetcBuilder.FacebookIconSrc.white == facebook.icon) ? 'selected' : '';
        output += ' >White</option><option value="' + IwetcBuilder.FacebookIconSrc.color + '" ';
        output += (IwetcBuilder.FacebookIconSrc.color == facebook.icon) ? 'selected' : '';
        output += ' >Color</option><option value="' + IwetcBuilder.FacebookIconSrc.white_border + '" ';
        output += (IwetcBuilder.FacebookIconSrc.white_border == facebook.icon) ? 'selected' : '';
        output += ' >White border</option><option value="' + IwetcBuilder.FacebookIconSrc.black_border + '" ';
        output += (IwetcBuilder.FacebookIconSrc.black_border == facebook.icon) ? 'selected' : '';
        output += ' >Black border</option><option value="' + IwetcBuilder.FacebookIconSrc.color_border + '" ';
        output += (IwetcBuilder.FacebookIconSrc.color_border == facebook.icon) ? 'selected' : '';
        output += ' >Color border</option><option value="' + IwetcBuilder.FacebookIconSrc.color_white + '" ';
        output += (IwetcBuilder.FacebookIconSrc.color_white == facebook.icon) ? 'selected' : '';
        output += ' >Color white</option><option value="' + IwetcBuilder.FacebookIconSrc.black_white + '" ';
        output += (IwetcBuilder.FacebookIconSrc.black_white == facebook.icon) ? 'selected' : '';
        output += ' >Black white</option><option value="' + IwetcBuilder.FacebookIconSrc.white_color + '" ';
        output += (IwetcBuilder.FacebookIconSrc.white_color == facebook.icon) ? 'selected' : '';
        output += ' >White color</option>' +
            '</select></div>' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Link</label>' +
            '<input type="text" value="' + facebook.link + '" placeholder="Link ..." class="iwetc-builder-editor-input" data-type="attribute" data-property="href" data-target="[data-name=\'socials_facebook_link\']">' +
            '</div>' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Target</label>' +
            '<select class="iwetc-builder-editor-input" data-type="attribute" data-property="target" data-target="[data-name=\'socials_facebook_link\']">' +
            '<option value="_blank" ';
        output += (facebook.target == '_blank') ? 'selected' : '';
        output += '>_blank</option><option value="_self" ';
        output += (facebook.target == '_self') ? 'selected' : '';
        output += '>_self</option><option value="_parent" ';
        output += (facebook.target == '_parent') ? 'selected' : '';
        output += '>_parent</option><option value="_top" ';
        output += (facebook.target == '_top') ? 'selected' : '';
        output += '>_top</option>' +
            '</select>' +
            '</div>' +
            '</div>' +

            '<div class="iwetc-builder-left-sidebar-subsection">' +
            '<div class="iwetc-builder-left-sidebar-subsection-title"><input type="checkbox" class="iwetc-builder-editor-input" data-type="add_remove_social_item" data-property="socials_twitter" ' + twitter.checked + '><span>Twitter</span></div>' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Icon</label>' +
            '<select class="iwetc-builder-editor-input" data-type="attribute" data-property="src" data-target="[data-name=\'socials_twitter_image\']"><option value="' + IwetcBuilder.TwitterIconSrc.black + '" ';
        output += (IwetcBuilder.TwitterIconSrc.black == twitter.icon) ? 'selected' : '';
        output += ' >Black</option><option value="' + IwetcBuilder.TwitterIconSrc.white + '" ';
        output += (IwetcBuilder.TwitterIconSrc.white == twitter.icon) ? 'selected' : '';
        output += ' >White</option><option value="' + IwetcBuilder.TwitterIconSrc.color + '" ';
        output += (IwetcBuilder.TwitterIconSrc.color == twitter.icon) ? 'selected' : '';
        output += ' >Color</option><option value="' + IwetcBuilder.TwitterIconSrc.white_border + '" ';
        output += (IwetcBuilder.TwitterIconSrc.white_border == twitter.icon) ? 'selected' : '';
        output += ' >White border</option><option value="' + IwetcBuilder.TwitterIconSrc.black_border + '" ';
        output += (IwetcBuilder.TwitterIconSrc.black_border == twitter.icon) ? 'selected' : '';
        output += ' >Black border</option><option value="' + IwetcBuilder.TwitterIconSrc.color_border + '" ';
        output += (IwetcBuilder.TwitterIconSrc.color_border == twitter.icon) ? 'selected' : '';
        output += ' >Color border</option><option value="' + IwetcBuilder.TwitterIconSrc.color_white + '" ';
        output += (IwetcBuilder.TwitterIconSrc.color_white == twitter.icon) ? 'selected' : '';
        output += ' >Color white</option><option value="' + IwetcBuilder.TwitterIconSrc.black_white + '" ';
        output += (IwetcBuilder.TwitterIconSrc.black_white == twitter.icon) ? 'selected' : '';
        output += ' >Black white</option><option value="' + IwetcBuilder.TwitterIconSrc.white_color + '" ';
        output += (IwetcBuilder.TwitterIconSrc.white_color == twitter.icon) ? 'selected' : '';
        output += ' >White color</option>' +
            '</select>' +
            '</div>' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Link</label>' +
            '<input type="text" value="' + twitter.link + '" placeholder="Link ..." class="iwetc-builder-editor-input" data-type="attribute" data-property="href" data-target="[data-name=\'socials_twitter_link\']">' +
            '</div>' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Target</label>' +
            '<select class="iwetc-builder-editor-input" data-type="attribute" data-property="target" data-target="[data-name=\'socials_twitter_link\']">' +
            '<option value="_blank" ';
        output += (twitter.target == '_blank') ? 'selected' : '';
        output += '>_blank</option><option value="_self" ';
        output += (twitter.target == '_self') ? 'selected' : '';
        output += '>_self</option><option value="_parent" ';
        output += (twitter.target == '_parent') ? 'selected' : '';
        output += '>_parent</option><option value="_top" ';
        output += (twitter.target == '_top') ? 'selected' : '';
        output += '>_top</option>' +
            '</select>' +
            '</div>' +
            '</div>' +

            '<div class="iwetc-builder-left-sidebar-subsection">' +
            '<div class="iwetc-builder-left-sidebar-subsection-title"><input type="checkbox" class="iwetc-builder-editor-input" data-type="add_remove_social_item" data-property="socials_youtube" ' + youtube.checked + '><span>Youtube</span></div>' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Icon</label>' +
            '<select class="iwetc-builder-editor-input" data-type="attribute" data-property="src" data-target="[data-name=\'socials_youtube_image\']"><option value="' + IwetcBuilder.YoutubeIconSrc.black + '" ';
        output += (IwetcBuilder.YoutubeIconSrc.black == youtube.icon) ? 'selected' : '';
        output += ' >Black</option><option value="' + IwetcBuilder.YoutubeIconSrc.white + '" ';
        output += (IwetcBuilder.YoutubeIconSrc.white == youtube.icon) ? 'selected' : '';
        output += ' >White</option><option value="' + IwetcBuilder.YoutubeIconSrc.color + '" ';
        output += (IwetcBuilder.YoutubeIconSrc.color == youtube.icon) ? 'selected' : '';
        output += ' >Color</option><option value="' + IwetcBuilder.YoutubeIconSrc.white_border + '" ';
        output += (IwetcBuilder.YoutubeIconSrc.white_border == youtube.icon) ? 'selected' : '';
        output += ' >White border</option><option value="' + IwetcBuilder.YoutubeIconSrc.black_border + '" ';
        output += (IwetcBuilder.YoutubeIconSrc.black_border == youtube.icon) ? 'selected' : '';
        output += ' >Black border</option><option value="' + IwetcBuilder.YoutubeIconSrc.color_border + '" ';
        output += (IwetcBuilder.YoutubeIconSrc.color_border == youtube.icon) ? 'selected' : '';
        output += ' >Color border</option><option value="' + IwetcBuilder.YoutubeIconSrc.color_white + '" ';
        output += (IwetcBuilder.YoutubeIconSrc.color_white == youtube.icon) ? 'selected' : '';
        output += ' >Color white</option><option value="' + IwetcBuilder.YoutubeIconSrc.black_white + '" ';
        output += (IwetcBuilder.YoutubeIconSrc.black_white == youtube.icon) ? 'selected' : '';
        output += ' >Black white</option><option value="' + IwetcBuilder.YoutubeIconSrc.white_color + '" ';
        output += (IwetcBuilder.YoutubeIconSrc.white_color == youtube.icon) ? 'selected' : '';
        output += ' >White color</option>' +
            '</select>' +
            '</div>' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Link</label>' +
            '<input type="text" value="' + youtube.link + '" placeholder="Link ..." class="iwetc-builder-editor-input" data-type="attribute" data-property="href" data-target="[data-name=\'socials_youtube_link\']">' +
            '</div>' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Target</label>' +
            '<select class="iwetc-builder-editor-input" data-type="attribute" data-property="target" data-target="[data-name=\'socials_youtube_link\']">' +
            '<option value="_blank" ';
        output += (youtube.target == '_blank') ? 'selected' : '';
        output += '>_blank</option><option value="_self" ';
        output += (youtube.target == '_self') ? 'selected' : '';
        output += '>_self</option><option value="_parent" ';
        output += (youtube.target == '_parent') ? 'selected' : '';
        output += '>_parent</option><option value="_top" ';
        output += (youtube.target == '_top') ? 'selected' : '';
        output += '>_top</option>' +
            '</select>' +
            '</div>' +
            '</div>' +

            '<div class="iwetc-builder-left-sidebar-subsection">' +
            '<div class="iwetc-builder-left-sidebar-subsection-title"><input type="checkbox" class="iwetc-builder-editor-input" data-type="add_remove_social_item" data-property="socials_instagram" ' + instagram.checked + '><span>Instagram</span></div>' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Icon</label>' +
            '<select class="iwetc-builder-editor-input" data-type="attribute" data-property="src" data-target="[data-name=\'socials_instagram_image\']"><option value="' + IwetcBuilder.InstagramIconSrc.black + '" ';
        output += (IwetcBuilder.InstagramIconSrc.black == instagram.icon) ? 'selected' : '';
        output += ' >Black</option><option value="' + IwetcBuilder.InstagramIconSrc.white + '" ';
        output += (IwetcBuilder.InstagramIconSrc.white == instagram.icon) ? 'selected' : '';
        output += ' >White</option><option value="' + IwetcBuilder.InstagramIconSrc.color + '" ';
        output += (IwetcBuilder.InstagramIconSrc.color == instagram.icon) ? 'selected' : '';
        output += ' >Color</option><option value="' + IwetcBuilder.InstagramIconSrc.white_border + '" ';
        output += (IwetcBuilder.InstagramIconSrc.white_border == instagram.icon) ? 'selected' : '';
        output += ' >White border</option><option value="' + IwetcBuilder.InstagramIconSrc.black_border + '" ';
        output += (IwetcBuilder.InstagramIconSrc.black_border == instagram.icon) ? 'selected' : '';
        output += ' >Black border</option><option value="' + IwetcBuilder.InstagramIconSrc.color_border + '" ';
        output += (IwetcBuilder.InstagramIconSrc.color_border == instagram.icon) ? 'selected' : '';
        output += ' >Color border</option><option value="' + IwetcBuilder.InstagramIconSrc.color_white + '" ';
        output += (IwetcBuilder.InstagramIconSrc.color_white == instagram.icon) ? 'selected' : '';
        output += ' >Color white</option><option value="' + IwetcBuilder.InstagramIconSrc.black_white + '" ';
        output += (IwetcBuilder.InstagramIconSrc.black_white == instagram.icon) ? 'selected' : '';
        output += ' >Black white</option><option value="' + IwetcBuilder.InstagramIconSrc.white_color + '" ';
        output += (IwetcBuilder.InstagramIconSrc.white_color == instagram.icon) ? 'selected' : '';
        output += ' >White color</option>' +
            '</select>' +
            '</div>' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Link</label>' +
            '<input type="text" value="' + instagram.link + '" placeholder="Link ..." class="iwetc-builder-editor-input" data-type="attribute" data-property="href" data-target="[data-name=\'socials_instagram_link\']">' +
            '</div>' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Target</label>' +
            '<select class="iwetc-builder-editor-input" data-type="attribute" data-property="target" data-target="[data-name=\'socials_instagram_link\']">' +
            '<option value="_blank" ';
        output += (instagram.target == '_blank') ? 'selected' : '';
        output += '>_blank</option><option value="_self" ';
        output += (instagram.target == '_self') ? 'selected' : '';
        output += '>_self</option><option value="_parent" ';
        output += (instagram.target == '_parent') ? 'selected' : '';
        output += '>_parent</option><option value="_top" ';
        output += (instagram.target == '_top') ? 'selected' : '';
        output += '>_top</option>' +
            '</select>' +
            '</div>' +
            '</div>' +

            '<div class="iwetc-builder-left-sidebar-subsection">' +
            '<div class="iwetc-builder-left-sidebar-subsection-title"><input type="checkbox" class="iwetc-builder-editor-input" data-type="add_remove_social_item" data-property="socials_linkedin" ' + linkedin.checked + '><span>Linkedin</span></div>' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Icon</label>' +
            '<select class="iwetc-builder-editor-input" data-type="attribute" data-property="src" data-target="[data-name=\'socials_linkedin_image\']"><option value="' + IwetcBuilder.LinkedinIconSrc.black + '" ';
        output += (IwetcBuilder.LinkedinIconSrc.black == linkedin.icon) ? 'selected' : '';
        output += ' >Black</option><option value="' + IwetcBuilder.LinkedinIconSrc.white + '" ';
        output += (IwetcBuilder.LinkedinIconSrc.white == linkedin.icon) ? 'selected' : '';
        output += ' >White</option><option value="' + IwetcBuilder.LinkedinIconSrc.color + '" ';
        output += (IwetcBuilder.LinkedinIconSrc.color == linkedin.icon) ? 'selected' : '';
        output += ' >Color</option><option value="' + IwetcBuilder.LinkedinIconSrc.white_border + '" ';
        output += (IwetcBuilder.LinkedinIconSrc.white_border == linkedin.icon) ? 'selected' : '';
        output += ' >White border</option><option value="' + IwetcBuilder.LinkedinIconSrc.black_border + '" ';
        output += (IwetcBuilder.LinkedinIconSrc.black_border == linkedin.icon) ? 'selected' : '';
        output += ' >Black border</option><option value="' + IwetcBuilder.LinkedinIconSrc.color_border + '" ';
        output += (IwetcBuilder.LinkedinIconSrc.color_border == linkedin.icon) ? 'selected' : '';
        output += ' >Color border</option><option value="' + IwetcBuilder.LinkedinIconSrc.color_white + '" ';
        output += (IwetcBuilder.LinkedinIconSrc.color_white == linkedin.icon) ? 'selected' : '';
        output += ' >Color white</option><option value="' + IwetcBuilder.LinkedinIconSrc.black_white + '" ';
        output += (IwetcBuilder.LinkedinIconSrc.black_white == linkedin.icon) ? 'selected' : '';
        output += ' >Black white</option><option value="' + IwetcBuilder.LinkedinIconSrc.white_color + '" ';
        output += (IwetcBuilder.LinkedinIconSrc.white_color == linkedin.icon) ? 'selected' : '';
        output += ' >White color</option>' +
            '</select>' +
            '</div>' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Link</label>' +
            '<input type="text" value="' + linkedin.link + '" placeholder="Link ..." class="iwetc-builder-editor-input" data-type="attribute" data-property="href" data-target="[data-name=\'socials_linkedin_link\']">' +
            '</div>' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Target</label>' +
            '<select class="iwetc-builder-editor-input" data-type="attribute" data-property="target" data-target="[data-name=\'socials_linkedin_link\']">' +
            '<option value="_blank" ';
        output += (linkedin.target == '_blank') ? 'selected' : '';
        output += '>_blank</option><option value="_self" ';
        output += (linkedin.target == '_self') ? 'selected' : '';
        output += '>_self</option><option value="_parent" ';
        output += (linkedin.target == '_parent') ? 'selected' : '';
        output += '>_parent</option><option value="_top" ';
        output += (linkedin.target == '_top') ? 'selected' : '';
        output += '>_top</option>' +
            '</select>' +
            '</div>' +
            '</div>' +

            '<div class="iwetc-builder-left-sidebar-subsection">' +
            '<div class="iwetc-builder-left-sidebar-subsection-title"><input type="checkbox" class="iwetc-builder-editor-input" data-type="add_remove_social_item" data-property="socials_whatsapp" ' + whatsapp.checked + '><span>Whatsapp</span></div>' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Icon</label>' +
            '<select class="iwetc-builder-editor-input" data-type="attribute" data-property="src" data-target="[data-name=\'socials_whatsapp_image\']"><option value="' + IwetcBuilder.WhatsappIconSrc.black + '" ';
        output += (IwetcBuilder.WhatsappIconSrc.black == whatsapp.icon) ? 'selected' : '';
        output += ' >Black</option><option value="' + IwetcBuilder.WhatsappIconSrc.white + '" ';
        output += (IwetcBuilder.WhatsappIconSrc.white == whatsapp.icon) ? 'selected' : '';
        output += ' >White</option><option value="' + IwetcBuilder.WhatsappIconSrc.color + '" ';
        output += (IwetcBuilder.WhatsappIconSrc.color == whatsapp.icon) ? 'selected' : '';
        output += ' >Color</option><option value="' + IwetcBuilder.WhatsappIconSrc.white_border + '" ';
        output += (IwetcBuilder.WhatsappIconSrc.white_border == whatsapp.icon) ? 'selected' : '';
        output += ' >White border</option><option value="' + IwetcBuilder.WhatsappIconSrc.black_border + '" ';
        output += (IwetcBuilder.WhatsappIconSrc.black_border == whatsapp.icon) ? 'selected' : '';
        output += ' >Black border</option><option value="' + IwetcBuilder.WhatsappIconSrc.color_border + '" ';
        output += (IwetcBuilder.WhatsappIconSrc.color_border == whatsapp.icon) ? 'selected' : '';
        output += ' >Color border</option><option value="' + IwetcBuilder.WhatsappIconSrc.color_white + '" ';
        output += (IwetcBuilder.WhatsappIconSrc.color_white == whatsapp.icon) ? 'selected' : '';
        output += ' >Color white</option><option value="' + IwetcBuilder.WhatsappIconSrc.black_white + '" ';
        output += (IwetcBuilder.WhatsappIconSrc.black_white == whatsapp.icon) ? 'selected' : '';
        output += ' >Black white</option><option value="' + IwetcBuilder.WhatsappIconSrc.white_color + '" ';
        output += (IwetcBuilder.WhatsappIconSrc.white_color == whatsapp.icon) ? 'selected' : '';
        output += ' >White color</option>' +
            '</select>' +
            '</div>' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Link</label>' +
            '<input type="text" value="' + whatsapp.link + '" placeholder="Link ..." class="iwetc-builder-editor-input" data-type="attribute" data-property="href" data-target="[data-name=\'socials_whatsapp_link\']">' +
            '</div>' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Target</label>' +
            '<select class="iwetc-builder-editor-input" data-type="attribute" data-property="target" data-target="[data-name=\'socials_whatsapp_link\']">' +
            '<option value="_blank" ';
        output += (whatsapp.target == '_blank') ? 'selected' : '';
        output += '>_blank</option><option value="_self" ';
        output += (whatsapp.target == '_self') ? 'selected' : '';
        output += '>_self</option><option value="_parent" ';
        output += (whatsapp.target == '_parent') ? 'selected' : '';
        output += '>_parent</option><option value="_top" ';
        output += (whatsapp.target == '_top') ? 'selected' : '';
        output += '>_top</option>' +
            '</select>' +
            '</div>' +
            '</div>';

        return output;
    }
});
IwetcBuilder.Property.addProperty({
    name: 'coupon_type',
    label: IwetcBuilder.Translate.coupon_type,
    getHtml: function (element) {
        let couponType = element.attr('data-coupon-type');
        let discountType = element.attr('data-discount-type');
        let amount = element.attr('data-coupon-amount');
        let expireAfterDays = element.attr('data-expire-after-days');
        let minimumSpend = element.attr('data-minimum-spend');
        let maximumSpend = element.attr('data-maximum-spend');
        let limitPerCoupon = element.attr('data-limit-per-coupon');
        let limitPerUser = element.attr('data-limit-per-user');
        let limitUsageItems = element.attr('data-limit-usage-items');
        let productIds = element.attr('data-products').split(',');
        let excludeProductIds = element.attr('data-exclude-products').split(',');
        let categoryIds = element.attr('data-categories').split(',');
        let excludeCategoryIds = element.attr('data-exclude-categories').split(',');
        let freeShipping = element.attr('data-allow-free-shipping');
        let individualUse = element.attr('data-individual-use');
        let excludeSaleItems = element.attr('data-exclude-sale-items');
        let couponCode = element.attr('data-coupon-code');

        let output = '<div class="iwetc-builder-left-sidebar-subsection">' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Type</label>' +
            '<select class="iwetc-builder-editor-input iwetc-builder-change-coupon-type" data-type="attribute" data-property="data-coupon-type"><option value="existing_coupon" ';
        output += (couponType == 'existing_coupon') ? 'selected' : '';
        output += '>Existing coupon</option><option value="generate_coupon" ';
        output += (couponType == 'generate_coupon') ? 'selected' : '';
        output += '>Generate coupon</option></select></div>';

        // existing coupon field
        output += '<div class="iwetc-builder-col-12 iwetc-existing-coupon" style="display: ';
        output += (couponType == 'existing_coupon') ? 'block' : 'none';
        output += ';">' +
            '<label>Select coupon</label>' +
            '<select class="iwetc-select2-coupons" style="width: 100%;">';
        if (couponCode !== 'Coupon Code') {
            output += '<option value="' + couponCode + '" selected>' + couponCode + '</option>';
        }
        output += '</select></div>';

        //  generate coupon fields
        output += '<div class="iwetc-generate-coupon" style="display: ';
        output += (couponType == 'generate_coupon') ? 'block' : 'none';
        output += ';">' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Discount type</label>' +
            '<select class="iwetc-builder-editor-input" data-type="attribute" data-property="data-discount-type"><option value="percentage" ';
        output += (discountType == 'percentage') ? 'selected' : '';
        output += '>Percentage discount</option><option value="fixed_cart" ';
        output += (discountType == 'fixed_cart') ? 'selected' : '';
        output += '>Fixed cart discount</option><option value="fixed_product" ';
        output += (discountType == 'fixed_product') ? 'selected' : '';
        output += '>Fixed product discount</option></select></div>' +

            '<div class="iwetc-builder-col-12">' +
            '<label>Coupon amount</label>' +
            '<input type="number" min="0" class="iwetc-builder-editor-input" value="' + amount + '" data-type="attribute" data-property="data-coupon-amount">' +
            '</div>' +

            '<div class="iwetc-builder-col-12">' +
            '<label>Expire after x days</label>' +
            '<input type="number" min="0" class="iwetc-builder-editor-input" data-type="attribute" value="' + expireAfterDays + '" data-property="data-expire-after-days">' +
            '</div>' +

            '<div class="iwetc-builder-col-12">' +
            '<label>Minimum spend</label>' +
            '<input type="number" min="0" class="iwetc-builder-editor-input" data-type="attribute" value="' + minimumSpend + '" data-property="data-minimum-spend">' +
            '</div>' +

            '<div class="iwetc-builder-col-12">' +
            '<label>Maximum spend</label>' +
            '<input type="number" min="0" class="iwetc-builder-editor-input" data-type="attribute" value="' + maximumSpend + '" data-property="data-maximum-spend">' +
            '</div>' +

            '<div class="iwetc-builder-col-12">' +
            '<label>Usage limit per coupon</label>' +
            '<input type="number" min="0" class="iwetc-builder-editor-input" data-type="attribute" value="' + limitPerCoupon + '" data-property="data-limit-per-coupon">' +
            '</div>' +

            '<div class="iwetc-builder-col-12">' +
            '<label>Limit usage to x items</label>' +
            '<input type="number" min="0" class="iwetc-builder-editor-input" data-type="attribute" value="' + limitUsageItems + '" data-property="data-limit-usage-items">' +
            '</div>' +

            '<div class="iwetc-builder-col-12">' +
            '<label>Usage limit per user</label>' +
            '<input type="number" min="0" class="iwetc-builder-editor-input" data-type="attribute" value="' + limitPerUser + '" data-property="data-limit-per-user">' +
            '</div>' +

            '<div class="iwetc-builder-col-12">' +
            '<label>Products</label>' +
            '<select class="iwetc-select2-products iwetc-builder-editor-input" style="width: 100%;" data-type="attribute" data-property="data-products" multiple>';
        if (jQuery.isArray(productIds) && productIds.length > 0) {
            jQuery.each(productIds, function (i, productId) {
                if (productId) {
                    output += '<option value="' + parseInt(productId) + '" selected>' + IwetcBuilder.Products[productId] + '</option>';
                }
            });
        }
        output += '</select>' +
            '</div>' +

            '<div class="iwetc-builder-col-12">' +
            '<label>Exclude products</label>' +
            '<select class="iwetc-select2-products iwetc-builder-editor-input" style="width: 100%;" data-type="attribute" data-property="data-exclude-products" multiple>';
        if (jQuery.isArray(excludeProductIds) && excludeProductIds.length > 0) {
            jQuery.each(excludeProductIds, function (i, productId) {
                if (productId) {
                    output += '<option value="' + parseInt(productId) + '" selected>' + IwetcBuilder.Products[productId] + '</option>';
                }
            });
        }
        output += '</select>' +
            '</div>' +

            '<div class="iwetc-builder-col-12">' +
            '<label>Categories</label>' +
            '<select class="iwetc-select2-product-categories iwetc-builder-editor-input" style="width: 100%;" data-type="attribute" data-property="data-categories" multiple>';
        if (jQuery.isArray(categoryIds) && categoryIds.length > 0) {
            jQuery.each(categoryIds, function (i, categoryId) {
                if (categoryId) {
                    output += '<option value="' + parseInt(categoryId) + '" selected>' + IwetcBuilder.ProductCategories[categoryId] + '</option>';
                }
            });
        }
        output += '</select>' +
            '</div>' +

            '<div class="iwetc-builder-col-12">' +
            '<label>Exclude categories</label>' +
            '<select class="iwetc-select2-product-categories iwetc-builder-editor-input" style="width: 100%;" data-type="attribute" data-property="data-exclude-categories" multiple>';
        if (jQuery.isArray(excludeCategoryIds) && excludeCategoryIds.length > 0) {
            jQuery.each(excludeCategoryIds, function (i, categoryId) {
                if (categoryId) {
                    output += '<option value="' + parseInt(categoryId) + '" selected>' + IwetcBuilder.ProductCategories[categoryId] + '</option>';
                }
            });
        }
        output += '</select>' +
            '</div>' +

            '<div class="iwetc-builder-col-12">' +
            '<label>Allow free shipping</label>' +
            '<input type="checkbox" class="iwetc-builder-properties-right-checkbox iwetc-builder-editor-input" data-type="attribute" data-property="data-allow-free-shipping" ';
        output += (freeShipping && freeShipping == 'true') ? 'checked="checked"' : '';
        output += '>' +
            '</div>' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Individual use only</label>' +
            '<input type="checkbox" class="iwetc-builder-properties-right-checkbox iwetc-builder-editor-input" data-type="attribute" data-property="data-individual-use" ';
        output += (individualUse && individualUse == 'true') ? 'checked="checked"' : '';
        output += '>' +
            '</div>' +
            '<div class="iwetc-builder-col-12">' +
            '<label>Exclude sale items</label>' +
            '<input type="checkbox" class="iwetc-builder-properties-right-checkbox iwetc-builder-editor-input" data-type="attribute" data-property="data-exclude-sale-items" ';
        output += (excludeSaleItems && excludeSaleItems == 'true') ? 'checked="checked"' : '';
        output += '>' +
            '</div>' +

            '</div>' +
            '</div>';

        return output;
    }
});
IwetcBuilder.Property.addProperty({
    name: 'coupon_text_editor',
    label: IwetcBuilder.Translate.text_editor,
    getHtml: function (element) {
        setTimeout(function () {
            iwetcTinyMceSetContent('iwetc-coupon-text-editor', element.html());
        }, 350);
        return '<textarea id="iwetc-coupon-text-editor" class="iwetc-builder-editor-input"></textarea>';
    }
});
IwetcBuilder.Property.addProperty({
    name: 'contact_icon_size',
    label: IwetcBuilder.Translate.icon_size,
    getHtml: function (element) {
        let width = 20;

        if (element.find('img').length > 0) {
            width = parseInt(element.find('img').first().css('width'));
        }

        return '<div class="iwetc-contact-icon-size"><div class="iwetc-builder-col-12">' +
            '<label>Width (px)</label>' +
            '<input type="range" min="0" max="100" value="' + width + '" placeholder="150" class="iwetc-builder-editor-input iwetc-slider-number-input iwetc-slider-number-input" data-type="style" data-target="img" data-property="width" data-unit="px" data-target="img">' +
            '<span class="iwetc-slider-number-preview">' + width + '</span>' +
            '</div>' +
            '</div>';
    }
});
IwetcBuilder.Property.addProperty({
    name: 'image_border_radius',
    label: IwetcBuilder.Translate.border_radius,
    getHtml: function (element) {
        let image = element.find('img');

        let borderRadiusProportion = element.attr('data-border-radius-proportion');
        let borderRadiusProportionChecked = '',
            borderRadiusProportionClassName = '',
            borderRadiusProportionIcon = IwetcBuilder.unlinkIcon;

        if (typeof borderRadiusProportion === 'undefined' || borderRadiusProportion == 'true') {
            borderRadiusProportionChecked = 'checked="checked"';
            borderRadiusProportionClassName = 'iwetc-proportion-enable';
            borderRadiusProportionIcon = IwetcBuilder.linkIcon;
        }

        let borderTopLeftRadius = (image.css('border-top-left-radius')) ? parseInt(image.css('border-top-left-radius')) : 0;
        let borderTopRightRadius = (image.css('border-top-right-radius')) ? parseInt(image.css('border-top-right-radius')) : 0;
        let borderBottomLeftRadius = (image.css('border-bottom-left-radius')) ? parseInt(image.css('border-bottom-left-radius')) : 0;
        let borderBottomRightRadius = (image.css('border-bottom-right-radius')) ? parseInt(image.css('border-bottom-right-radius')) : 0;

        let output = '<div class="iwetc-builder-left-sidebar-subsection iwetc-constrain-proportion-container">' +
            '<div class="iwetc-builder-col-2-5">' +
            '<label>T-L</label>' +
            '<input type="number" min="0" value="' + borderTopLeftRadius + '" placeholder="0" class="iwetc-builder-editor-input iwetc-has-proportion" data-type="style" data-property="border-top-left-radius" data-target="img" data-unit="px">' +
            '</div>' +
            '<div class="iwetc-builder-col-2-5">' +
            '<label>T-R</label>' +
            '<input type="number" min="0" value="' + borderTopRightRadius + '" placeholder="0" class="iwetc-builder-editor-input iwetc-has-proportion" data-type="style" data-property="border-top-right-radius" data-target="img" data-unit="px">' +
            '</div>' +
            '<div class="iwetc-builder-col-2-5">' +
            '<label>B-R</label>' +
            '<input type="number" min="0" value="' + borderBottomRightRadius + '" placeholder="0" class="iwetc-builder-editor-input iwetc-has-proportion" data-type="style" data-property="border-bottom-right-radius" data-target="img" data-unit="px">' +
            '</div>' +
            '<div class="iwetc-builder-col-2-5">' +
            '<label>B-L</label>' +
            '<input type="number" min="0" value="' + borderBottomLeftRadius + '" placeholder="0" class="iwetc-builder-editor-input iwetc-has-proportion" data-type="style" data-property="border-bottom-left-radius" data-target="img" data-unit="px">' +
            '</div>' +
            '<div class="iwetc-constrain-proportion-field">' +
            '<label class="';
        output += borderRadiusProportionClassName;
        output += '"><strong></strong><span>' + borderRadiusProportionIcon +
            '<input type="checkbox" class="iwetc-constrain-proportion iwetc-builder-editor-input" data-type="attribute" data-property="data-border-radius-proportion" ';
        output += borderRadiusProportionChecked;
        output += '></span></label>' +
            '</div>' +
            '</div>';

        return output;
    }
});
IwetcBuilder.Property.addProperty({
    name: 'socials_icon_size',
    label: IwetcBuilder.Translate.icon_size,
    getHtml: function (element) {
        let width = 20;

        if (element.find('img').length > 0) {
            width = parseInt(element.find('img').first().css('width'));
        }

        return '<div class="iwetc-contact-icon-size"><div class="iwetc-builder-col-12">' +
            '<label>Width (px)</label>' +
            '<input type="range" min="0" max="100" value="' + width + '" placeholder="150" class="iwetc-builder-editor-input iwetc-slider-number-input" data-type="style" data-property="width" data-unit="px" data-target="img">' +
            '<span class="iwetc-slider-number-preview">' + width + '</span>' +
            '</div>' +
            '</div>';
    }
});
IwetcBuilder.Property.addProperty({
    name: 'socials_style',
    label: IwetcBuilder.Translate.style,
    getHtml: function (element) {
        let style = element.find('ul').attr('data-style');

        let output = '<div class="iwetc-builder-left-sidebar-subsection">' +
            '<div class="iwetc-builder-col-12">' +
            '<select class="iwetc-builder-editor-input iwetc-builder-socials-style" data-type="attribute" data-property="data-style" data-target="ul">' +
            '<option value="style_1" ';
        output += (style == 'style_1') ? 'selected' : '';
        output += '>Style 1</option><option value="style_2" ';
        output += (style == 'style_2') ? 'selected' : '';
        output += '>Style 2</option>' +
            '</select>' +
            '</div>' +
            '</div>';

        return output;
    }
});