<?php

namespace iwetcl\classes\bootstrap;

use iwetcl\classes\controllers\Activation_Controller;
use iwetcl\classes\controllers\Email_Builder;
use iwetcl\classes\helpers\Path_Helper;
use iwetcl\classes\requests\Ajax_Handler;
use iwetcl\classes\requests\Post_Handler;

class IWETCL
{
    private static $instance;

    public static function init()
    {
        if (is_null(self::$instance)) {
            self::$instance = new self();
        }
    }

    private function __construct()
    {
        IWETCL_Email_Trigger::init();

        if (!current_user_can('manage_woocommerce')) {
            return;
        }

        add_action('admin_menu', [$this, 'add_admin_menu']);

        Ajax_Handler::register_callback();
        Post_Handler::register_callback();

        if (IWETCL_Verification::is_active()) {
            IWETCL_Custom_Query::init();
            Email_Builder::init();
        }
    }

    public function add_admin_menu()
    {
        if (IWETCL_Verification::is_active()) {
            add_menu_page(__('iT Email Customizer', 'ithemeland-woocommerce-email-template-customizer-lite'), sprintf('%s', '<span style="color: #627ddd;font-weight: 900;">iT</span> Email Customizer'), 'manage_options', 'edit.php?post_type=iwetc_emails', '', IWETCL_IMAGES_URL . 'iwetc_icon.png', 2);
            add_submenu_page('edit.php?post_type=iwetc_emails', __('All Emails', 'ithemeland-woocommerce-email-template-customizer-lite'), __('All Emails', 'ithemeland-woocommerce-email-template-customizer-lite'), 'manage_options', 'edit.php?post_type=iwetc_emails', '', 1);
            add_submenu_page('edit.php?post_type=iwetc_emails', __('Add New Email', 'ithemeland-woocommerce-email-template-customizer-lite'), __('Add New Email', 'ithemeland-woocommerce-email-template-customizer-lite'), 'manage_options', 'post-new.php?post_type=iwetc_emails', '', 2);
            if (!Path_Helper::isAllowedDomain()) {
                add_submenu_page('edit.php?post_type=iwetc_emails', __('Active plugin', 'ithemeland-woocommerce-email-template-customizer-lite'), __('Active plugin', 'ithemeland-woocommerce-email-template-customizer-lite'), 'manage_options', 'iwetc_activation', [new Activation_Controller(), 'index'], 15);
            }
        } else {
            add_menu_page(__('iT Email Customizer', 'ithemeland-woocommerce-email-template-customizer-lite'), sprintf('%s', '<span style="color: #627ddd;font-weight: 900;">iT</span> Email Customizer'), 'manage_options', 'iwetc_activation', [new Activation_Controller(), 'index'], IWETCL_IMAGES_URL . 'iwetc_icon.png', 2);
        }
    }

    public static function iwetcl_woocommerce_required()
    {
        include IWETCL_VIEWS_DIR . 'alerts/iwetcl_woocommerce_required.php';
    }

    public static function iwetcl_wp_init()
    {
        // load textdomain
        load_plugin_textdomain('ithemeland-woocommerce-email-template-customizer-lite', false, IWETCL_LANGUAGES_DIR);
    }

    public static function activate()
    {
        //
    }

    public static function deactivate()
    {
        //
    }
}
