<?php

namespace iwetcl\classes\bootstrap;

class IWETCL_Custom_Query
{
    private static $instance;

    public static function init()
    {
        if (is_null(self::$instance)) {
            self::$instance = new self();
        }

        return self::$instance;
    }

    private function __construct()
    {
        add_filter('posts_where', [$this, 'general_column_filter'], 10, 2);
    }

    public function general_column_filter($where, $wp_query)
    {
        global $wpdb;
        if (!($search_term = $wp_query->get('iwetc_general_column_filter'))) {
            return $where;
        }

        if (is_array($search_term) && count($search_term) > 0) {
            foreach ($search_term as $item) {
                $field = esc_sql($item['field']);
                $value = (is_array($item['value'])) ? esc_sql($item['value']) : trim(esc_sql($item['value']));
                switch ($item['operator']) {
                    case 'like':
                        $custom_where = "({$wpdb->posts}.{$field} LIKE '%{$value}%')";
                        break;
                    case 'exact':
                        $custom_where = "({$wpdb->posts}.{$field} = '{$value}')";
                        break;
                    case 'not':
                        $custom_where = "({$wpdb->posts}.{$field} != '{$value}')";
                        break;
                    case 'begin':
                        $custom_where = "({$wpdb->posts}.{$field} LIKE '{$value}%')";
                        break;
                    case 'end':
                        $custom_where = "({$wpdb->posts}.{$field} LIKE '%{$value}')";
                        break;
                    case 'in':
                        $custom_where = "({$wpdb->posts}.{$field} IN ({$value}))";
                        break;
                    case 'or':
                        if (is_array($value)) {
                            $custom_where = "(";
                            $i = 1;
                            foreach ($value as $value_item) {
                                $custom_where .= "({$wpdb->posts}.{$field} = '{$value_item}')";
                                if (count($value) > $i) {
                                    $custom_where .= " OR ";
                                }
                                $i++;
                            }
                            $custom_where .= ")";
                        }
                        break;
                    case 'not_in':
                        $custom_where = "({$wpdb->posts}.{$field} NOT IN ({$value}))";
                        break;
                    case 'between':
                        $value = (is_numeric($value[1])) ? "{$value[0]} AND {$value[1]}" : "'{$value[0]}' AND '{$value[1]}'";
                        $custom_where = "({$wpdb->posts}.{$field} BETWEEN {$value})";
                        break;
                    case '>':
                        $custom_where = "({$wpdb->posts}.{$field} > {$value})";
                        break;
                    case '<':
                        $custom_where = "({$wpdb->posts}.{$field} < {$value})";
                        break;
                    case '>_with_quotation':
                        $custom_where = "({$wpdb->posts}.{$field} > '{$value}')";
                        break;
                    case '<_with_quotation':
                        $custom_where = "({$wpdb->posts}.{$field} < '{$value}')";
                        break;
                }
            }
        }

        if (!empty($custom_where)) {
            $where .= ' AND ' . $custom_where;
        }

        return $where;
    }
}
