<?php

namespace iwetcl\classes\bootstrap;

use iwetcl\classes\helpers\Shortcode_Helper;
use iwetcl\classes\repositories\builder\Email_Template;
use iwetcl\classes\repositories\Order;
use iwetcl\classes\services\render\Email_Render;

class IWETCL_Email_Trigger
{
    private static $instance;
    private $template;
    private $object;
    private $object_type;
    private $email_id;
    private $shortcode;

    public static function init()
    {
        if (is_null(self::$instance)) {
            self::$instance = new self();
        }

        return self::$instance;
    }

    private function __construct()
    {
        $this->shortcode = Shortcode_Helper::get_instance();

        add_action('woocommerce_email', [$this, 'get_email_ids'], PHP_INT_MAX);
        add_filter('woocommerce_mail_content', [$this, 'set_email_content'], PHP_INT_MAX);

        add_filter('wp_new_user_notification_email', [$this, 'set_new_user_email_template'], PHP_INT_MAX, 3);
    }

    public function set_new_user_email_template($wp_new_user_notification_email, $user, $blogname)
    {
        $this->email_id = 'customer_new_account';

        $email_repository = Email_Template::get_instance();
        $this->template = $email_repository->get_email_by_type($this->email_id);

        $this->shortcode->set_data([
            'user_object' => $user
        ]);

        if (!empty($this->template)) {
            $wp_new_user_notification_email['headers'] = ["Content-Type: text/html"];
            $wp_new_user_notification_email['subject'] = $this->shortcode->replace($this->template['subject']);

            $email_render = new Email_Render([
                'object_type' => 'user',
                'object' => $user,
                'render_type' => 'wc_action',
                'custom_css' => $this->template['custom_css'],
                'direction' => $this->template['direction'],
                'email_structure' => $this->template['structure'],
            ]);

            $rendered = $email_render->render();
            if (!empty($rendered)) {
                $wp_new_user_notification_email['message'] = $rendered;
            }
        }

        return $wp_new_user_notification_email;
    }

    public function get_email_ids($email_object)
    {
        if (is_array($email_object->emails)) {
            foreach ($email_object->emails as $email) {
                add_filter('woocommerce_email_recipient_' . $email->id, [$this, 'trigger_recipient'], 20, 3);
                add_filter('woocommerce_email_subject_' . $email->id, [$this, 'set_email_subject']);
            }
        }
        add_filter('woocommerce_email_recipient_customer_partially_refunded_order', array($this, 'trigger_recipient'), 20, 3);
    }

    public function trigger_recipient($recipient, $object, $email)
    {
        $email_repository = Email_Template::get_instance();
        $email_template = $email_repository->get_email_by_type($email->id);
        if (!empty($email_template)) {
            $this->email_id = $email->id;
            $this->template = $email_template;
            $this->object = $object;
            $this->object_type = ($object instanceof \WP_User) ? 'user' : 'order';
        }

        return $recipient;
    }

    public function set_email_subject($subject)
    {
        $data = [];

        if ($this->object instanceof \WC_Order) {
            $data = [
                'order_object' => $this->object,
                'user_object' => $this->object->get_user(),
            ];
        }

        if ($this->object instanceof \WP_User) {
            $data = [
                'user_object' => $this->object
            ];
        }

        $this->shortcode->set_data($data);
        return (!empty($this->template)) ? $this->shortcode->replace($this->template['subject']) : $subject;
    }

    public function set_email_content($message)
    {
        if (!empty($this->template)) {
            $email_render = new Email_Render([
                'object_type' => $this->object_type,
                'object' => $this->object,
                'render_type' => 'wc_action',
                'custom_css' => $this->template['custom_css'],
                'direction' => $this->template['direction'],
                'email_structure' => $this->template['structure'],
            ]);

            $rendered = $email_render->render();
            if (!empty($rendered)) {
                $message = $rendered;
            }
        }

        return $message;
    }
}
