<?php

namespace iwetcl\classes\helpers;

class Sanitizer
{
    public static function array($input)
    {
        $sanitized = null;

        if (is_array($input) && count($input)) {
            foreach ($input as $key => $value) {
                $sanitized[sanitize_text_field($key)] = (is_array($value)) ? self::array($value) : sprintf("%s", stripslashes($value));
            }
        }

        return $sanitized;
    }

    public static function number($input)
    {
        return filter_var($input, FILTER_SANITIZE_NUMBER_FLOAT, FILTER_FLAG_ALLOW_FRACTION);
    }

    public static function attribute($input)
    {
        return sprintf('%s', str_replace("\'", "'", str_replace('\"', "'", str_replace('\\\"', "'", $input))));
    }

    public static function html($input)
    {
        return sprintf('%s', str_replace("\'", "'", str_replace('\\\"', "'", $input)));
    }

    public static function array_flatten($array, $sanitize = null)
    {
        if (!is_array($array)) {
            return false;
        }
        $result = array();
        foreach ($array as $key => $value) {
            if (is_array($value)) {
                $result = array_merge($result, self::array_flatten($value, $sanitize));
            } else {
                switch ($sanitize) {
                    case 'int':
                        $result = array_merge($result, array($key => intval($value)));
                        break;
                    default:
                        $result = array_merge($result, array($key => $value));
                        break;
                }
            }
        }
        return $result;
    }
}
