<?php

namespace iwetcl\classes\helpers;

use stdClass;

class Shortcode_Helper
{
    private static $instance;

    private $password_reset_key;
    private $user_object;
    private $order_object;

    public static function get_instance()
    {
        if (is_null(self::$instance)) {
            self::$instance = new self();
        }

        return self::$instance;
    }

    private function __construct()
    {
    }

    public function set_data($data)
    {
        $this->password_reset_key = '';

        if (!empty($data['user_object']) && $data['user_object'] instanceof \WP_User) {
            $this->user_object = $data['user_object'];
            $this->password_reset_key = (isset($data['password_reset_key']) && $data['password_reset_key'] === true) ? get_password_reset_key($this->user_object) : '';
        } else {
            $this->user_object = new stdClass;
            $this->user_object->ID = 0;
            $this->user_object->display_name = 'Guest';
            $this->user_object->user_login = '';
            $this->user_object->user_email = '';
            $this->user_object->first_name = '';
            $this->user_object->last_name = '';
        }

        if (!empty($data['order_object']) && $data['order_object'] instanceof \WC_Order) {
            $this->order_object = $data['order_object'];

            if (!($this->user_object instanceof \WP_User)) {
                $this->user_object->ID = 0;
                $this->user_object->display_name = (!empty($this->order_object->get_shipping_first_name())) ? $this->order_object->get_shipping_first_name() . ' ' . $this->order_object->get_shipping_last_name() : 'Guest';
                $this->user_object->user_email = $this->order_object->get_billing_email();
                $this->user_object->first_name = $this->order_object->get_shipping_first_name();
                $this->user_object->last_name = $this->order_object->get_shipping_last_name();
            }
        }
    }

    public function replace($string)
    {
        $shortcodes = self::get_shortcodes();

        if (!empty($shortcodes)) {
            foreach ($shortcodes as $key => $value) {
                if (strpos($string, $key) !== false) {
                    $string = str_replace($key, $value, $string);
                }
            }
        }

        return $string;
    }

    private function get_shortcodes()
    {
        $date_format = get_option('date_format', 'Y-m-d');
        $shop_url = wc_get_page_permalink('shop');
        $my_account_url = wc_get_page_permalink('myaccount');
        $checkout_url  = wc_get_checkout_url();

        $shortcodes =  [
            '{admin_email}' => get_option('admin_email', ''),
            '{site_title}' => get_bloginfo('name'),
            '{home_url}' => home_url(),
            '{site_url}' => site_url(),
            '{shop_url}' => $shop_url ? $shop_url : home_url(),
            '{myaccount_url}' => $my_account_url ? $my_account_url : home_url(),
            '{checkout_url}' => $checkout_url ? $checkout_url : home_url(),

            '{customer_name}' => (!empty($this->user_object->display_name)) ? $this->user_object->display_name : '',
            '{customer_note}' => '',
            '{first_name}' => (!empty($this->user_object->first_name)) ? $this->user_object->first_name : $this->user_object->display_name,
            '{last_name}' => (!empty($this->user_object->last_name)) ? $this->user_object->last_name : '',
            '{order_date}' => '',
            '{order_discount}' => '',
            '{order_fully_refund}' => '',
            '{order_number}' => '',
            '{order_partial_refund}' => '',
            '{order_received_url}' => '',
            '{order_shipping}' => '',
            '{order_subtotal}' => '',
            '{order_total}' => '',
            '{order_tax}' => '',
            '{payment_method}' => '',
            '{payment_url}' => '',
            '{user_email}' => $this->user_object->user_email,

            '{billing_first_name}' => '',
            '{billing_last_name}' => '',
            '{billing_company}' => '',
            '{billing_country}' => '',
            '{billing_address}' => '',
            '{billing_address_1}' => '',
            '{billing_address_2}' => '',
            '{billing_postcode}' => '',
            '{billing_city}' => '',
            '{billing_state}' => '',
            '{billing_email}' => '',
            '{billing_phone}' => '',

            '{shipping_first_name}' => '',
            '{shipping_last_name}' => '',
            '{shipping_company}' => '',
            '{shipping_country}' => '',
            '{shipping_address}' => '',
            '{shipping_address_1}' => '',
            '{shipping_address_2}' => '',
            '{shipping_postcode}' => '',
            '{shipping_city}' => '',
            '{shipping_state}' => '',
            '{shipping_method}' => '',

            '{reset_password_url}' => esc_url(add_query_arg(array('key' => $this->password_reset_key, 'id' => $this->user_object->ID), wc_get_endpoint_url('lost-password', '', wc_get_page_permalink('myaccount')))),
            '{user_login}' => $this->user_object->user_login,
        ];

        if (!empty($this->order_object)) {
            $refunds = $this->order_object->get_refunds();
            $refund_html = '';
            if ($refunds) {
                foreach ($refunds as $id => $refund) {
                    $refund_html .= '<div>' . wc_price('-' . $refund->get_amount(), array('currency' => $this->order_object->get_currency())) . '</div>';
                }
            }

            // set order tax
            if ('excl' === get_option('woocommerce_tax_display_cart') && wc_tax_enabled()) {
                if ('itemized' === get_option('woocommerce_tax_total_display')) {
                    $taxes = [];
                    foreach ($this->order_object->get_tax_totals() as $key => $tax) {
                        $taxes[] = $tax->label . ' : ' . $tax->formatted_amount;
                    }
                    $tax = implode(',', $taxes);
                } else {
                    $tax = wc_price($this->order_object->get_total_tax(), ['currency' => $this->order_object->get_currency()]);
                }
            }

            $shortcodes['{customer_name}'] = $this->order_object->get_formatted_billing_full_name();
            $shortcodes['{customer_note}'] = $this->order_object->get_customer_note();
            $shortcodes['{first_name}'] = $this->order_object->get_billing_first_name();
            $shortcodes['{last_name}'] = $this->order_object->get_billing_last_name();
            $shortcodes['{order_id}'] = intval($this->order_object->get_id());
            $shortcodes['{order_date}'] = date_i18n($date_format, strtotime($this->order_object->get_date_created()));
            $shortcodes['{order_discount}'] = $this->order_object->get_discount_to_display();
            $shortcodes['{order_fully_refund}'] = $refund_html;
            $shortcodes['{order_number}'] = $this->order_object->get_order_number();
            $shortcodes['{order_partial_refund}'] = $refund_html;
            $shortcodes['{order_received_url}'] = $this->order_object->get_checkout_order_received_url();
            $shortcodes['{order_shipping}'] = $this->order_object->get_shipping_to_display();
            $shortcodes['{order_subtotal}'] = $this->order_object->get_subtotal_to_display();
            $shortcodes['{order_total}'] = $this->order_object->get_formatted_order_total();
            $shortcodes['{order_tax}'] = (isset($tax)) ? $tax : '';
            $shortcodes['{payment_method}'] = (!empty($this->order_object->get_payment_method_title())) ? $this->order_object->get_payment_method_title() : '';
            $shortcodes['{payment_url}'] = $this->order_object->get_checkout_payment_url();
            $shortcodes['{user_email}'] = $this->order_object->get_billing_email();

            $shortcodes['{billing_first_name}'] = $this->order_object->get_billing_first_name();
            $shortcodes['{billing_last_name}'] = $this->order_object->get_billing_last_name();
            $shortcodes['{billing_company}'] = $this->order_object->get_billing_company();
            $shortcodes['{billing_country}'] = $this->order_object->get_billing_country();
            $shortcodes['{billing_address}'] = $this->order_object->get_formatted_billing_address();
            $shortcodes['{billing_address_1}'] = $this->order_object->get_billing_address_1();
            $shortcodes['{billing_address_2}'] = $this->order_object->get_billing_address_2();
            $shortcodes['{billing_postcode}'] = $this->order_object->get_billing_postcode();
            $shortcodes['{billing_city}'] = $this->order_object->get_billing_city();
            $shortcodes['{billing_state}'] = $this->order_object->get_billing_state();
            $shortcodes['{billing_email}'] = $this->order_object->get_billing_email();
            $shortcodes['{billing_phone}'] = $this->order_object->get_billing_phone();

            $shortcodes['{shipping_first_name}'] = $this->order_object->get_shipping_first_name();
            $shortcodes['{shipping_last_name}'] = $this->order_object->get_shipping_last_name();
            $shortcodes['{shipping_company}'] = $this->order_object->get_shipping_company();
            $shortcodes['{shipping_country}'] = $this->order_object->get_shipping_country();
            $shortcodes['{shipping_address}'] = $this->order_object->get_formatted_shipping_address();
            $shortcodes['{shipping_address_1}'] = $this->order_object->get_shipping_address_1();
            $shortcodes['{shipping_address_2}'] = $this->order_object->get_shipping_address_2();
            $shortcodes['{shipping_postcode}'] = $this->order_object->get_shipping_postcode();
            $shortcodes['{shipping_city}'] = $this->order_object->get_shipping_city();
            $shortcodes['{shipping_state}'] = $this->order_object->get_shipping_state();
            $shortcodes['{shipping_method}'] = $this->order_object->get_shipping_method();
        }

        return $shortcodes;
    }
}
