<?php

namespace iwetcl\classes\repositories;

class Coupon
{
    private static $instance;

    public static function get_instance()
    {
        if (is_null(self::$instance)) {
            self::$instance = new self();
        }

        return self::$instance;
    }

    private function __construct()
    {
    }

    public function get_coupon($coupon_id)
    {
        return new \WC_Coupon(intval($coupon_id));
    }

    public function get_coupons($args)
    {
        $args['post_type'] = 'shop_coupon';

        if (!isset($args['posts_per_page'])) {
            $args['posts_per_page'] = -1;
        }

        if (!isset($args['post_status'])) {
            $args['post_status'] = 'publish';
        }

        $coupons = new \WP_Query($args);

        return (!empty($coupons->posts)) ? $coupons->posts : [];
    }

    public function create($data = [])
    {
        $coupon_code = $this->generate_coupon_code();
        $coupon = new \WC_Coupon($coupon_code);
        $setter_methods = $this->get_setter_methods();

        if (!empty($setter_methods) && is_array($setter_methods)) {
            foreach ($setter_methods as $key => $method) {
                if (isset($data[$key]) && $data[$key] != ''  && method_exists($coupon, $method)) {
                    $value = (is_array($data[$key])) ? array_map('sanitize_text_field', $data[$key]) : sanitize_text_field($data[$key]);
                    $coupon->{$method}($value);
                }
            }
        }

        $coupon->save();
        return ($coupon instanceof \WC_Coupon) ? $coupon : false;
    }

    private function get_setter_methods()
    {
        return [
            'discount_type' => 'set_discount_type',
            'amount' => 'set_amount',
            'products' => 'set_product_ids',
            'exclude_products' => 'set_excluded_product_ids',
            'categories' => 'set_product_categories',
            'exclude_categories' => 'set_excluded_product_categories',
            'expire_date' => 'set_date_expires',
            'minimum_spend' => 'set_minimum_amount',
            'maximum_spend' => 'set_maximum_amount',
            'limit_per_coupon' => 'set_usage_limit',
            'limit_per_user' => 'set_usage_limit_per_user',
            'limit_usage_items' => 'set_limit_usage_to_x_items',
            'free_shipping' => 'set_free_shipping',
            'individual_use' => 'set_individual_use',
            'exclude_sale_items' => 'set_exclude_sale_items',
        ];
    }

    public function generate_coupon_code()
    {
        for ($i = 0; $i < 1; $i++) {
            $coupon_code = strtolower(wp_generate_password(8, false));
            if ($this->coupon_code_exists($coupon_code)) {
                $i--;
            } else {
                break;
            }
        }
        return $coupon_code;
    }

    private function coupon_code_exists($coupon_code)
    {
        global $wpdb;
        return $wpdb->get_var($wpdb->prepare("SELECT COUNT(ID) FROM $wpdb->posts WHERE post_type = 'shop_coupon' AND post_name = '%s'", esc_sql(sanitize_text_field($coupon_code))));
    }
}
