<?php

namespace iwetcl\classes\repositories;

class Order
{
    private static $instance;

    public static function get_instance()
    {
        if (is_null(self::$instance)) {
            self::$instance = new self();
        }

        return self::$instance;
    }

    private function __construct()
    {
        //
    }

    public function get_order($order_id)
    {
        return wc_get_order(intval($order_id));
    }

    public function get_orders($args = [])
    {
        if (!isset($args['post_type'])) {
            $args['post_type'] = ['shop_order'];
        }

        if (!isset($args['posts_per_page'])) {
            $args['posts_per_page'] = -1;
        }

        if (!isset($args['post_status'])) {
            $args['post_status'] = 'any';
        }

        $orders = get_posts($args);
        return $orders;
    }

    public function get_order_statuses()
    {
        return wc_get_order_statuses();
    }

    public function get_orders_per_status()
    {
        $statuses = $this->get_order_statuses();
        $orders = [];

        if (!empty($statuses) && is_array($statuses)) {
            foreach ($statuses as $status_name => $status_label) {
                $result = wc_get_orders([
                    'numberposts' => 1,
                    'status' => $status_name
                ]);

                if (!empty($result[0]) && $result[0] instanceof \WC_Order) {
                    $orders[] = $result[0];
                }
            }
        }

        return $orders;
    }

    public function get_billing_countries()
    {
        return WC()->countries->countries;
    }

    public function get_product_ids_from_order($order_object)
    {
        $product_ids = [];
        if (!empty($order_object) && $order_object instanceof \WC_Order) {
            foreach ($order_object->get_items('line_item') as $order_item) {
                $item_data = $order_item->get_data();
                $product_ids[] = intval($item_data['product_id']);
            }
        }

        return $product_ids;
    }

    public function get_categories_by_product_ids($product_ids)
    {
        $category_ids = [];
        if (!empty($product_ids) && is_array($product_ids)) {
            foreach ($product_ids as $product_id) {
                $product_category_ids = wc_get_product_cat_ids(intval($product_id));
                $category_ids = array_merge($category_ids, $product_category_ids);
            }
        }

        return array_unique($category_ids);
    }
}
