<?php

namespace iwetcl\classes\repositories;

class Post
{
    private static $instance;

    public static function get_instance()
    {
        if (is_null(self::$instance)) {
            self::$instance = new self();
        }

        return self::$instance;
    }

    private function __construct()
    {
    }

    public function get_post($coupon_id)
    {
        return new \WC_Coupon(intval($coupon_id));
    }

    public function get_posts($args)
    {
        if (!isset($args['post_type'])) {
            $args['post_type'] = 'post';
        }

        if (!isset($args['posts_per_page'])) {
            $args['posts_per_page'] = -1;
        }

        if (!isset($args['post_status'])) {
            $args['post_status'] = 'publish';
        }

        $result = new \WP_Query($args);
        return (!empty($result->posts)) ? $result->posts : [];
    }

    public function get_post_categories_by_name($name)
    {
        return get_terms([
            'taxonomy' => 'category',
            'hide_empty' => false,
            'name__like' => strtolower(sanitize_text_field($name))
        ]);
    }

    public function get_preload_post_categories($email_template_id)
    {
        if (empty($email_template_id)) {
            return [];
        }

        $preload = get_post_meta(intval($email_template_id), 'iwetc_preload', true);
        if (empty($preload['post_categories'])) {
            return [];
        }

        $post_category_ids = explode(',', $preload['post_categories']);

        return get_terms([
            'taxonomy' => 'category',
            'hide_empty' => false,
            'include' => array_map('intval', $post_category_ids),
            'fields' => 'id=>name'
        ]);
    }

    public function get_preload_post_included($email_template_id)
    {
        if (empty($email_template_id)) {
            return [];
        }

        $preload = get_post_meta(intval($email_template_id), 'iwetc_preload', true);
        if (empty($preload['post_included'])) {
            return [];
        }

        $output = [];
        $post_ids = explode(',', $preload['post_included']);

        $posts = get_posts([
            'numberposts' => -1,
            'include' => array_map('intval', $post_ids),
        ]);

        if (!empty($posts)) {
            foreach ($posts as $post_item) {
                if ($post_item instanceof \WP_Post) {
                    $output[$post_item->ID] = $post_item->post_title;
                }
            }
        }

        return $output;
    }

    public function get_preload_post_excluded($email_template_id)
    {
        if (empty($email_template_id)) {
            return [];
        }

        $preload = get_post_meta(intval($email_template_id), 'iwetc_preload', true);
        if (empty($preload['post_excluded'])) {
            return [];
        }

        $output = [];
        $post_ids = explode(',', $preload['post_excluded']);

        $posts = get_posts([
            'numberposts' => -1,
            'include' => array_map('intval', $post_ids),
        ]);

        if (!empty($posts)) {
            foreach ($posts as $post_item) {
                if ($post_item instanceof \WP_Post) {
                    $output[$post_item->ID] = $post_item->post_title;
                }
            }
        }

        return $output;
    }
}
