<?php

namespace iwetcl\classes\repositories;

class Product
{
    private static $instance;

    public static function get_instance()
    {
        if (is_null(self::$instance)) {
            self::$instance = new self();
        }

        return self::$instance;
    }

    private function __construct()
    {
    }

    public function get_product($coupon_id)
    {
        return new \WC_Coupon(intval($coupon_id));
    }

    public function get_products($args)
    {
        if (!isset($args['post_type'])) {
            $args['post_type'] = ['product', 'product_variation'];
        }

        if (!isset($args['posts_per_page'])) {
            $args['posts_per_page'] = -1;
        }

        if (!isset($args['post_status'])) {
            $args['post_status'] = 'publish';
        }

        $products = new \WP_Query($args);
        return (!empty($products->posts)) ? $products->posts : [];
    }

    public function get_product_categories_by_name($name)
    {
        return get_terms([
            'taxonomy' => 'product_cat',
            'hide_empty' => false,
            'name__like' => strtolower(sanitize_text_field($name))
        ]);
    }

    public function get_product_categories()
    {
        return get_terms([
            'taxonomy' => 'product_cat',
            'hide_empty' => false,
        ]);
    }

    public function get_preload_products($email_template_id)
    {
        if (empty($email_template_id)) {
            return [];
        }

        $preload = get_post_meta(intval($email_template_id), 'iwetc_preload', true);
        if (empty($preload['products'])) {
            return [];
        }

        $product_ids = explode(',', $preload['products']);
        if (empty($product_ids) || !is_array($product_ids)) {
            return [];
        }

        $result = new \WP_Query([
            'post_type' => ['product', 'product_variation'],
            'posts_per_page' => -1,
            'include' => array_map('intval', $product_ids)
        ]);

        if (empty($result->posts)) {
            return [];
        }

        $output = [];
        foreach ($result->posts as $product) {
            $output[$product->ID] = $product->post_title;
        }

        return $output;
    }

    public function get_preload_product_categories($email_template_id)
    {
        if (empty($email_template_id)) {
            return [];
        }

        $preload = get_post_meta(intval($email_template_id), 'iwetc_preload', true);
        if (empty($preload['product_categories'])) {
            return [];
        }

        $product_category_ids = explode(',', $preload['product_categories']);

        return get_terms([
            'taxonomy' => 'product_cat',
            'hide_empty' => false,
            'include' => array_map('intval', $product_category_ids),
            'fields' => 'id=>name'
        ]);
    }
}
