<?php

namespace iwetcl\classes\requests;

use iwetcl\classes\helpers\Sanitizer;
use iwetcl\classes\helpers\Shortcode_Helper;
use iwetcl\classes\templates\Template;
use iwetcl\classes\repositories\Coupon;
use iwetcl\classes\repositories\Order;
use iwetcl\classes\repositories\Post;
use iwetcl\classes\repositories\Product;
use iwetcl\classes\services\render\Email_Render;

class Ajax_Handler
{
    private static $instance;

    public static function register_callback()
    {
        if (is_null(self::$instance)) {
            self::$instance = new self();
        }

        return self::$instance;
    }

    private function __construct()
    {
        add_action('wp_ajax_iwetc_get_email_preview', [$this, 'get_email_preview']);
        add_action('wp_ajax_iwetc_send_test_email', [$this, 'send_test_email']);
        add_action('wp_ajax_iwetc_get_coupons', [$this, 'get_coupons']);
        add_action('wp_ajax_iwetc_get_products', [$this, 'get_products']);
        add_action('wp_ajax_iwetc_get_product_categories', [$this, 'get_product_categories']);
        add_action('wp_ajax_iwetc_get_posts', [$this, 'get_posts']);
        add_action('wp_ajax_iwetc_get_post_categories', [$this, 'get_post_categories']);
        add_action('wp_ajax_iwetc_update_theme', [$this, 'update_theme']);
    }

    public function get_email_preview()
    {
        $email_render_service = new Email_Render([
            'object_type' => (!empty($_POST['order_id'])) ? 'order_id' : '',
            'object' => (!empty($_POST['order_id'])) ? intval($_POST['order_id']) : '',
            'render_type' => 'preview',
            'custom_css' => sanitize_text_field($_POST['custom_css']),
            'direction' => sanitize_text_field($_POST['direction']),
            'email_structure' => Sanitizer::array($_POST['email_structure']),
        ]);

        $email_rendered = $email_render_service->render();
        $this->make_response([
            'success' => true,
            'email_rendered' => $email_rendered
        ]);
    }

    public function send_test_email()
    {
        if (empty($_POST['to_email']) || !is_email($_POST['to_email'])) {
            return false;
        }

        if (!empty($_POST['order_id'])) {
            $order_repository = Order::get_instance();
            $order = $order_repository->get_order(intval($_POST['order_id']));
            if ($order instanceof \WC_Order) {
                $user_object = $order->get_user();
                if ($user_object instanceof \WP_User) {
                    $shortcode = Shortcode_Helper::get_instance();
                    $shortcode->set_data([
                        'order_object' => $order,
                        'user_object' => $user_object
                    ]);
                }
            }
        }

        $subject = (!empty($shortcode)) ? $shortcode->replace(sanitize_text_field($_POST['email_subject'])) : sanitize_text_field($_POST['email_subject']);

        $email_render_service = new Email_Render([
            'object_type' => 'order',
            'object' => (!empty($order) && $order instanceof \WC_Order) ? $order : null,
            'render_type' => 'test_email',
            'custom_css' => sanitize_text_field($_POST['custom_css']),
            'direction' => sanitize_text_field($_POST['direction']),
            'email_structure' => Sanitizer::array($_POST['email_structure']),
        ]);
        $email_rendered = $email_render_service->render();
        $headers = ['Content-Type: text/html; charset=UTF-8'];

        $result = wp_mail(sanitize_email($_POST['to_email']), $subject, $email_rendered, $headers);

        $this->make_response([
            'sent' => $result
        ]);
    }

    public function get_coupons()
    {
        $coupon_repository = Coupon::get_instance();
        $list = [];
        $coupons = $coupon_repository->get_coupons([
            'iwetc_general_column_filter' => [
                [
                    'field' => 'post_title',
                    'value' => sanitize_text_field($_POST['search']),
                    'operator' => 'like'
                ]
            ]
        ]);

        if (!empty($coupons)) {
            foreach ($coupons as $coupon) {
                if ($coupon instanceof \WP_Post) {
                    $list['results'][] = [
                        'id' => $coupon->post_title,
                        'text' => $coupon->post_title
                    ];
                }
            }
        }

        $this->make_response($list);
    }

    public function get_products()
    {
        $product_repository = Product::get_instance();
        $list = [];
        $products = $product_repository->get_products([
            'iwetc_general_column_filter' => [
                [
                    'field' => 'post_title',
                    'value' => sanitize_text_field($_POST['search']),
                    'operator' => 'like'
                ]
            ]
        ]);

        if (!empty($products)) {
            foreach ($products as $product) {
                if ($product instanceof \WP_Post) {
                    $list['results'][] = [
                        'id' => $product->ID,
                        'text' => $product->post_title
                    ];
                }
            }
        }

        $this->make_response($list);
    }

    public function get_product_categories()
    {
        $product_repository = Product::get_instance();
        $list = [];
        $categories = $product_repository->get_product_categories_by_name(sanitize_text_field($_POST['search']));

        if (!empty($categories)) {
            foreach ($categories as $category) {
                if ($category instanceof \WP_Term) {
                    $list['results'][] = [
                        'id' => $category->term_id,
                        'text' => $category->name
                    ];
                }
            }
        }

        $this->make_response($list);
    }

    public function get_posts()
    {
        $post_repository = Post::get_instance();
        $list = [];
        $posts = $post_repository->get_posts([
            'iwetc_general_column_filter' => [
                [
                    'field' => 'post_title',
                    'value' => sanitize_text_field($_POST['search']),
                    'operator' => 'like'
                ]
            ]
        ]);

        if (!empty($posts)) {
            foreach ($posts as $post) {
                if ($post instanceof \WP_Post) {
                    $list['results'][] = [
                        'id' => $post->ID,
                        'text' => $post->post_title
                    ];
                }
            }
        }

        $this->make_response($list);
    }

    public function get_post_categories()
    {
        $post_repository = Post::get_instance();
        $list = [];
        $categories = $post_repository->get_post_categories_by_name(sanitize_text_field($_POST['search']));

        if (!empty($categories)) {
            foreach ($categories as $category) {
                if ($category instanceof \WP_Term) {
                    $list['results'][] = [
                        'id' => $category->term_id,
                        'text' => $category->name
                    ];
                }
            }
        }

        $this->make_response($list);
    }

    public function update_theme()
    {
        if (!empty($_POST['theme_name'])) {
            update_option('iwetc_theme', sanitize_text_field($_POST['theme_name']));
        }
        $this->make_response('true');
    }

    private function make_response($data)
    {
        echo (is_array($data)) ? json_encode($data, JSON_UNESCAPED_UNICODE) : $data;
        die();
    }
}
