<?php

namespace iwetcl\classes\requests;

use iwetcl\classes\repositories\Flush_Message;
use iwetcl\classes\services\activation\Activation_Service;

class Post_Handler
{
    private static $instance;

    public static function register_callback()
    {
        if (is_null(self::$instance)) {
            self::$instance = new self();
        }

        return self::$instance;
    }

    private function __construct()
    {
        add_action('admin_post_iwetc_activation_plugin', [$this, 'activation_plugin']);
    }

    public function activation_plugin()
    {
        $message = "Error! Try again";

        if (isset($_POST['activation_type'])) {
            if ($_POST['activation_type'] == 'skip') {
                update_option('iwetcl_is_active', 'skipped');
                return $this->redirect(IWETCL_MAIN_PAGE);
            } else {
                if (!empty($_POST['email']) && !empty($_POST['industry'])) {
                    $activation_service = new Activation_Service();
                    $info = $activation_service->activation([
                        'email' => sanitize_email($_POST['email']),
                        'domain' => sanitize_url($_SERVER['SERVER_NAME']),
                        'product_id' => 'iwetcl',
                        'product_name' => IWETCL_LABEL,
                        'industry' => sanitize_text_field($_POST['industry']),
                        'multi_site' => is_multisite(),
                        'core_version' => null,
                        'subsystem_version' => IWETCL_VERSION,
                    ]);

                    if (!empty($info) && is_array($info)) {
                        if (!empty($info['result']) && $info['result'] == true) {
                            update_option('iwetcl_is_active', 'yes');
                            $message = __('Success !', 'ithemeland-woocommerce-email-template-customizer-lite');
                        } else {
                            update_option('iwetcl_is_active', 'no');
                            $message = (!empty($info['message'])) ? esc_html($info['message']) : __('System Error !', 'ithemeland-woocommerce-email-template-customizer-lite');
                        }
                    } else {
                        update_option('iwetcl_is_active', 'no');
                        $message = __('Connection Timeout! Please Try Again', 'ithemeland-woocommerce-email-template-customizer-lite');
                    }
                }
            }
        }

        $this->redirect(IWETCL_MAIN_PAGE, $message);
    }

    private function redirect($url = null, $message = [])
    {
        $url = (!empty($url)) ? $url : IWETCL_MAIN_PAGE;

        if (!is_null($message)) {
            $flush_message_repository = new Flush_Message();
            $flush_message_repository->set($message);
        }

        wp_redirect($url);
        die();
    }
}
