<?php

namespace iwetcl\classes\services\render;

use iwetcl\classes\repositories\Coupon;
use iwetcl\classes\repositories\Order;

class Element_Render
{
    private static $instance;

    public static function get_instance()
    {
        if (is_null(self::$instance)) {
            self::$instance = new self();
        }

        return self::$instance;
    }

    private function __construct()
    {
    }

    public function get_text($data)
    {
        $output = '<div style="width: 100%; float: left; padding: 1px 0;">';
        $output .= sprintf('%s', wp_unslash($data['html']));
        $output .= '</div>';
        return $output;
    }

    public function get_html($data)
    {
        $output = '<div style="width: 100%; float: left; padding: 1px 0;">';
        $output .= sprintf('%s', wp_unslash($data['html']));
        $output .= '</div>';
        return $output;
    }

    public function get_order_details($data)
    {
        $template = (!empty($data['attributes']['data-template']) && in_array($data['attributes']['data-template'], ['default', 'vertical_text', 'horizontal_text'])) ? esc_attr($data['attributes']['data-template']) : 'default';

        ob_start();
        wc_get_template("order_details_{$template}.php", [
            'order' => $data['order'],
            'show_sku' => (!empty($data['attributes']['show-sku'])) ? 'yes' : 'no',
            'translate' => [
                'product' => (!empty($data['translate']['order_details_product_text'])) ? esc_html($data['translate']['order_details_product_text']) : 'Product',
                'quantity' => (!empty($data['translate']['order_details_quantity_text'])) ? esc_html($data['translate']['order_details_quantity_text']) : 'Quantity',
                'price' => (!empty($data['translate']['order_details_price_text'])) ? esc_html($data['translate']['order_details_price_text']) : 'Price',
            ],
            'element_content_attributes' => (!empty($data['element_content_attributes'])) ? $data['element_content_attributes'] : '',
            'children_attributes' => (!empty($data['children_attributes'])) ? $data['children_attributes'] : '',
        ], IWETCL_NAME, IWETCL_VIEWS_DIR . 'builder/element/');

        return ob_get_clean();
    }

    public function get_order_subtotal($data)
    {
        ob_start();
        wc_get_template("order_subtotal.php", [
            'order' => $data['order'],
            'translate' => [
                'subtotal' => (!empty($data['translate']['order_subtotal_subtotal_text'])) ? esc_html($data['translate']['order_subtotal_subtotal_text']) : 'Subtotal',
                'discount' => (!empty($data['translate']['order_subtotal_discount_text'])) ? esc_html($data['translate']['order_subtotal_discount_text']) : 'Discount',
                'shipping' => (!empty($data['translate']['order_subtotal_shipping_text'])) ? esc_html($data['translate']['order_subtotal_shipping_text']) : 'Shipping',
                'order_fully_refunded' => (!empty($data['translate']['order_subtotal_order_fully_refunded_text'])) ? esc_html($data['translate']['order_subtotal_order_fully_refunded_text']) : 'Order fully refunded',
                'refunded' => (!empty($data['translate']['order_subtotal_refunded_text'])) ? esc_html($data['translate']['order_subtotal_refunded_text']) : 'Refunded',
            ],
            'element_content_attributes' => (!empty($data['element_content_attributes'])) ? $data['element_content_attributes'] : '',
            'children_attributes' => (!empty($data['children_attributes'])) ? $data['children_attributes'] : '',
        ], IWETCL_NAME, IWETCL_VIEWS_DIR . 'builder/element/');

        return ob_get_clean();
    }

    public function get_order_total($data)
    {
        ob_start();
        wc_get_template("order_total.php", [
            'order' => $data['order'],
            'translate' => [
                'total' => (!empty($data['translate']['order_total_text'])) ? esc_html($data['translate']['order_total_text']) : 'Total',
            ],
            'element_content_attributes' => (!empty($data['element_content_attributes'])) ? $data['element_content_attributes'] : '',
            'children_attributes' => (!empty($data['children_attributes'])) ? $data['children_attributes'] : '',
        ], IWETCL_NAME, IWETCL_VIEWS_DIR . 'builder/element/');

        return ob_get_clean();
    }

    public function get_shipping_method($data)
    {
        ob_start();
        wc_get_template("shipping_method.php", [
            'order' => $data['order'],
            'translate' => [
                'shipping_method' => (!empty($data['translate']['shipping_method_text'])) ? esc_html($data['translate']['shipping_method_text']) : 'Shipping method',
            ],
            'element_content_attributes' => (!empty($data['element_content_attributes'])) ? $data['element_content_attributes'] : '',
            'children_attributes' => (!empty($data['children_attributes'])) ? $data['children_attributes'] : '',
        ], IWETCL_NAME, IWETCL_VIEWS_DIR . 'builder/element/');

        return ob_get_clean();
    }

    public function get_payment_method($data)
    {
        ob_start();
        wc_get_template("payment_method.php", [
            'order' => $data['order'],
            'translate' => [
                'payment_method' => (!empty($data['translate']['payment_method_text'])) ? esc_html($data['translate']['payment_method_text']) : 'Payment method',
            ],
            'element_content_attributes' => (!empty($data['element_content_attributes'])) ? $data['element_content_attributes'] : '',
            'children_attributes' => (!empty($data['children_attributes'])) ? $data['children_attributes'] : '',
        ], IWETCL_NAME, IWETCL_VIEWS_DIR . 'builder/element/');

        return ob_get_clean();
    }

    public function get_customer_note($data)
    {
        ob_start();
        wc_get_template("customer_note.php", [
            'order' => $data['order'],
            'translate' => [
                'customer_note' => (!empty($data['translate']['customer_note_text'])) ? esc_html($data['translate']['customer_note_text']) : 'Customer note',
            ],
            'element_content_attributes' => (!empty($data['element_content_attributes'])) ? $data['element_content_attributes'] : '',
            'children_attributes' => (!empty($data['children_attributes'])) ? $data['children_attributes'] : '',
        ], IWETCL_NAME, IWETCL_VIEWS_DIR . 'builder/element/');

        return ob_get_clean();
    }

    public function get_billing_address($data)
    {
        ob_start();
        wc_get_template("billing_address.php", [
            'order' => $data['order'],
            'element_content_attributes' => (!empty($data['element_content_attributes'])) ? $data['element_content_attributes'] : '',
            'children_attributes' => (!empty($data['children_attributes'])) ? $data['children_attributes'] : '',
        ], IWETCL_NAME, IWETCL_VIEWS_DIR . 'builder/element/');

        return ob_get_clean();
    }

    public function get_shipping_address($data)
    {
        ob_start();
        wc_get_template("shipping_address.php", [
            'order' => $data['order'],
            'element_content_attributes' => (!empty($data['element_content_attributes'])) ? $data['element_content_attributes'] : '',
            'children_attributes' => (!empty($data['children_attributes'])) ? $data['children_attributes'] : '',
        ], IWETCL_NAME, IWETCL_VIEWS_DIR . 'builder/element/');

        return ob_get_clean();
    }

    public function get_products($data)
    {
        $data['row'] = (!empty($data['attributes']['data-row'])) ? intval($data['attributes']['data-row']) : 1;
        $data['column'] = (!empty($data['attributes']['data-column'])) ? intval($data['attributes']['data-column']) : 2;
        $products = $this->get_products_by_type($data);

        ob_start();
        wc_get_template('products.php', [
            'products' => $products,
            'row' => $data['row'],
            'column' => $data['column'],
            'add_to_cart' => (!empty($data['attributes']['data-add-to-cart']) && $data['attributes']['data-add-to-cart'] == 'true'),
            'element_content_attributes' => (!empty($data['element_content_attributes'])) ? $data['element_content_attributes'] : '',
            'children_attributes' => (!empty($data['children_attributes'])) ? $data['children_attributes'] : '',
        ], IWETCL_NAME, IWETCL_VIEWS_DIR . 'builder/element/');

        return ob_get_clean();
    }

    public function get_post($data)
    {
        $posts = $this->get_posts_by_type($data);
        $row = (!empty($data['attributes']['data-row'])) ? intval($data['attributes']['data-row']) : 1;
        $column = (!empty($data['attributes']['data-column'])) ? intval($data['attributes']['data-column']) : 2;

        ob_start();
        wc_get_template('posts.php', [
            'posts' => $posts,
            'row' => $row,
            'column' => $column,
            'element_content_attributes' => (!empty($data['element_content_attributes'])) ? $data['element_content_attributes'] : '',
            'children_attributes' => (!empty($data['children_attributes'])) ? $data['children_attributes'] : '',
        ], IWETCL_NAME, IWETCL_VIEWS_DIR . 'builder/element/');

        return ob_get_clean();
    }

    public function get_coupon($data)
    {
        $coupon_code = 'Coupon Code';
        if (!empty($data['children_attributes']['coupon']['data-coupon-type']) && $data['children_attributes']['coupon']['data-coupon-type'] == 'existing_coupon') {
            $coupon_code = (!empty($data['children_attributes']['coupon']['data-coupon-code'])) ? sanitize_text_field($data['children_attributes']['coupon']['data-coupon-code']) : '';
            if (!empty($coupon_code)) {
                $coupon = new \WC_Coupon($coupon_code);
            }
        }

        if (!empty($data['children_attributes']['coupon']['data-coupon-type']) && $data['children_attributes']['coupon']['data-coupon-type'] == 'generate_coupon' && $data['render_type'] == 'wc_action') {
            $coupon = $this->generate_coupon($data);
        }

        if (!empty($coupon) && $coupon instanceof \WC_Coupon) {
            $coupon_code = $coupon->get_code();
            $coupon_expire_date = $coupon->get_date_expires();
            $coupon_amount = $coupon->get_amount();

            if (strpos($data['html'], '{coupon_code}') !== false) {
                $data['html'] = str_replace('{coupon_code}', $coupon_code, $data['html']);
            }
            if (strpos($data['html'], '{coupon_expire_date}') !== false && !empty($coupon_expire_date->date('Y/m/d H:i'))) {
                $data['html'] = str_replace('{coupon_expire_date}', $coupon_expire_date->date('Y/m/d H:i'), $data['html']);
            }
            if (strpos($data['html'], '{coupon_amount}') !== false) {
                $data['html'] = str_replace('{coupon_amount}', $coupon_amount, $data['html']);
            }
        }

        return (!empty($data['html'])) ? sprintf('%s', wp_unslash($data['html'])) : '';
    }

    public function get_wc_hook($data)
    {
        $hook = (!empty($data['children_attributes']['wc_hook']['data-wc-hook'])) ? $data['children_attributes']['wc_hook']['data-wc-hook'] : 'woocommerce_email_before_order_table';
        if (!empty($data['order'])) {
            switch ($hook) {
                case 'woocommerce_email_before_order_table':
                    ob_start();
                    do_action('woocommerce_email_before_order_table', $data['order'], false, '', '');
                    $hook_string = ob_get_clean();
                    break;
                case 'woocommerce_email_after_order_table':
                    ob_start();
                    do_action('woocommerce_email_after_order_table', $data['order'], false, '', '');
                    $hook_string = ob_get_clean();
                    break;
                case 'woocommerce_email_order_meta':
                    ob_start();
                    do_action('woocommerce_email_order_meta', $data['order'], false, '', '');
                    $hook_string = ob_get_clean();
                    break;
                default:
                    $hook_string = '';
            }
        }

        ob_start();
        wc_get_template('wc_hook.php', [
            'hook_string' => $hook_string,
            'element_content_attributes' => (!empty($data['element_content_attributes'])) ? $data['element_content_attributes'] : '',
            'children_attributes' => (!empty($data['children_attributes'])) ? $data['children_attributes'] : '',
        ], IWETCL_NAME, IWETCL_VIEWS_DIR . 'builder/element/');

        return ob_get_clean();
    }

    // Private methods

    private function get_products_by_type($data)
    {
        $order_repository = Order::get_instance();
        $bought_ids = $order_repository->get_product_ids_from_order($data['order']);
        $product_ids = [];
        $exclude_product_ids = [];
        $categories = [];
        $exclude_categories = [];
        $orderby = 'date';
        $limit = intval($data['row']) * intval($data['column']);
        if (!empty($data['attributes']['data-type'])) {
            switch ($data['attributes']['data-type']) {
                case 'related':
                    foreach ($bought_ids as $id) {
                        $product_ids = array_merge($product_ids, wc_get_related_products($id));
                    }
                    break;
                case 'on_sale':
                    $product_ids = wc_get_product_ids_on_sale();
                    break;
                case 'up_sell':
                    foreach ($bought_ids as $id) {
                        $upsell_ids = get_post_meta($id, '_upsell_ids', true);
                        if (is_array($upsell_ids) && count($upsell_ids)) {
                            $product_ids = array_merge($product_ids, $upsell_ids);
                        }
                    }
                    break;
                case 'cross_sell':
                    foreach ($bought_ids as $id) {
                        $cross_sell_ids = get_post_meta($id, '_crosssell_ids', true);
                        if (is_array($cross_sell_ids) && count($cross_sell_ids)) {
                            $product_ids = array_merge($product_ids, $cross_sell_ids);
                        }
                    }
                    break;
                case 'category':
                    foreach ($bought_ids as $id) {
                        $cats = get_the_terms($id, 'product_cat');
                        if (is_array($cats) && count($cats)) {
                            foreach ($cats as $cat) {
                                $categories[] = $cat->slug;
                            }
                        }
                    }
                    break;
                case 'featured':
                    $product_ids = wc_get_featured_product_ids();
                    break;
                case 'best_seller':
                    $args  = [
                        'post_type' => 'product',
                        'meta_key' => 'total_sales',
                        'orderby' => 'meta_value_num',
                        'posts_per_page' => $limit
                    ];

                    $query = new \WP_Query($args);
                    if (is_wp_error($query)) {
                        break;
                    }

                    $products = $query->get_posts();
                    if (is_array($products) && count($products)) {
                        foreach ($products as $product) {
                            $product_ids[] = $product->ID;
                        }
                    }
                    break;
                case 'best_rated':
                    $args  = [
                        'post_type' => 'product',
                        'meta_key' => '_wc_average_rating',
                        'orderby' => 'meta_value_num',
                        'posts_per_page' => $limit
                    ];

                    $query = new \WP_Query($args);
                    if (is_wp_error($query)) {
                        break;
                    }

                    $products = $query->get_posts();
                    if (is_array($products) && count($products)) {
                        foreach ($products as $product) {
                            $product_ids[] = $product->ID;
                        }
                    }
                    break;
                case 'custom_query':
                    if (!empty($data['attributes']['data-products'])) {
                        $ids = explode(',', $data['attributes']['data-products']);
                        if (!empty($ids) && is_array($ids)) {
                            $product_ids = $product_ids + $ids;
                        }
                    }

                    if (!empty($data['attributes']['data-exclude-products'])) {
                        $ids = explode(',', $data['attributes']['data-exclude-products']);
                        if (!empty($ids) && is_array($ids)) {
                            $exclude_product_ids = $exclude_product_ids + $ids;
                        }
                    }

                    if (!empty($data['attributes']['data-categories'])) {
                        $ids = explode(',', $data['attributes']['data-categories']);
                        if (!empty($ids) && is_array($ids)) {
                            foreach ($ids as $category_id) {
                                $category = get_term_by('term_id', intval($category_id));
                                if ($category instanceof \WP_Term) {
                                    $categories[] = $category->slug;
                                }
                            }
                        }
                    }

                    if (!empty($data['attributes']['data-exclude-categories'])) {
                        $ids = explode(',', $data['attributes']['data-exclude-categories']);
                        if (empty($ids) || !is_array($ids)) {
                            break;
                        }
                        $args  = [
                            'post_type' => 'product',
                            'posts_per_page' => $limit,
                            'tax_query' => [
                                [
                                    'taxonomy'  => 'product_cat',
                                    'field'     => 'term_id',
                                    'terms'     => array_map('intval', $ids),
                                    'operator'  => 'IN',
                                ]
                            ],
                        ];

                        $query = new \WP_Query($args);
                        if (is_wp_error($query)) {
                            break;
                        }

                        $products = $query->get_posts();
                        if (is_array($products) && count($products)) {
                            foreach ($products as $product) {
                                $exclude_product_ids[] = $product->ID;
                            }
                        }
                    }
                    break;
            }
        }

        $args = [
            'status' => 'publish',
            'limit' => $limit,
            'include' => array_unique($product_ids),
            'exclude' => array_unique($exclude_product_ids),
            'orderby' => $orderby,
            'order' => 'DESC',
            'stock_status' => 'instock',
        ];

        if (!empty($categories)) {
            $args['category'] = $categories;
        }

        return wc_get_products($args);
    }

    private function get_posts_by_type($data)
    {
        $row = (!empty($data['attributes']['data-row'])) ? intval($data['attributes']['data-row']) : 1;
        $column = (!empty($data['attributes']['data-column'])) ? intval($data['attributes']['data-column']) : 2;

        $args = [
            'post_type' => 'post',
            'numberposts' => ($row * $column),
            'post_status' => ['publish']
        ];

        if (!empty($data['attributes']['data-category'])) {
            $args['category'] = sanitize_text_field($data['attributes']['data-category']);
        }
        if (!empty($data['attributes']['data-included'])) {
            $args['include'] = array_map('intval', explode(',', $data['attributes']['data-included']));
        }
        if (!empty($data['attributes']['data-excluded'])) {
            $args['exclude'] = array_map('intval', explode(',', $data['attributes']['data-excluded']));
        }

        $posts = get_posts($args);
        return $posts;
    }

    private function generate_coupon($content)
    {
        if (empty($content['children_attributes']['coupon'])) {
            return false;
        }

        $coupon_repository = Coupon::get_instance();
        $expire_date = '';
        if (!empty($content['children_attributes']['coupon']['data-expire-after-days'])) {
            $expire_date = (current_time('U') + intval($content['children_attributes']['coupon']['data-expire-after-days']) * DAY_IN_SECONDS);
        }

        $coupon = $coupon_repository->create([
            'discount_type' => (!empty($content['children_attributes']['coupon']['data-discount-type'])) ? sanitize_text_field($content['children_attributes']['coupon']['data-discount-type']) : '',
            'amount' => (!empty($content['children_attributes']['coupon']['data-coupon-amount'])) ? sanitize_text_field($content['children_attributes']['coupon']['data-coupon-amount']) : '',
            'products' => (!empty($content['children_attributes']['coupon']['data-products'])) ? sanitize_text_field($content['children_attributes']['coupon']['data-products']) : '',
            'exclude_products' => (!empty($content['children_attributes']['coupon']['data-exclude-products'])) ? sanitize_text_field($content['children_attributes']['coupon']['data-exclude-products']) : '',
            'categories' => (!empty($content['children_attributes']['coupon']['data-categories'])) ? sanitize_text_field($content['children_attributes']['coupon']['data-categories']) : '',
            'exclude_categories' => (!empty($content['children_attributes']['coupon']['data-exclude-categories'])) ? sanitize_text_field($content['children_attributes']['coupon']['data-exclude-categories']) : '',
            'expire_date' => $expire_date,
            'minimum_spend' => (!empty($content['children_attributes']['coupon']['data-minimum-spend'])) ? sanitize_text_field($content['children_attributes']['coupon']['data-minimum-spend']) : '',
            'maximum_spend' => (!empty($content['children_attributes']['coupon']['data-maximum-spend'])) ? sanitize_text_field($content['children_attributes']['coupon']['data-maximum-spend']) : '',
            'limit_per_coupon' => (!empty($content['children_attributes']['coupon']['data-limit-per-coupon'])) ? sanitize_text_field($content['children_attributes']['coupon']['data-limit-per-coupon']) : '',
            'limit_per_user' => (!empty($content['children_attributes']['coupon']['data-limit-per-user'])) ? sanitize_text_field($content['children_attributes']['coupon']['data-limit-per-user']) : '',
            'limit_usage_items' => (!empty($content['children_attributes']['coupon']['data-limit-usage-items'])) ? sanitize_text_field($content['children_attributes']['coupon']['data-limit-usage-items']) : '',
            'free_shipping' => (!empty($content['children_attributes']['coupon']['data-allow-free-shipping'])) ? sanitize_text_field($content['children_attributes']['coupon']['data-allow-free-shipping']) : '',
            'individual_use' => (!empty($content['children_attributes']['coupon']['data-individual-use'])) ? sanitize_text_field($content['children_attributes']['coupon']['data-individual-use']) : '',
            'exclude_sale_items' => (!empty($content['children_attributes']['coupon']['data-exclude-sale-items'])) ? sanitize_text_field($content['children_attributes']['coupon']['data-exclude-sale-items']) : '',
        ]);

        return ($coupon && $coupon instanceof \WC_Coupon) ? $coupon : false;
    }
}
