<?php

namespace iwetcl\classes\templates;

use iwetcl\classes\templates\cancelled_order\Cancelled_Order;
use iwetcl\classes\templates\customer_completed_order\Customer_Completed_Order;
use iwetcl\classes\templates\customer_invoice\Customer_Invoice;
use iwetcl\classes\templates\customer_new_account\Customer_New_Account;
use iwetcl\classes\templates\customer_note\Customer_Note;
use iwetcl\classes\templates\customer_on_hold_order\Customer_On_Hold_Order;
use iwetcl\classes\templates\customer_processing_order\Customer_Processing_Order;
use iwetcl\classes\templates\customer_refunded_order\Customer_Refunded_Order;
use iwetcl\classes\templates\customer_reset_account\Customer_Reset_Account;
use iwetcl\classes\templates\default_template\Default_Template;
use iwetcl\classes\templates\failed_order\Failed_Order;
use iwetcl\classes\templates\new_order\New_Order;

class Template
{
    private static $instance;

    private $templates_option_name;
    private $custom_template_preset;

    public static function get_instance()
    {
        if (is_null(self::$instance)) {
            self::$instance = new self();
        }

        return self::$instance;
    }

    public function __construct()
    {
        $this->templates_option_name = "iwetc_templates";
        $this->custom_template_preset = "iwetc_template_";
    }

    public function get_templates()
    {
        $templates = $this->get_default_templates();
        $custom_templates = $this->get_custom_templates();
        if (!empty($custom_templates)) {
            $templates['custom_templates'] = $custom_templates;
        }

        return $templates;
    }

    public function get_custom_templates()
    {
        $output = [];

        global $wpdb;
        $custom_templates = $wpdb->get_results("SELECT option_name as template_key, option_value as structure FROM {$wpdb->options} WHERE option_name LIKE 'iwetc_template\_%'", OBJECT_K);

        if (empty($custom_templates)) {
            return $output;
        }

        $templates = get_option($this->templates_option_name, []);
        if (!empty($templates)) {
            foreach ($templates as $template_key => $template_data) {
                $key = $this->custom_template_preset . $template_key;
                if (!empty($custom_templates[$key]) && !empty($custom_templates[$key]->structure)) {
                    $template_data['structure'] = $custom_templates[$key]->structure;
                    $output[$template_key] = $template_data;
                }
            }
        }

        return $output;
    }

    public function delete($slug)
    {
        $templates = get_option($this->templates_option_name, []);
        $slug = sanitize_text_field($slug);
        if (isset($templates[$slug])) {
            unset($templates[$slug]);
            delete_option($this->custom_template_preset . $slug, null);
        }

        return update_option($this->templates_option_name, $templates);
    }

    public function insert_new_template($template)
    {
        if (empty($template['structure']) || empty($template['slug']) || empty($template['label'])) {
            return false;
        }

        $structure = $template['structure'];
        unset($template['structure']);

        $slug = sanitize_text_field($template['slug']);
        unset($template['slug']);

        $custom_templates = get_option($this->templates_option_name, []);
        if (isset($custom_templates[$slug])) {
            $slug = sanitize_text_field($slug . '_' . rand(100, 999));
        }

        $custom_templates[$slug] = $template;
        return (update_option($this->templates_option_name, $custom_templates)) ? update_option($this->custom_template_preset . $slug, $structure) : false;
    }

    private function get_classes()
    {
        return [
            'default' => Default_Template::get_instance(),
            'customer_new_account' => Customer_New_Account::get_instance(),
            'customer_reset_password' => Customer_Reset_Account::get_instance(),
            'customer_note' => Customer_Note::get_instance(),
            'customer_invoice' => Customer_Invoice::get_instance(),
            'customer_completed_order' => Customer_Completed_Order::get_instance(),
            'failed_order' => Failed_Order::get_instance(),
            'cancelled_order' => Cancelled_Order::get_instance(),
            'new_order' => New_Order::get_instance(),
            'customer_processing_order' => Customer_Processing_Order::get_instance(),
            'customer_on_hold_order' => Customer_On_Hold_Order::get_instance(),
            'customer_refunded_order' => Customer_Refunded_Order::get_instance(),
        ];
    }

    public function get_default_templates()
    {
        $classes = $this->get_classes();
        $templates = [];

        if (!empty($classes)) {
            foreach ($classes as $type => $instance) {
                if (method_exists($instance, 'get_templates')) {
                    $templates[$type] = $instance->get_templates();
                }
            }
        }

        return $templates;
    }
}
